#
# spec file for package crmsh
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with regression_tests

%global gname haclient
%global uname hacluster
%global crmsh_docdir %{_defaultdocdir}/%{name}

%global upstream_version tip
%global upstream_prefix crmsh
%global crmsh_release 1

%if 0%{?fedora_version} || 0%{?centos_version} || 0%{?rhel_version} || 0%{?rhel} || 0%{?fedora}
%define pkg_group System Environment/Daemons
%else
%define pkg_group Productivity/Clustering/HA
%endif

Name:           crmsh
Summary:        High Availability cluster command-line interface
License:        GPL-2.0-or-later
Group:          %{pkg_group}
Version:        5.0.0+20250324.9041399d
Release:        1.1
URL:            http://crmsh.github.io
Source0:        %{name}-%{version}.tar.bz2
Source1:        %{name}.tmpfiles.d.conf

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version}
# Requiring pacemaker makes crmsh harder to build on other distributions,
# and is mostly a convenience feature. So only do it for SUSE.
Requires(pre):  pacemaker
%endif
Requires:       %{name}-scripts >= %{version}-%{release}
Requires:       /usr/bin/which
Requires:       python3 >= 3.10
Requires:       python3-PyYAML
Requires:       python3-lxml
Requires:       python3-packaging
BuildRequires:  python3-lxml
BuildRequires:  python3-setuptools
BuildRequires:  python3-pip
BuildRequires:  python3-wheel

%if 0%{?suse_version}
# only require csync2 on SUSE since bootstrap
# only works for SUSE at the moment anyway
Requires:       csync2
%endif

%if 0%{?suse_version}
# Suse splits this off into a separate package
Requires:       python3-curses
Requires:       python3-python-dateutil
BuildRequires:  fdupes
BuildRequires:  python3-curses
%else
Requires:       python3-dateutil
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
%endif

# Required for core functionality
BuildRequires:  asciidoc
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  pkgconfig
BuildRequires:  python3

%if 0%{?suse_version}
# xsltproc is necessary for manpage generation; this is split out into
# libxslt-tools as of openSUSE 12.2.  Possibly strictly should be
# required by asciidoc
BuildRequires:  libxslt-tools
%endif

%if 0%{?suse_version} || 0%{?fedora_version} || 0%{?centos_version} || 0%{?rhel_version} || 0%{?rhel} || 0%{?fedora}
BuildArch:      noarch
%endif

%description
The crm shell is a command-line interface for High-Availability
cluster management on GNU/Linux systems. It simplifies the
configuration, management and troubleshooting of Pacemaker-based
clusters, by providing a powerful and intuitive set of features.

%package test
Summary:        Test package for crmsh
Group:          %{pkg_group}
Requires:       crmsh
%if %{with regression_tests}
Requires(post): mailx
Requires(post): procps
%if 0%{?suse_version}
Requires(post): python3-python-dateutil
%else
Requires(post): python3-dateutil
%endif
Requires(post): python3-tox
Requires(post): pacemaker
BuildArch:      noarch
%if 0%{?suse_version}
Requires(post): libglue-devel
%else
Requires(post): cluster-glue-libs-devel
%endif
Requires(post): python3-PyYAML
%endif

%description test
The crm shell is a command-line interface for High-Availability
cluster management on GNU/Linux systems. It simplifies the
configuration, management and troubleshooting of Pacemaker-based
clusters, by providing a powerful and intuitive set of features.
This package contains the regression test suite for crmsh.

%package scripts
Summary:        Crm Shell Cluster Scripts
Group:          Productivity/Clustering/HA

%description scripts
Cluster scripts for crmsh. The cluster scripts can be run
directly from the crm command line, or used by user interfaces
like hawk to implement configuration wizards.

%prep
%setup -q

# replace the shebang in all the scripts
# with ${_bindir}/python3
find . -type f -exec sed -i \
    -e "s|#!/usr/bin/python3?|#!%{__python3}|" \
    -e "s|#!/usr/bin/env python3?|#!%{__python3}|" \
    {} \;
sed -i -e '1{\@^#!%{_bindir}/python3@d}' crmsh/report/core.py

# this is wrong FIXME
sed -i -e '/data_files/d' setup.py

%build
./autogen.sh

%{configure}            \
    --sysconfdir=%{_sysconfdir} \
    --localstatedir=%{_var}             \
    --with-version=%{version}    \
    --docdir=%{crmsh_docdir}

%if 0%{?suse_version}
%python3_pyproject_wheel
%else
%pyproject_buildrequires -t
%pyproject_wheel
%endif

# Generate manpages
for manpg in doc/crm{,sh_crm_report}.8.adoc ; do
    a2x -f manpage $manpg
done

for docad in doc/crm{,sh_crm_report}.8.adoc ; do
    asciidoc --unsafe --backend=xhtml11 $docad
done

%if %{with regression_tests}
tox
if [ ! $? ]; then
    echo "Unit tests failed."
    exit 1
fi
%endif

%install
# make DESTDIR=%%{buildroot} docdir=%%{crmsh_docdir} install
%if 0%{?suse_version}
%python3_pyproject_install
%else
%pyproject_install
%endif

# additional directories
install -d -m0770 %{buildroot}%{_localstatedir}/cache/crm
install -d -m0770 %{buildroot}%{_localstatedir}/log/crmsh
install -d -m0755 %{buildroot}%{_tmpfilesdir}

# install configuration
install -Dm0644 -t %{buildroot}%{_sysconfdir}/crm etc/{crm.conf,profiles.yml}
install -m0644 %{SOURCE1} %{buildroot}%{_tmpfilesdir}/%{name}.conf

# install manpages
install -Dpm0644 -t %{buildroot}%{_mandir}/man8 doc/*.8
install -Dpm0644 -t %{buildroot}%{_datadir}/crmsh/ doc/crm.8.adoc

# install data
for d in $(cat data-manifest); do
	if [ -x $d ] ; then mode="0755" ; else mode="0644" ; fi
	install -D -m $mode $d %{buildroot}%{_datadir}/crmsh/$d
done
mv %{buildroot}%{_datadir}/crmsh/test{,s}
install -p test/testcases/xmlonly.sh \
	%{buildroot}%{_datadir}/crmsh/tests/testcases/configbasic-xml.filter

install -Dm0644 contrib/bash_completion.sh \
	%{buildroot}%{_datadir}/bash-completion/completions/crm

if [ -f %{buildroot}%{_bindir}/crm ]; then
	install -Dm0755 %{buildroot}%{_bindir}/crm %{buildroot}%{_sbindir}/crm
	rm %{buildroot}%{_bindir}/crm
fi

%if 0%{?suse_version}
%fdupes %{buildroot}
%endif

%post
%tmpfiles_create %{_tmpfilesdir}/%{name}.conf

%if %{with regression_tests}
# Run regression tests after installing the package
# NB: this is called twice by OBS, that's why we touch the file
%post test
testfile=`mktemp -t .crmsh_regression_tests_ran_XXXXXX`
# check if time in file is less than 2 minutes ago
if [ -e $testfile ] && [ "$(( $(date +%s) - $(cat $testfile) ))" -lt 120 ]; then
	echo "Skipping regression tests..."
	exit 0
fi
# write current time to file
rm -f "$testfile"
echo "$(date +%s)" > "$testfile"
%{_datadir}/%{name}/tests/regression.sh
result1=$?
cd %{_datadir}/%{name}/tests
./cib-tests.sh
result2=$?
[ $result1 -ne 0 ] && (echo "Regression tests failed."; cat ${buildroot}/crmtestout/regression.out)
[ $result2 -ne 0 ] && echo "CIB tests failed."
[ $result1 -eq 0 -a $result2 -eq 0 ]
%endif

%files
###########################################################
%defattr(-,root,root)

%{_sbindir}/crm
%{python3_sitelib}/crmsh*

%{_datadir}/%{name}
%exclude %{_datadir}/%{name}/tests
%exclude %{_datadir}/%{name}/scripts

%{_tmpfilesdir}/%{name}.conf

%doc doc/*.html
%doc COPYING AUTHORS ChangeLog README.md
%doc contrib/*
%{_mandir}/man8/*

%config %{_sysconfdir}/crm

%dir %attr (770, %{uname}, %{gname}) %{_var}/cache/crm
%dir %attr (770, %{uname}, %{gname}) %{_var}/log/crmsh
%{_datadir}/bash-completion/completions/crm

%files scripts
%defattr(-,root,root)
%{_datadir}/%{name}/scripts

%files test
%defattr(-,root,root)
%{_datadir}/%{name}/tests

%changelog
* Mon Mar 24 2025 zzhou@suse.com
- Update to version 5.0.0+20250324.9041399d:
  * Dev: behave: add functional test cases for previous changes
  * minor refactors
  * Dev: pre-migration: add checks for deprecated resource agents (jsc#PED-11808)
  * Dev: pre-migration: update the unsupported list
  * Dev: pre-migration: check lsb or service resource agents (jsc#PED-11808)
  * Dev: pre-migration: use a unsupported list instead of supported list (jsc#PED-11808)
* Mon Mar 24 2025 nicholas.yang@suse.com
- Update to version 5.0.0+20250324.b5d78d9b:
  * Dev: Dockerfile: Install sudo explicitly
  * Dev: ui_corosync: fix completer for link remove
* Fri Mar 21 2025 XLiang@suse.com
- Update to version 5.0.0+20250321.dd765c54:
  * Dev: testcases: Udate testcases for previous commit
  * Dev: doc: Update the default value of <heartbeat_dir> in the documentation
  * Dev: ui_resource: Refactor do_trace function
* Thu Mar 20 2025 XLiang@suse.com
- Update to version 5.0.0+20250321.169fb42c:
  * Update crmsh/idmgmt.py
  * Dev: behave: Add functional test for previous commit
  * Fix: idmgmt: Replace hashtag('#') with point('.') in id (bsc#1239782)
* Wed Mar 19 2025 XLiang@suse.com
- Update to version 5.0.0+20250319.39f5be9f:
  * Dev: testcases: Adjust original testcases for previous changes
  * Dev: cibverify: Print output of crm_verify directly
* Wed Mar 19 2025 XLiang@suse.com
- Update to version 5.0.0+20250319.96e9d2ea:
  * Fix: doc: fix a minor syntax error
* Tue Mar 18 2025 XLiang@suse.com
- Update to version 5.0.0+20250318.919ea162:
  * Dev: testcases: Adjust original testcases under python3.13
  * Dev: behave: const: Update output of argparse metavar under python3.13
  * Dev: run-functional-tests: Stop redirecting the build output to /dev/null
  * Dev: unittests: Add python 3.13 for unit tests
  * Dev: Dockerfile: Update python package version to 3.13
* Sat Mar 15 2025 XLiang@suse.com
- Update to version 5.0.0+20250315.4985e9fd:
  * Dev: Replace 'Master/Slave' with 'Promoted/Unpromoted' in multiple files
  * Dev: scripts: Use promotable clone instead of ms command
  * Dev: unittests: Adjust unit test for previous commit
  * Dev: ui_configure: Remove 'ms' sub-command (jsc#PED-8231)
* Fri Mar 14 2025 XLiang@suse.com
- Update to version 5.0.0+20250314.a0f51f29:
  * Dev: behave: Add test case for 'configure upgrade' command
* Fri Mar 14 2025 XLiang@suse.com
- Update to version 5.0.0+20250314.ba91f946:
  * Dev: ui_configure: Enable -F option for 'configure upgrade'
  * Dev: doc: Mention that 'configure upgrade' supports -F option
* Wed Mar 12 2025 XLiang@suse.com
- Update to version 5.0.0+20250312.ee7aaf45:
  * Dev: migration: minor refines in message wording
  * Refactor: migration: extract a function _migrate_totem_interface (jsc#PED-8252)
  * Refactor: cibquery: extract a function to get cluster nodes without side effects (jsc#PED-8252)
  * Dev: migration: fix incorrect bindnetaddr when migrating a multicast cluster (jsc#PED-8252)
  * Fix: migration: IndexError when there is only one interface (jsc#PED-8252)
  * Dev: migration: refine the message about unsupported component version (jsc#PED-8252)
  * Dev: migration: add a message about corosync.conf.bak (jsc#PED-82582)
  * Fix: migration: should not report need migration when the cluster has some non-fatal problems which need manual fix (jsc#PED-8252)
  * Dev: migration: no need to check if cluster services is stopped (jsc#PED-8252)
  * Dev: migration: add a checker for cib schema version (jsc#PED-8252)
  * Dev: migration: split problem level and is_blocker (jsc#PED-8252)
  * Dev: migration: check if the cluster is already migrated to SLES 16 (jsc#PED-8252)
  * Fix: migration: should not show pre-migration check summary when called with `--fix` (jsc#PED-8252)
  * Dev: behave: add functional tests for pre-migration checks (jsc#PED-8252)
  * Dev: migration: do not check pacemaker version (jsc#PED-8252)
  * Dev: migration: refine message wording (jsc#PED-11808)
  * Dev: pre-migration: add summary section to output (jsc#PED-11808)
  * Refactor: cibquery: has_primitive_filesystem_ocfs2 to has_primitive_filesystem_with_fstype
  * Fix: cibquery: grouped primitives is missing from query results (jsc#PED-11808)
  * Doc: ui_cluster: add document for `crm cluster health hawk2|sles16`
  * Dev: pre-migration: add message about removing stonith:external/sbd (jsc#PED-11808)
  * Fix: ui_cluster: fix do_health usage output
  * Dev: pre-migration: add completer for 'crm cluster health sles16' (jsc#PED-11808)
  * Dev: pre-migration: do not colorize hostname header (jsc#PED-11808)
  * Dev: add pre-migration checks for pacemaker version (jsc#PED-11808)
  * Dev: pre-migration: check if ocfs2 is used (jsc#PED-11808)
  * Dev: pre-migration: check removed fence agents (jsc#PED-11808)
  * Dev: pre-migration: check removed resource agents (jsc#PED-11808)
  * Dev: pre-migration: check SAPHanaSR Classic resource agents (jsc#PED-11808)
  * Dev: pre-migration: add checks for used corosync features (jsc#PED-11808)
  * Dev: migration: copy migrated corosync.conf to remote nodes (jsc#PED-8252)
  * Dev: migration: run checks on remote nodes (jsc#PED-8252)
  * Dev: prun: create event loop manually
  * Dev: ui_cluster: add 'crm cluster health sles [--fix]' (jsc#PED-8252)
  * Dev: profiles: set default crypto_hash to sha256 to follow corosync default
  * Dev: migration: implement multicast to knet migration (jsc#PED-8252)
  * Fix: corosync: use os.env instead of os.getenv for consistency (bsc#1205925)
  * Dev: migration: populate node name in corosync node list for knet multilink (jsc#PED-8252)
  * Dev: migration: implement corosync.conf migration for corosync 3 (jsc#PED-8252)
* Wed Mar 12 2025 XLiang@suse.com
- Update to version 5.0.0+20250312.e90df9c5:
  * Dev: unittests: Adjust unit test for previous commit
  * Dev: utils: Ignore config.core.OCF_1_1_SUPPORT option
  * Dev: etc: Drop OCF_1_1_SUPPORT option in crm.conf (jsc#PED-8550)
* Tue Mar 11 2025 XLiang@suse.com
- Update to version 5.0.0+20250311.9e0cd40b:
  * Dev: ssh_key: more robust error handling in KeyFileManager (bsc#1239084)
* Mon Mar 10 2025 XLiang@suse.com
- Update to version 5.0.0+20250310.bab2cdb3:
  * Dev: doc: Update the doc of 'configure upgrade' command
  * Dev: ui_configure: Improve 'configure upgrade' command
* Thu Mar  6 2025 XLiang@suse.com
- Update to version 5.0.0+20250306.0f77021d:
  * Fix: Makefile.am: uninstall-local and clean-local targets
  * Makefile.am: add uninstall-hook target to clean up data files
* Mon Mar  3 2025 XLiang@suse.com
- Update to version 5.0.0+20250303.149f5b77:
  * Dev: utils: Add parentheses to if else statements
  * Dev: behave: Sync dlm ra name in ocfs2 and gfs2 test cases
  * Dev: cluster_fs: Use 'dlm-controld-ra' as the default dlm ra name
* Fri Feb 28 2025 XLiang@suse.com
- Update to version 5.0.0+20250228.f1101e77:
  * Dev: unittests: Adjust unit test for previous commit
  * Dev: Add error log when cluster services fail to start
* Tue Feb 18 2025 XLiang@suse.com
- Update to version 5.0.0+20250218.87655e09:
  * Dev: behave: Add test case for schema change
  * Dev: doc: Improve documentation for `configure schema` command
  * Dev: ui_configure: Get schema statically when cluster is not running
  * Dev: schema: Make sure schema changed after setting new schema by `configure schema`
* Mon Feb 17 2025 nicholas.yang@suse.com
- Update to version 5.0.0+20250217.8bb3232e:
  * Dev: unittest: Remove or replace stonith:null and stonith:ssh
  * Dev: testcases: Adjust original test cases to match pacemaker-3
  * Dev: ui_cib: crm_shadow reset requires '--force' option
  * Fix: ci: test container image build failure in tumbleweed
* Wed Feb 12 2025 XLiang@suse.com
- Update to version 5.0.0+20250212.e63ac0bf:
  * Dev: unittests: Adjust unit test for previous commit
  * Dev: doc: Drop the syntax mention of '@<id>:name' in crm.8.adoc
  * Dev: Improve options of 'crm status' command (jsc#PED-8231)
  * Dev: constants: Drop deprecated 'restart-type' resource option (jsc#PED-8231)
  * Dev: Drop unsupported 'moon' in date_spec (jsc#PED-8231)
  * Dev: Remove deprecated cibadmin --local option (jsc#PED-8231)
  * Dev: crash_test.utils: Drop deprecated 'poweroff' value of 'stonith-action' option (jsc#PED-8231)
  * Dev: constants: Drop deprecated "crmd-integration-timeout" and "crmd-finalization-timeout" (jsc#PED-8231)
  * Dev: utils: Make change since 'crmd-transition-delay' already renamed to 'transition-delay' (jsc#PED-8231)
  * Dev: bootstrap: Drop 'record-pending' operation option (jsc#PED-8231)
* Mon Feb 10 2025 XLiang@suse.com
- Update to version 5.0.0+20250210.db3e9f28:
  * Dev: Add cancel option when confirming to commit for the pending changes
* Mon Feb 10 2025 XLiang@suse.com
- Update to version 5.0.0+20250210.5c190a8d:
  * Dev: unittests: Adjust unit test for previous commit
  * Fix: sbd: Detect if sbd package is missing on peer nodes
* Sat Feb  8 2025 XLiang@suse.com
- Update to version 5.0.0+20250208.0b368d36:
  * Dev: Refactor: Introduce custom sort order enable/disable functions
  * Dev: ui_configure: Add completer for 'configure schema' command
  * Revert "Fix: ui_context: Don't complete for unknown argument"
* Fri Feb  7 2025 XLiang@suse.com
- Update to version 5.0.0+20250207.bbfaace1:
  * Dev: Replace "stonith:external/<agent>" to fence_agents in multiple places (jsc#PED-8733)
* Fri Feb  7 2025 XLiang@suse.com
- Update to version 5.0.0+20250207.7601cb12:
  * Fix: bootstrap: Local joining node should be included when merging known_hosts (bsc#1229419)
* Thu Feb  6 2025 XLiang@suse.com
- Update to version 5.0.0+20250206.325350ba:
  * Dev: unittests: Adjust unit test for previous commit
  * Dev: bootstrap: Check if core packages like corosync/pacemaker are installed
* Thu Jan 23 2025 XLiang@suse.com
- Update to version 5.0.0+20250123.155bd2c2:
  * Dev: unittests: Adjust unit test for previous commit
  * Fix: sbd: Check if fence_sbd command exists before initializing device (bsc#1236184)
  * Dev: unittests: Adjust unit test for previous commit
  * Fix: report: Check if mounted.ocfs2 command exists before using it (bsc#1236220)
  * Dev: unittests: Adjust unit test for previous commit
  * Dev: sbd: Remove the 'devices' parameter for fence_sbd agent
* Mon Jan 20 2025 XLiang@suse.com
- Update to version 5.0.0+20250120.024e86c6:
  * Fix: ui_context: Don't complete for unknown argument
  * Fix: ui_context: Don't complete for unknown command
* Fri Jan 17 2025 XLiang@suse.com
- Update to version 5.0.0+20250117.dddbde52:
  * Dev: behave: Adjust functional test for previous commit
  * Dev: bootstrap: Option -N should require option -y
* Thu Jan 16 2025 XLiang@suse.com
- Update to version 5.0.0+20250116.32f6a518:
  * Dev: unittests: Adjust unit test for previous commit
  * Fix: report: Check corosync.service status before querying quorum status (bsc#1235930)
* Mon Jan  6 2025 XLiang@suse.com
- Update to version 5.0.0+20250106.9dcea10f:
  * Dev: unittests: Remove duplicated test case
* Fri Jan  3 2025 XLiang@suse.com
- Update to version 5.0.0+20250103.44145ae9:
  * Dev: unittests: Adjust unit test for previous commit
  * Fix: bootstrap: Improve sync_files_to_disk function (bsc#1219537)
* Thu Jan  2 2025 XLiang@suse.com
- Update to version 5.0.0+20250102.150f4c85:
  * Fix: unittest: rename TestPrinter to UnitTestPrinter
* Thu Jan  2 2025 XLiang@suse.com
- Update to version 5.0.0+20250102.24021985:
  * Dev: unittests: Rewrite test_findln_by_timestamp by using fixed date
* Mon Dec 30 2024 XLiang@suse.com
- Update to version 5.0.0+20241230.14da5227:
  * Dev: ra: Drop legacy code to get metadata of the pacemaker daemons
* Mon Dec 30 2024 XLiang@suse.com
- Update to version 5.0.0+20241230.aae750fc:
  * Dev: doc: Update crm.8.adoc
  * Dev: ui_configure: Print all properties if no property is specified
  * Dev: help: Support '--help' option for cluster properties (jsc#PED-11860)
* Wed Dec 25 2024 XLiang@suse.com
- Update to version 5.0.0+20241225.66a75d1d:
  * Dev: unittests: Add unit test for previous commit
  * Dev: report: Support crm report to collect GFS2 information
  * Dev: behave: Add functional test for GFS2
  * Dev: bootstrap: add gfs2 stage functionality (Technical Preview) (jsc#PED-11709)
  * Dev: Rename ocfs2.py as cluster_fs.py
  * Revert "Dev: ocfs2: Drop support for configuring ocfs2 (jsc#PED-11038)"
  * Revert "Dev: behave: Adjust functional tests for previous commit"
  * Revert "Dev: report: Remove unused function dump_D_process"
* Tue Dec 17 2024 XLiang@suse.com
- Update to version 5.0.0+20241217.562ce848:
  * Dev: utils: Change `get_dc` function as the behavior of `crmadmin -D` changed
  * Dev: doc: Add examples for the 'failcount' command
  * Dev: behave: Adjust functional test for previous commit
  * Dev: ui_resource: Refine 'do_failcount' function
* Mon Dec  9 2024 XLiang@suse.com
- Update to version 5.0.0+20241209.20981523:
  * Dev: unittests: Adjust unit test for previous commit
  * Dev: report: Remove unused function dump_D_process
  * Dev: report: Handle collect files with the same name
  * Dev: report: Add ~/.config/crm/crm.conf to the list of collected files
* Wed Dec  4 2024 XLiang@suse.com
- Update to version 5.0.0+20241204.e1006f33:
  * Dev: unittests: Adjust unit test for previous commits
  * Dev: ui_sbd: Don't show stonith-watchdog-timeout for disk-based SBD
  * Dev: sbd: Delete stonith-watchdog-timeout property when configuring
  * Dev: sbd: Remove sbd delay start related diretories when running sbd purge
  * Dev: Don't set and show SBD_WATCHDOG_TIMEOUT for disk-based SBD
  * Dev: ui_sbd: Adjust output of `sbd status`
  * Dev: ui_sbd: Adjust sbd configure subcommand
  * Dev: ui_sbd: Print sbd cmdline content in `sbd status` command
  * Dev: sbd: Split get_sbd_device_interactive into smaller functions
  * Dev: behave: Add sbd_ui.feature to test the crm sbd UI
  * Dev: doc: Upadate crm.8.adoc for SBD help text
  * Dev: ui_sbd: Replace 'sbd disable' as 'sbd purge'
  * Dev: sh: Add get_rc_output_without_input in ClusterShell
  * Dev: sbd: Move constants.SHOW_SBD_START_TIMEOUT_CMD to sbd.py
  * Dev: ui_sbd: Check if node is reachable when getting the node list
  * Dev: ui_sbd: Reuse sbd.SBDManager.restart_cluster_if_possible
  * Dev: bootstrap: Add a log info when starting pacemaker.service
  * Dev: ui_sbd: Check if the adding device is already initialized
  * Dev: ui_sbd: Adjust sbd confiure interface
  * Dev: ui_sbd: Replace sbd remove as sbd disable sub-command
  * Dev: ui_sbd: Add sbd device sub command
  * Dev: ui_sbd: No need to specify device="" when trying to modify properties under diskless sbd
  * Dev: report: Dump output of 'crm sbd configure show' and 'crm sbd status' to the report result
  * Dev: Refactor the code to avoid circular import
  * Dev: ui_sbd: Refactor do_status method
  * Dev: bootstrap: Check if sbd package is installed in the right place
  * Dev: ui_sbd: Minor changes to the code
  * Dev: ui_sbd: Clean up existing fence_sbd resource before configure diskless SBD
  * Dev: ui_sbd: Update regex for parsing SBD device by partlabel
  * Dev: ui_sbd: Catch both stderr and stdout for crm resource status
  * Dev: ui_sbd: No need to consider static case when calling crm configure show
  * Dev: ui_sbd: Add property/sysconfig section header for sbd configure show
  * Dev: doc: Add help info for crm sbd sublevel
  * Dev: behave: Adjust functional test for previous changes
  * Dev: ui_sbd: Add new 'crm sbd' sublevel (jsc#PED-8256)
  * Dev: utils: Introduced `detect_duplicate_device_path` function in utils
* Wed Nov 27 2024 XLiang@suse.com
- Update to version 5.0.0+20241127.3e90e46f:
  * Fix: report: Fix a regression for irregular file collection
* Mon Nov 25 2024 XLiang@suse.com
- Update to version 5.0.0+20241125.ae21432f:
  * Dev: unittests: Adjust unit test for previous commit
  * Dev: bootstrap: Remove import_ssh_key function
  * Dev: unittests: Adjust unit test for previous commits
  * Dev: ssh_key: Split fetch_public_key_list into two functions
  * Dev: bootstrap: Improve shell script in generate_ssh_key_pair_on_remote
  * Dev: bootstrap: Reuse AuthorizedKeyManager to add key to authorized_keys
  * Dev: bootstrap: Adjust the docstring of configure_ssh_key function
  * Dev: bootstrap: Change the parameter name in swap_public_ssh_key function
  * Dev: bootstrap: Avoid hardcoding the ssh key type as RSA
  * Dev: ssh_key: Avoid hardcoding the ssh key type as RSA
  * Dev: utils: Avoid hardcoding the ssh key type as RSA
* Sat Nov 23 2024 XLiang@suse.com
- Update to version 5.0.0+20241123.9b1d80fb:
  * Fix: behave: systemd bpf-restrict-fs fails in opensuse tumbleweed
* Fri Nov 22 2024 nicholas.yang@suse.com
- Update to version 5.0.0+20241122.37cd25b6:
  * Dev: behave: add CAP_SYS_ADMIN to container for systemd hardening
* Wed Nov 13 2024 XLiang@suse.com
- Update to version 5.0.0+20241113.0af43cf2:
  * unused code removal
  * Dev: bootstrap: more robust implementation for ssh_merge (bsc#1230530)
* Mon Nov 11 2024 XLiang@suse.com
- Update to version 5.0.0+20241111.a27e5ec8:
  * Fix: log: The report DEBUG log message is not displayed in the log file
* Fri Nov  8 2024 XLiang@suse.com
- Update to version 5.0.0+20241108.a052c25d:
  * Dev: unittests: Adjust unit test for previous commit
  * Dev: report.utils: For a sequence of archived log files, check the modify time
  * Fix: report.utils: Fix the performance issue (bsc#1232821)
  * Dev: report.utils: Add debug info for the log file types
  * Fix: report.collect: Make sure the log is not None before using it (bsc#1232821)
* Wed Nov  6 2024 XLiang@suse.com
- Update to version 5.0.0+20241106.ec9b843c:
  * Dev: github-actions: rebuild the test container image weekly
* Mon Nov  4 2024 XLiang@suse.com
- Update to version 5.0.0+20241104.3da03cd4:
  * Fix: pylint: fix string literal problems
  * Dev: add pylint to check ill-formated string literals
  * Dev: test_container: end knet 1.29 staging
  * Dev: github: add a workflow to build test container image
* Mon Nov  4 2024 nicholas.yang@suse.com
- Update to version 5.0.0+20241104.4972fadc:
  * Fix: Python 3.12: SyntaxWarning: invalid escape sequence
* Tue Oct 29 2024 XLiang@suse.com
- Update to version 5.0.0+20241029.917b0d91:
  * Dev: bootstrap: Refine remote_auth stage
* Tue Oct 29 2024 XLiang@suse.com
- Update to version 5.0.0+20241029.8adcb7c4:
  * README.md: use crmsh-cd as build status badge
* Mon Oct 28 2024 XLiang@suse.com
- Update to version 5.0.0+20241028.94635ab9:
  * Fix: behave: AppArmor profile "podman" specified but not loaded in opensuse tumbleweed
  * Fix: scripts: health: failed to extract report when it is compressed in bz2
  * Fix: behave: apply apparmor profile 'podman' if apparmor is enabled
  * Dev: beahve: refine messages in the test runner script
  * Dev: test_container: replace iptables with iptables-nft (#1572)
  * Dev: behave: adjust test cases for podman network config (#1572)
  * Fix: behave: adapt to podman network config (#1572)
  * Fix: behave: add CAP_NET_ADMIN for firewall (#1572)
  * Dev: behave: simplify container cleanup (#1572)
  * Dev: github-actions: remove docker related configurations (#1572)
  * Fix: behave: use jq to parse container network metadata (#1572)
  * Dev: github-actions: run functional test script as root
  * Dev: behave: use unprivileged podman containers instead of privileged docker containers (#1572)
  * Fix: testcases: adapt to pacemaker updates
  * use knet-1.29 image
  * Fix: hahealth: return fail when report failed (bsc#1231840) (#1589)
* Fri Oct 25 2024 XLiang@suse.com
- Update to version 5.0.0+20241025.e3d8b015:
  * Dev: behave: Adjust functional tests for previous commit
  * Dev: unittests: Adjust unit test for previous commit
  * Dev: ocfs2: Drop support for configuring ocfs2 (jsc#PED-11038)
* Fri Oct 11 2024 XLiang@suse.com
- Update to version 5.0.0+20241011.05736903:
  * Dev: behave: Adjust functional test for previous commit
  * Fix: cibconfig: Disable auto add advise values for operations (bsc#1231386)
* Wed Oct  9 2024 XLiang@suse.com
- Update to version 5.0.0+20241009.6e8ba2a7:
  * Fix: ui_cluster: Stop renaming cluster name when using qdevice
* Fri Sep 27 2024 XLiang@suse.com
- Update to version 5.0.0+20240927.113b2113:
  * Dev: unittest: Adjust unit test for previous commit
  * Dev: behave: Adjust functional test for previous commit
  * Dev: utils: Check node is reachable by using both ping and ssh
* Fri Sep 27 2024 XLiang@suse.com
- Update to version 5.0.0+20240927.3727fc0c:
  * Fix: help: crm help <topic> does not work (#1567)
* Fri Sep 27 2024 XLiang@suse.com
- Update to version 5.0.0+20240927.e5c5acf8:
  * Dev: report: do not capture stderr when unarchiving tarballs
  * Dev: report: make error messages easier to parse for hawk2 (bsc#1228899)
  * Fix: report: find_shell should accept hacluster user (bsc#1228899)
* Thu Sep 26 2024 XLiang@suse.com
- Update to version 5.0.0+20240926.93245958:
  * Dev: healthcheck: Enhace log clarity
  * Dev: ui_cluster: Change the completer for crm cluster health
* Tue Sep 24 2024 XLiang@suse.com
- Update to version 5.0.0+20240924.685cf0a1:
  * Fix: command: `do_help` does not work as a 3rd level subcommand
  * Dev: report: add a reminder to use `crm cluster health` (bsc#1228899)
  * Dev: behave: add functional tests for previous changes
  * Dev: ui_cluster: add a reminder to use "crm cluster init/join ssh" to initialize ssh (bsc#1228899)
  * Dev: scripts: add a reminder to use `crm cluster health` to fix hacluster passwordless ssh authentication (bsc#1228899)
  * Dev: scripts: generate readable messages when ssh authentication fails (bsc#1228899)
  * Fix: report: should not try interactive authentication when stdin is not a tty (bsc#1228899)
  * Dev: behave: remove unused functional tests
  * Dev: main: remove upgradeutil (bsc#1228899)
* Fri Sep 20 2024 XLiang@suse.com
- Update to version 5.0.0+20240920.c4ce88eb:
  * Fix: bootstrap: check is_nologin more robustly (bsc#1228251)
  * Dev: unittests: Adjust unit test for previous commit
  * Dev: completers: Reuse node completer for cluster remove and health
  * Dev: bootstrap: Enhance log clarity during crm cluster remove process
* Mon Sep  9 2024 XLiang@suse.com
- Update to version 5.0.0+20240909.28abc7cb:
  * Dev: utils: Catch PermissionError when reading files
* Mon Sep  9 2024 XLiang@suse.com
- Update to version 5.0.0+20240909.1d497d0c:
  * Fix: ui_corosync: should raise LinkArgumentParser.SyntaxException when fails to validate linknumber (#1546)
  * Fix: corosync: should validate linknumber (#1546)
  * Fix: doc: fix broken links in crm.8.adoc (#1546)
* Fri Sep  6 2024 nicholas.yang@suse.com
- Update to version 5.0.0+20240906.af151668:
  * Dev: ui_corosync: use corosync-cfgtool instead of corosync-cmaptool to retreive link status (jsc#PED-8083)
  * Dev: ui_corosync: reject to remove a link if removing it breaks the cluster (jsc#PED-8083)
  * Dev: corosync: allow linknumber not to start with 0
  * Dev: ui_corosync: refine the error messages for missing or duplicated nodes (jsc#PED-8083)
  * Dev: ui_corosync: sync and reload corosync.conf after changes (jsc#PED-8083)
  * Dev: ui_corosync: refactor to reuse configuration loading and saving code
  * Dev: bootstrap: refactor to reuse KNET_LINK_NUM_LIMIT from corosync module
  * Dev: corosync: add the list of updatable options in the error message when an not updatable option is specified
  * Fix: ui_corosync: should not allow empty option values when adding new links
  * Dev: docs: add documents for `crm corosync link`
  * Dev: behave: add funtional tests for 'crm corosync link ...'
  * Fix: corosync: does not detect last link correctly
  * Dev: corosync_config_format: sort keys to put `ringX_addr`s together (jsc#PED-8083)
  * Dev: ui_corosync: print a message when running link update without any arguement
  * Fix: ui_corosync: should detect unconfigured addresses when adding/updating links
  * Fix: corosync: show detect duplicated addresses when adding/updating links
  * Dev: ui_corosync: add subcommand 'crm corosync link add' (jsc#PED-8083)
  * Dev: corosync: implement adding links (jsc#PED-8083)
  * Dev: corosync: implement removing links (jsc#PED-8083)
  * Dev: corosync: implement updating node addresses (jsc#ped-8083)
  * unused code removal
  * Dev: ui_corosync: add subcommand 'crm corosync link update' (jsc#PED-8083)
  * minor code cleanup
  * Dev: corosync: implement updating link options (jsc#PED-8083)
  * minor code cleanup
  * Dev: ui_corosync: add subcommand 'crm corosync link show' (jsc#PED-8083)
  * Dev: corosync: implement collecting link info from config (jsc#PED-8083)
  * Dev: corosync: refactor COROSYNC_KNOWN_SEC_NAMES_WITH_LIST
* Fri Sep  6 2024 XLiang@suse.com
- Update to version 5.0.0+20240906.6f44c708:
  * Refactor: help: rename HelpEntry.long to HelEntry.long_help
  * Dev: help: capture error messages when `--help` fails rather
  * Fix: help: should retrieve help for intermediate levels from _COMMAND_TREE
  * Fix: help: append subcommand list to long descriptions
  * Dev: help: add support for subcommand aliases
  * Dev: help: multilevel subcommand tree rendering in help_overview()
  * Dev: command: adapt annotation `command.help` to multilevel help
  * Dev: help: use tree struture to store the help of subcommands
  * Dev: help: replace seperator '_' in anchors with '.'
  * Dev: help: refactor HelpEntry to put lazy loading implementation to a separated subclass
  * Dev: ui_node: Improve command 'clearstate <node>'
* Wed Sep  4 2024 XLiang@suse.com
- Update to version 5.0.0+20240904.9aed74c9:
  * Dev: Rename variables to make them look like boolean type
  * Dev: run-functional-tests: Add 'fa_advised_op_values = yes' option for origin functional tests
  * Dev: Rename the option 'add_advised_op_values' to 'ra_advised_op_values'
  * Dev: Add a new internal flag to control auto add time units on operation
  * Fix: Add a new option 'fa_advised_op_values' (bsc#1228858)
* Tue Sep  3 2024 XLiang@suse.com
- Update to version 5.0.0+20240903.6c0ffe2a:
  * Dev: behave: Add functional test for previous commit
  * Dev: utils: Load CIB_file env before some readonly commands
  * Dev: behave: Adjust functional test for previous commit
  * Dev: unittests: Adjust unit test for previous commit
  * Fix: utils: Stop providing the detailed and precise sudoer rules to "hack" the privilege (bsc#1229093)
* Mon Sep  2 2024 XLiang@suse.com
- Update to version 5.0.0+20240902.62399591:
  * Dev: behave: Add functional test for ssh blocking case
  * Dev: unittests: Adjust unit test for previous commit
  * Fix: report: When 'core.no_ssh' set to 'yes', crm report works in local mode (bsc#1228899)
  * Fix: upgradeutil: Immdiately return if config.core.no_ssh is set (bsc#1228899)
  * Fix: ui_cluster: Handle 'crm cluster start --all' command (bsc#1228899)
  * Fix: ui_cluster: Handle 'crm cluster stop --all' command (bsc#1228899)
  * Fix: utils: Define utils.NoSSHError exception and ssh wrapper function (bsc#1228899)
  * Fix: config: Add 'core.no_ssh' option (bsc#1228899)
* Fri Aug 30 2024 XLiang@suse.com
- Update to version 5.0.0+20240830.951595de:
  * Fix: bootstrap: drop environ SSH_AUTH_SOCK before checking passwordless ssh when it is not enabled (bsc#1228950)
  * Fix: bootstrap: should check if sudo is available when running `cluster join -c` with a non-root destination user (bsc#1228950)
  * Fix: bootstrap: should check if sudo is available when running `cluster init -N` with a non-root destination user (bsc#1228950)
* Thu Aug 29 2024 XLiang@suse.com
- Update to version 5.0.0+20240829.d528f3b2:
  * Dev: behave: update functional tests for previous changes
  * Fix: completers: deferring calls to crm_mon until envsetup() is called (bsc#1228271)
  * Fix: utils: allow haclient group to use cluster level commands (bsc#1228271)
  * Fix: scripts: call commands as current user when running as hacluster (bsc#1228271)
  * Fix: prun: allow pcopy_to_remote to use intercept (bsc#1228271)
* Thu Aug 29 2024 XLiang@suse.com
- Update to version 5.0.0+20240829.9e723030:
  * Dev: behave: Add functional test for previous commit
  * Fix: Don't add time units to values for existing CIB (bsc#1228817)
  * Dev: unittest: Adjust unit test for previous commit
  * Fix: utils: group check failure when os.getgroups() returns empty (bsc#1229030)
* Mon Aug 26 2024 XLiang@suse.com
- Update to version 5.0.0+20240826.84fcb728:
  * Dev: unittests: Add unit tests for pickling CommandFailure
  * Dev: unittests: Adjust unit test for previous commit
  * Dev: sh: Ensure CommandFailure Exception is Picklable Across Processes (bsc#1229686)
  * Fix: report: Error output of crm_verify should be recorded in report result (bsc#1229686)
* Thu Aug 22 2024 XLiang@suse.com
- Update to version 5.0.0+20240822.9ee6ca4d:
  * Revert "Dev: doc: Add deprecated note for 'crm configure erase'"
  * Revert "Dev: ui_configure: Deprecate configure erase sub-command" (bsc#1228713)
* Mon Aug 12 2024 XLiang@suse.com
- Update to version 5.0.0+20240812.49aeacfa:
  * Dev: Add option core.add_advised_op_values, default value is 'yes'
  * Dev: Rename variable 'add_default_op_values' to 'add_advised_op_values'
* Tue Aug  6 2024 alex_burlakov@gmx.de
- Update to version 5.0.0+20240806.7e270329:
  * Dev: scripts/health/collect: use ansible to get sysinfo
* Wed Jul 31 2024 XLiang@suse.com
- Update to version 5.0.0+20240731.2abacf27:
  * Dev: crm_rpmcheck: use ansible to get package versions
  * Fix: ui_context: enter_level() should not check requirements for non-functional subcommands
* Tue Jul 23 2024 XLiang@suse.com
- Update to version 5.0.0+20240723.68039940:
  * Dev: prun: replace deprecated stdlib API asyncio.get_event_loop()
  * unused code removal
  * Dev: ui_cluster: refactor Cluster._wait_for_dc()
  * Dev: utils: revert previous changes to get_dc()
  * Dev: utils: rename wait4dc to wait_dc_stable
  * DC lost during wait
* Thu Jul 18 2024 XLiang@suse.com
- Update to version 5.0.0+20240718.3877db63:
  * Dev: qdevice: numbers automatically the steps to generate client certs
  * Dev: prun: add more possible libexec PATH for sftp-server
  * Dev: behave: adjust functional tests for previous commits
  * fix a typo
  * Dev: unittest: adjust unit tests for previous commits
  * Fix: qdevice: config "tls" should accept value "required" (bsc#1227649)
  * Fix: bootstrap: refine the wording in the question asking TLS config for qdevice (bsc#1227649)
  * Fix: qdevice: TLS certs should always be generated for qnetd (bsc#1227649)
* Thu Jul 18 2024 XLiang@suse.com
- Update to version 5.0.0+20240718.b77bc9ed:
  * Dev: Rename variables to distinguish the concept of adding default
  * Dev: behave: Add functional test for rsc_template
  * Fix: cibconfig: Disable complete advised operation values when adding a rsc_template
* Tue Jul 16 2024 XLiang@suse.com
- Update to version 5.0.0+20240716.99f2232d:
  * Dev: github-actions: actions/setup-python@v4 is deprecated
* Tue Jul 16 2024 XLiang@suse.com
- Update to version 5.0.0+20240716.b2d65eba:
  * Fix: hahealth.py script
* Thu Jul 11 2024 XLiang@suse.com
- Update to version 5.0.0+20240711.72c64e62:
  * Dev: behave: Add functional test for previous commit
  * Dev: bootstrap: Use the existing function to query cluster property
  * Dev: Remove crmsh/ordereddict.py
* Thu Jul 11 2024 XLiang@suse.com
- Update to version 5.0.0+20240711.bda8e3da:
  * Fix: cli: loading cib should be a soft depenedency
  * Dev: ui_context: refactor NON_FUNCTIONAL_COMMAND and NON_FUNCTIONAL_OPTIONS
  * Revert changes to `quit` and `up` in ui_context from #1300 (#1466)
  * Fix: cibconfig: do not load cib to check if cib is changed (#1466)
  * Fix: ui_context: crm configure up prompt #1466
  * Dev: ra: Refine RAInfo.params interface to exclude some completion results
  * Dev: ui_context: Don't append space when completion ends with equal sign
  * Dev: ui_configure: Complete required parameters first
* Fri Jun 28 2024 XLiang@suse.com
- Update to version 5.0.0+20240628.3b3d7eeb:
  * Fix: ui_context: crm cluster delete autocompletion #1403 #1460
* Wed Jun 26 2024 nicholas.yang@suse.com
- Update to version 5.0.0+20240626.8f0ed3e4:
  * Dev: testcases: Replace LVM with LVM-activate
  * Dev: testcases: Replace IPaddr with IPaddr2
  * Dev: Dockerfile: Update dockerfile after corosync3 is in the Factory
* Tue Jun 25 2024 nicholas.yang@suse.com
- Update to version 5.0.0+20240625.c6cc5997:
  * Fix: github-actions: should pass secrets to reusable workflows
  * Revert "Fix: codecov: use environ to pass CODECOV_TOKEN (#1472)"
* Tue Jun 25 2024 XLiang@suse.com
- Update to version 5.0.0+20240625.26e3dd24:
  * Dev: unittest: Adjust unit test for previous commit
  * Dev: behave: Adjust functional test for previous commit
  * Dev: sbd: Replace external/sbd as fence_sbd (jsc#PED-8256, jsc#PED-8498)
* Tue Jun 25 2024 XLiang@suse.com
- Update to version 5.0.0+20240625.b1ff9f63:
  * Fix: codecov: use environ to pass CODECOV_TOKEN (#1472)
* Fri Jun 21 2024 XLiang@suse.com
- Update to version 5.0.0+20240621.fe4d011b:
  * Dev: Drop rkt container type in bundle (jsc#PED-5577)
* Thu Jun 20 2024 XLiang@suse.com
- Update to version 5.0.0+20240620.4dcac184:
  * Dev: ui_configure: Remove _keywords interface and unused code
  * Dev: crash_test.utils: Reuse color constants from crmsh.constants
  * Dev: Remove unused code about hb_delnode
* Thu Jun 20 2024 XLiang@suse.com
- Update to version 5.0.0+20240620.4a694b72:
  * Dev: ra: Guess stonith class type when using fence agents
* Mon Jun 17 2024 XLiang@suse.com
- Update to version 5.0.0+20240617.5ab3a5de:
  * Revert "Dev: codecov: ignore crm report module"
  * Dev: coverage: inject coverage with sitecustomize.py in feature tests
* Mon Jun 17 2024 XLiang@suse.com
- Update to version 5.0.0+20240617.30a5a20d:
  * Dev: doc: Adjust doc for deprecated multi-rule within a location constraint
  * Fix: upgradeutil: refine error handling (bsc#1226147, bsc#1223371)
  * Dev: doc: Remove 'moon' from doc
* Fri Jun 14 2024 XLiang@suse.com
- Update to version 5.0.0+20240614.6ce8e96f:
  * Dev: behave: Add corosync_ui.feature to collect test cases for crm corosync ui
  * Dev: ui_corosync: Improve corosync.show and corosync.edit subcommands
* Wed Jun 12 2024 XLiang@suse.com
- Update to version 5.0.0+20240612.f016a26d:
  * Dev: doc: Drop help info of 'configure ms' command
  * Dev: doc: Move 'id-ref' usage into help primitive section
  * Dev: Hide 'configure ms' command from UI (jsc#PED-8550)
* Wed Jun 12 2024 XLiang@suse.com
- Update to version 5.0.0+20240612.49d57d50:
  * Dev: spec: bump python requirement to >= 3.10
  * Dev: workflows: Relace OBS_PROJECT and TARGET_PROJECT with plain text
  * Dev: workflows: Enable submit CD stage for master branch
* Wed Jun 12 2024 XLiang@suse.com
- Update to version 5.0.0+20240612.cd025007:
  * Dev: Dockerfile: Update dockerfile
  * Dev: testcases: Other Adjustments for original testcases
  * Dev: testcases: Remove unknown resource meta attribute
  * Dev: testcases: Apply constraints to the group instead of the grouped resource
  * Dev: testcases: Avoid multiple rule in a location constraint
  * Dev: testcases: Convert 'ms' or 'master' command into promotable clone
* Fri Jun  7 2024 XLiang@suse.com
- Update to version 5.0.0+20240607.92252e3b:
  * Dev: bootstrap: warn about cleartext traffic in corosync
* Thu Jun  6 2024 XLiang@suse.com
- Update to version 5.0.0+20240606.c078907b:
  * Dev: Hide lsb and service resource agent class type from UI and doc (jsc#PED-5577)
* Wed Jun  5 2024 XLiang@suse.com
- Update to version 5.0.0+20240605.622cca25:
  * Dev: ui_resource: Set role as Promoted/Unpromoted when promote/demote (jsc#PED-8550)
  * Dev: unittest: Adjust unit test for previous commit
  * Dev: ui_resource: Improve completers for 'crm resource' command
* Tue Jun  4 2024 XLiang@suse.com
- Update to version 5.0.0+20240604.b5b23f4c:
  * Dev: testcases: Adjust testcases for previous commit
  * Dev: Parsing resource meta attributes dynamically (jsc#PED-8261, jsc#PED-8249)
* Mon Jun  3 2024 XLiang@suse.com
- Update to version 5.0.0+20240603.014eb0cf:
  * Dev: codecov: add codecov badge to README.md
  * Dev: codecov: add flag report in generated comments
  * Dev: codecov: upload unit tests coverage
  * Dev: codecov: add 'integration' flags for integration tests
  * Dev: codecov: remove token from codecov.yml
  * Dev: github-actions: update actions/checkout to v4
  * Dev: github-actions: update host environment to ubuntu 24.04
  * Dev: github-actions: update codevcov-action to v4
  * Fix: codecov: specify token explicitly
* Fri May 31 2024 XLiang@suse.com
- Update to version 5.0.0+20240531.a1e0fb15:
  * Dev: testcases: Adjust original testcases for previous changes
  * Dev: behave: Add functional test about auto convert deprecated roles
  * Dev: config: Set OCF_1_1_SUPPORT to yes (jsc#PED-8550)
* Fri May 31 2024 XLiang@suse.com
- Update to version 5.0.0+20240531.bab7d7e1:
  * Dev: cibconfig: Remove unused code about v1 format of diff, which is deprecated
* Fri May 31 2024 XLiang@suse.com
- Update to version 5.0.0+20240531.c9a83780:
  * Fix: cmd_status: call crm_mon without shell (#1429)
* Tue May 28 2024 XLiang@suse.com
- Update to version 5.0.0+20240528.c723009c:
  * Dev: behave: Adjust functional test for previous changes
  * Dev: bootstrap: Minor refactoring of the get_address_list function
  * Dev: bootstrap: On join side, adjust the condition of comparing the link number
  * Dev: utils: Give valid value list for the -i option when the value is invalid
* Tue May 28 2024 nicholas.yang@suse.com
- Update to version 5.0.0+20240528.d55edf88:
  * Dev: log an error when fencing node without stonith device configured and running
* Mon May 20 2024 XLiang@suse.com
- Update to version 5.0.0+20240520.964151e0:
  * Fix: healthcheck: KeyError when local nodename not found in cib (bsc#1223438)
* Thu May  9 2024 XLiang@suse.com
- Update to version 5.0.0+20240509.ea6db174:
  * Dev: Change the RA name string format (jsc#PED-106)
  * Dev: unittest: Adjust unit test for previous commit
  * Dev: utils: Add info when property is newly added
* Wed May  8 2024 XLiang@suse.com
- Update to version 5.0.0+20240508.ec25d367:
  * Dev: unittest: Adjust unit test for previous commit
  * Dev: corosync_config_format: Enable to parse comments
  * Dev: corosync_config_format: Add new line between sections
* Mon May  6 2024 XLiang@suse.com
- Update to version 5.0.0+20240506.8f4bef4a:
  * Dev: Drop nagios related code, the help text, and the man page (jsc#PED-8259, jsc#PED-8232)
  * Fix: bootstrap: open corosync ports in firewalld
  * Dev: unittest: Adjust unit test for previous commit
  * Dev: Drop SuSEfirewall2 support
* Tue Apr 30 2024 XLiang@suse.com
- Update to version 5.0.0+20240430.42ad4f1e:
  * Dev: corosync: Show corosync cpg status in `crm corosync status cpg`
* Tue Apr 30 2024 XLiang@suse.com
- Update to version 5.0.0+20240430.c840652f:
  * Dev: doc/website-v1: update man-4.6 (#1409)
  * Fix: doc/toolchain: fix missing anchor in generated AIO doc (#1409)
* Tue Apr 30 2024 XLiang@suse.com
- Update to version 5.0.0+20240430.6ec5681d:
  * Dev: doc: Don't show the usage of 'crm ra info cluster'
  * Fix: main: Set PATH environment first
  * Dev: bash_completion: Enable complete 'id=' on non-interactive mode
* Mon Apr 29 2024 XLiang@suse.com
- Update to version 5.0.0+20240429.11eff3d0:
  * Dev: corosync: Add corosync.is_valid_corosync_conf function
* Sun Apr 28 2024 XLiang@suse.com
- Update to version 5.0.0+20240428.1a81df0b:
  * Fix: ui_cluster: do_start should parse cmdline args before doing any checks
  * Revert "Fix: corosync: should not raise ValueError when failing to open config file"
  * Dev: ui_context: make help subcommands to exit with 0 (#1374)
  * Fix: corosync: should not raise ValueError when failing to open config file
  * Fix: corosync: ConfigParser.get_all(nonexsistent) should return an empty list
* Sun Apr 28 2024 XLiang@suse.com
- Update to version 5.0.0+20240428.33a59842:
  * Doc: regenerate man-4.6
  * Dev: ui_context: ignore requirements when option --help is specified
* Thu Apr 25 2024 XLiang@suse.com
- Update to version 5.0.0+20240425.1c0f1969:
  * Refactor: corosync: move conf_parser.ConfParser to corosync.ConfParser
  * Dev: ui_corosync: add completer for `corosync get` and `corosync set`
  * Dev: corosync_config_format: add more unit tests
  * Dev: unittest: adjust unit tests for previous changes
  * Dev: conf_parser: use the new implementation
  * Fix: open_atomic: no need to fsync on exception
  * Dev: corosync_config_format: new parser and serializer for corosync configuration file
* Thu Apr 25 2024 XLiang@suse.com
- Update to version 5.0.0+20240425.e18847d4:
  * Dev: behave: Add functional test for previous change
  * Dev: ui_context: Skip querying CIB when in a sublevel or help command
* Wed Apr 24 2024 XLiang@suse.com
- Update to version 5.0.0+20240424.43605231:
  * Dev: Remove unused code
* Tue Apr 23 2024 XLiang@suse.com
- Update to version 5.0.0+20240423.44a32f7b:
  * Dev: unittest: Adjust unit test for previous commit
  * Dev: behave: Adjust functional test for previous changes
  * Dev: bootstrap: Setup the stage dependency on init and join side (bsc#1175865, bsc#1219940)
  * Dev: ui_cluster: Remove unused codes
  * Dev: bootstrap: Enhance stage validation
  * Dev: bootstrap: Remove unused function join_remote_auth
  * Fix: healthcheck: Add crmsh.constants.SSH_OPTION when doing ssh in check_local
  * Fix: healthcheck: Missing 'id_' prefix while checking the ssh key existence
* Mon Apr 22 2024 XLiang@suse.com
- Update to version 5.0.0+20240422.8c7f5aef:
  * add doc/website-v1/news.adoc to .gitignore
  * Dev: doc: update howto build the website (#1374)
  * Dev: doc: add website target in Makefile (#1374)
  * Dev: doc/toolchain: add asciidoc-py (#1374)
  * Dev: doc/website-v1: add man-4.6 (#1374)
  * Dev: doc/toolchain: implement adocaio (#1374)
  * Dev: doc/website-v1: adapt to python3 (#1374)
  * Dev: doc/toolchain: add asciidoctor (#1374)
  * Dev: doc/toolchain: implement generating include statement for asciidoc (#1374)
  * Dev: doc/toolchain: add Containerfile (#1374)
  * Dev: doc/toolchain: implement adocxt (#1374)
  * Dev: doc/toolchain: implement help2adoc (#1374)
* Tue Apr 16 2024 XLiang@suse.com
- Update to version 5.0.0+20240416.300e2099:
  * Dev: log: Set the log format for crmsh.log as rfc5424
* Tue Apr 16 2024 XLiang@suse.com
- Update to version 5.0.0+20240416.1b89f200:
  * Dev: unittest: Adjust unit test for previous commit
  * Fix: bootstrap: Detect cluster service on init node before saving the canonical hostname (bsc#1222714)
  * Dev: behave: Add functional test for previous commit
  * Dev: doc: Drop the options for the old daemon names, pengine, crmd, cib and stonithd in the help/man
  * Dev: unittest: Adjust unit test
  * Dev: testcases: Adjust original testcases to match the new behavior
  * Dev: ra: Show related info when "advanced", "generated" and "deprecated" detected in metadata
  * Dev: ra: Parsing select values in cluster option metadata
  * Dev: ra: Get cluster option metadata from crm_attribute command (jsc#PED-8037, jsc#PED-8016)
  * Dev: unittest: Adjust unit test for previous commit
  * Dev: behave: Adjust functional test for previous commit
  * Fix: ui_node: When `utils.list_cluster_nodes` return None, try to get ip list from corosync.conf
* Wed Mar 27 2024 XLiang@suse.com
- Update to version 5.0.0+20240327.ed9189d9:
  * Dev: unittest: Adjust unit test for previous commit
  * Dev: report: Collect quorum/qdevice/qnetd status
* Wed Mar 27 2024 XLiang@suse.com
- Update to version 5.0.0+20240327.e5522426:
  * Dev: bootstrap: Add all nodes' keys to qnetd authroized_keys even init
  * Dev: behave: Addd functional test for previous commit
  * Dev: bootstrap: Give a warning when detecting $SSH_AUTH_SOCK but not use --use-ssh-agent option
  * Fix: bootstrap: fix NameError
  * Dev: unittest: Adjust unit test for previous commit
  * Dev: qdevice: Refactor init_qdevice function
  * Dev: qdevice: Add all nodes' keys to qnetd authorized_keys
* Mon Mar 25 2024 XLiang@suse.com
- Update to version 5.0.0+20240325.c91eef27:
  * Dev: behave: Adjust functional test for previous commit
  * Fix: sh: Return the value of AuthorizationError.diagnose if it is not None
* Fri Mar 15 2024 XLiang@suse.com
- Update to version 5.0.0+20240315.77a0cf32:
  * Dev: unittest: Adjust unit test for previous commit
  * Dev: bootstrap: Remove unused ssh_remote related code
  * Dev: Remove unused vgfs term from the code
  * Dev: unittest: Adjust unit test for previous commit
  * Dev: bootstrap: Remove unused function bootstrap.append_unique
  * Dev: ssh_key: Extract duplicate code about list keys from ssh-agent to a function
  * Dev: bootstrap: Refactor qdevice user parsing and finding
* Thu Mar 14 2024 XLiang@suse.com
- Update to version 5.0.0+20240314.389eebee:
  * Fix: utils: set env `CIB_shadow` using `os.environ` (bsc#1205925)
  * Fix: pass env to child process explicitly (bsc#1205925)
  * Fix: term: unset env `COLUMNS` and `ROWS` (bsc#1205925)
  * Dev: unittest: update unit tests for previous changes
  * Fix: sh: pass env to child process explicitly (bsc#1205925)
* Wed Mar 13 2024 XLiang@suse.com
- Update to version 5.0.0+20240313.bb7bb5d1:
  * Dev: sh: Fix typo in docstring
* Tue Mar 12 2024 XLiang@suse.com
- Update to version 5.0.0+20240312.9b93d857:
  * Dev: unittest: Adjust unit test for previous commit
  * Fix: bootstrap: Remove unused -i option when calling csync2_remote and ssh_remote stage (bsc#1212080)
  * Dev: unitest: Adjust unit test for previous change
  * Fix: report: Show different perspectives of cluster
* Mon Mar  4 2024 XLiang@suse.com
- Update to version 5.0.0+20240304.94b4c39b:
  * Fix: ui_node: prevent traceback on node online
  * Fix: ui_node: prevent traceback on node standby
* Mon Mar  4 2024 nicholas.yang@suse.com
- Update to version 5.0.0+20240304.17fd3413:
  * Dev: workflows: Remove the redundant stage condition
* Mon Mar  4 2024 XLiang@suse.com
- Update to version 4.6.0+20240302.43c4f758:
  * Fix cluster init example on the start guide.
  * Dev: unittests: Adjust unit test for previous changes
  * Dev: behave: Adjust functional test for previous changes
  * Dev: minor fix to align with branch crmsh-4.6
  * Dev: utils: Add IP.is_valid_ip back
  * Dev: run-functional-tests: Change report compress command as bzip2
  * Dev: report: Add config.report.compress_prog option
  * Fix: add diagnostic messages when crm report cannot find ssh-agent (bsc#1219538)
  * Dev: unittest: adjust unit tests for previous changes
  * Dev: use ClusterShell for the changes in the previous commit
  * Fix: crm report hangs in the root passwordless with ssh-agent
  * Dev: unittest: adjust unit tests for previous changes
  * Fix: report: use ClusterShell for ssh (bsc#1220170)
  * Fix: ui_node: clearstate command needs adjustment (bsc#1219831)
  * Dev: unittest: adjust unit tests for previous changes
  * Fix: bootstrap: fail to join a cluster with hostname alias
  * Dev: behave: add functional tests for previous changes
  * Fix: bootstrap: clear stall data about ssh users left possiblely from previous setups (bsc#1219476)
  * Dev: spec: Add setuptools as BuildRequires
  * Dev: behave: Adjust functional test for previous change
  * Fix: report: Escape special characters in pattern (bsc#1220022)
  * Dev: ui_configure: verify all cib objects even if there is no primitive resource configured
  * Dev: ui_configure: bundle: support podman container
  * Dev: constants: Update the bundle help text
  * Dev: parse: Assign meaningful id to the bundle's port-mapping and storage-mapping
  * Dev: testcases: Adjust original regression test cases
  * Dev: cibconfig: Hide the id of bundle port-mapping and storage-mapping
  * Dev: cibconfig: Change the multiline format for bundle
  * Dev: utils: Return empty list if corosync.conf does not exist
  * Dev: unittest: Adjust unit test for previous change
  * Dev: behave: Add functional test for previous change
  * Dev: report: Enable crm report even cib.xml does not exist
  * Dev: utils: Query pacemaker_remote node correctly
  * Fix: ui_cluster: Can't start cluster with --all option if no cib (bsc#1219052)
  * Fix: bootstrap: ssh key of the init node is duplicated in the authorized_keys files of other node (bsc#1218940)
  * Fix: sh: guide users to setup key-based ssh authentication when non-interactive authentcation fails (bsc#1219045)
  * Dev: unittest: Adjust unit test for previous changes
  * Dev: testcases: Adjust original regression test cases
  * Dev: behave: Adjust functional test for previous change
  * Fix: parse: Automatically append 's' as default time unit for timeout and interval (#1304)
  * Dev: ui_configure: Update the operation id after the monitor interval changed
  * Dev: ChangeLog: update ChangeLog for release 4.6.0
  * Dev: codecov: ignore crm report module
  * Dev: unittest: Adjust unit test for prevous changes
  * Dev: behave: Adjust functional test for previous changes
  * Fix: report: Unable to gather log files that are in the syslog format (bsc#1218491)
  * Fix: pin the tag of container image used in test
  * Dev: ui_corosync: Add a completer for corosync.set to enumerate all current paths
  * Dev: bootstrap: Assign hosts with _context.node_list_in_cluster in join_ssh_merge (bsc#1218331)
  * Dev: ChangeLog: update ChangeLog for release 4.6.0-rc2
  * Fix: github-actions: fix file owner for git
  * Dev: github-actions: update container image used in CD
  * Dev: behave: Adjust functional test for previous change
  * Dev: ui_cluster: Move --use-ssh-agent to optional arguments
  * Fix: autoconf: --with-version does not override the variable used in `version.in`
  * Dev: unify version string used in setup.py and autotools
  * Dev: unittest: Adjust unit test for previous change
  * Dev: behave: Add functional test for previous change
  * Fix: ui_cluster: Improve the process of 'crm cluster stop' (bsc#1213889)
  * Fix: scripts.health: call `setup_logging()` before importing crmsh.reprot.utils
  * Dev: unittest: adjuest unit tests for previous changes
  * Dev: behave: adjust regression tests for previous changes
  * Dev: log: save backtrace of ValueError in logfile and suppress it in console
  * Refactor: log: use levelno instead levelname to filter logs
  * Refactor: log: implement lineno in Logger instead of handler
  * Refactor: log: remove FileCustomFormatter
  * Refactor: log: remove ConsoleReportFormatter
  * Refactor: log: add LeveledFormatter to use different formats for different log levels
  * Refactor: log: unused code removal
  * Refactor: log: refactor DEBUG2 into a standard Logger interface
  * Refactor: log: refactor ConsoleCustomFormatter
  * Dev: ChangeLog: update ChangeLog for release 4.6.0-rc1
  * Dev: unittest: Add unit test for crm report module
  * Dev: report: Consider ssh agent case in crm report
  * Dev: behave: Complete test case for crm report with ssh-agent
  * Dev: report: Use ast.literal_eval instead of eval
  * Dev: utils: Rename utils.check_space_option_value to utils.check_empty_option_value
  * Dev: behave: Add 'No crmsh tracebacks' assert
  * Dev: report: Consolidate utils.read_from_file
  * Dev: codecov.yml: Increase code coverage threshold as 0.35%%
  * Dev: behave: Adjust functional behave test for previous changes
  * Dev: doc: Unify contents of manpage and help info
  * Dev: report: Rewrite crm report module
  * Dev: utils: Remove unused codes
  * Dev: config: Exclude pacemaker.log from collect_extra_logs
  * Dev: log: Add funcName for DEBUG2 log level
  * Dev: utils: To prevent shell injection, manipulate the argument array instead of the command line string
  * Fix: bootstrap: fix the owner and permission of file authorized_keys (bsc#1217279)
  * Dev: behave: add a test case for bsc#1217279
  * Dev: unittest: add a test case for the previous change
  * Fix: prun: should not call user_pair_for_ssh() when target host is localhost (bsc#1217094)
  * Dev: report: Redirect warning and error from remote node into stderr
  * Fix: utils: Add 'sudo' only when there is a sudoer(bsc#1215549)
  * Dev: behave: Move path setting into background
  * Dev: unittest: Adjust unit test for previous changes
  * Dev: xmlutil: refactor class CrmMonXmlParser
  * Dev: completers: Add online_nodes and standby_nodes
  * Fix: bootstrap: add informative logging for generating new ssh keypairs
  * Fix: forward ssh-agent for `crm report __slave`
  * Dev: behave: adjust test cases for non-root ssh-agent scenoria
  * Fix: sh: raise AuthorizationError and generate diagnose messages when ClusterShell fails with 255
  * Dev: bootstrap: allow to authenticate interactively in `crm cluster join --use-ssh-agent`
  * Dev: ssh-agent: add informative logging for adding keys to authorized_keys
  * Dev: ssh-agent: add diagnose messages
  * Dev: behave: adjust test cases for better coverage of `crm cluster init -N`
  * Dev: unittest: adjust unit tests for previous changes
  * Dev: behave: adjust functional tests for previous changes
  * Dev: bootstrap: implement ssh-agent support for geo cluster (jsc#PED-5774)
  * Dev: bootstrap: refine key swap for user `hacluster`
  * Dev: bootstrap: implement ssh-agent support for qdevice (jsc#PED-5774)
  * Dev: bootstrap: implement ssh-agent support (jsc#PED-5774)
  * Dev: regression.sh: Show error messages when test fails
  * Dev: behave: Adjust functional test for previous change
  * Dev: cmd_status: Show error correctly for crm status
  * Dev: ui_utils: Supports '=' when setting node/resource attributes
  * Fix: report: Pick up tarball suffix dynamically (bsc#1215438)
  * Fix: report: Pick 'gzip' as the first compress prog for cross-platform compatibility(bsc#1215438)
  * Fix: constants: Add several resource meta attributes (bsc#1215319)
  * refactor: move get_stdout and get_stdout_stderr to crmsh.sh.ShellUtils
  * refactor: remame SshShell to SSHShell refactor: remame AutoShell to ClusterShell refactor: rename get_stdout_stderr* to get_rc_stdout_stderr* refactor: rename get_raw_stdout_stderr* to get_rc_stdout_stderr_rc* refactor: rename *_no_input to *_without_input add doc strings
  * Dev: spec: Remove %%generate_buildrequires to prevent OBS build failures on SLE15SP5 and Leap15.5
  * Dev: behave: adjust functional tests for previous changes
  * Fix: unittest: fix several test cases for bootstarp.adjust_properties
  * Dev: unittest: adjust unit tests for previous changes
  * Dev: unittest: create unit tests for sh.py and service_manager.py
  * Dev: refactor shell calling routines
  * Dev: workflows: Enable delivery and submit CD stages for branch crmsh-4.6
  * Dev: codecov: allow minor drop (< 0.1%%) in coverage checks
  * [crmsh-4.5] Fix: github-actions: add condition to prevent crm-cd.yml running in a forked repo
  * Dev: utils: strip new line when get_stdout_or_raise_error returns
  * Fix: codecov: delay notifications until all reports are uploaded
  * Dev: behave: adjust functional tests for previous changes
  * Dev: unittest: adjust unittest for previous changes
  * Fix: prun: setsid to prevent ssh from asking a password from terminal
  * Fix: upgradeutil: reduce the timeout for getting sequence from remote node (bsc#1213797)
  * Dev: behave: Adjust functional test based on previous change
  * Dev: corosync: Enable logging.to_logfile
  * Dev: github-workflows: do not build when push to a forked repo
  * Fix: codecov: add token in plaintext
  * Revert "Fix: codecov: specify token explicitly"
  * Fix: userdir: Get the effictive user name instead of using getpass.getuser (bsc#1213821)
  * Dev: requirements: remove parallax
  * Dev: spec: Adjust spec file for Fedora
  * Dev: spec: Rewrite SPEC file to use modern pip+wheel and don't use deprecated setup.py
  * Dev: behave: add a function test for the previous change
  * Fix: upgradeutil: support the change of path of upgrade_seq in crmsh-4.5 (bsc#1213050)
  * Fix: codecov: specify token explicitly
  * Fix: ui_context: wait4dc should assume a subcommand completes successfully if no exceptions are raised (bsc#1212992)
  * Fix: unittest: fix unit tests for crmsh.bootstrap.Context.set_context
  * Dev: codecov: do not post comment in pull requests until all behave tests are finished
  * Dev: testcases: update the cases to adapt to updated version of pacemaker
  * Dev: behave: install coverage.py in docker image
  * Dev: test_container: refactor Dockerfile for better performance
  * Dev: github-actions: add codecov
  * Dev: behave: add coverage to functional test
  * Fix: upgradeutil: do not tried to upgrade when the cluster is partially set up
  * Dev: behave: adjust functional tests for previous changes
  * Dev: unittest: add unit tests for bootstrap.Context.initialize_user
  * Dev: unittest: adjust unit tests for previous changes
  * Fix: bootstrap: fix the validation of option -N and -c (bsc#1212436)
  * switch to the new container image
  * Dev: behave: adjust functional test for previous changes
  * Fix: geo_cluster: the behavior of choosing a default user in geo_join/geo_init_arbitrator is different with `cluster join` (bsc#1211817)
  * Fix: utils: do not use sudoer user to create ssh session unless it is specified explicitly (bsc#1211817)
  * Dev: behave: add a function `assert_in` to print the difference when the assertion fails
  * Fix: behave: specify username explicitly in non-root cases for option --qnetd-hostname/--cluster-node
  * Dev: behave: rewrite check_service_state with the new agent
  * Dev: behave: use a standalone agent instead of crmsh.parallax to run commands
  * medium: ui_node: fix cib rollback race on node standby
  * Dev: unittest: Adjust unit test for previous changes
  * Dev: behave: Add functional test for previous change
  * Dev: remove unused codes
  * Dev: ui_cluster: Use 'CustomAppendAction' instead of 'append' argparse action
  * Dev: bootstrap: Configure ssh key when fetch geo config
  * Dev: cmd_status: Use --output-as option instead of deprecated --as-html and --as-xml options
  * Dev: cmd_status: Append 'with quorum' and 'WITHOUT quorum' to display keyword list
  * Dev: workflows: Deliver package to network:ha-clustering:Stable
* Thu Feb 29 2024 XLiang@suse.com
- Update to version 4.5.0+20240229.6003a756:
  * Dev: unittest: disable python 3.10 in test matrix
* Thu Feb 29 2024 nicholas.yang@suse.com
- Update to version 4.5.0+20240229.5b80fde1:
  * Dev: unittests: avoid using importlib.reload to reload module
  * Dev: utils: Add functools.wraps to memoize decorator
  * Dev: Dockerfile: Adjust dockerfile based on the latest tumbleweed image
  * Dev: unittest: Add unit test for previous changes
  * Dev: testcases: Adjust testcases since package upgrade in CI image
  * Dev: run-functional-tests: start sshd.service after deploying node
  * Dev: run-functional-tests: Write configuration into /etc/sudoers.d/ instead of /etc/sudoers
  * unittests: use 'importlib' instead of 'imp' for Python 3.12
  * Dev: Add 'packaging' dependency to crmsh for version comparison
  * Dev: utils: Replace LooseVersion with packaging.version
  * Dev: unittest: Enable python 3.12 in the CI
  * Dev: ra: Remove unused codes about lrmadmin
* Thu Jan 25 2024 XLiang@suse.com
- Update to version 4.5.0+20240125.e3d1170e:
  * Import missing sys library in config.py
* Sat Jan 20 2024 XLiang@suse.com
- Update to version 4.5.0+20240120.312fce26:
  * Fix a typo in update_err()
* Thu Dec 14 2023 XLiang@suse.com
- Update to version 4.5.0+20231214.d797e044:
  * Add profile for AWS and GCP with recommended corosync token timeout
* Tue Dec  5 2023 XLiang@suse.com
- Update to version 4.5.0+20231205.02233764:
  * Dev: unittest: Adjust unit test for previous changes
  * Dev: xmlutil: refactor class CrmMonXmlParser
  * Dev: completers: Add online_nodes and standby_nodes
* Tue Dec  5 2023 XLiang@suse.com
- Update to version 4.5.0+20231205.5a8cb632:
  * Dev: utils: To prevent shell injection, manipulate the argument array instead of the command line string
  * Dev: behave: Move path setting into background
  * Dev: report: Redirect warning and error from remote node into stderr
  * Fix: utils: Add 'sudo' only when there is a sudoer(bsc#1215549)
* Thu Nov 23 2023 XLiang@suse.com
- Update to version 4.5.0+20231123.d533f2da:
  * Dev: regression.sh: Show error messages when test fails
* Wed Nov 22 2023 XLiang@suse.com
- Update to version 4.5.0+20231122.0efc476c:
  * Dev: unittest: Adjust unit test cases
  * Dev: workflows: Enable unit test for the master branch
* Mon Nov 13 2023 XLiang@suse.com
- Update to version 4.5.0+20231113.4095895e:
  * Dev: behave: Adjust functional test for previous change
  * Dev: ui_utils: Supports '=' when setting node/resource attributes
* Mon Nov 13 2023 XLiang@suse.com
- Update to version 4.5.0+20231113.31d3ebb7:
  * Dev: cmd_status: Show error correctly for crm status
* Sun Oct  8 2023 XLiang@suse.com
- Update to version 4.5.0+20231008.2d66012a:
  * Dev: spec: Remove %%generate_buildrequires to prevent OBS build failures on SLE15SP5 and Leap15.5
* Fri Sep 22 2023 XLiang@suse.com
- Update to version 4.5.0+20230922.08be0ca4:
  * Fix: constants: Add several resource meta attributes (bsc#1215319)
* Mon Aug 21 2023 XLiang@suse.com
- Update to version 4.5.0+20230821.31ab66ca:
  * Dev: behave: Adjust functional test for previous changes
  * Dev: bootstrap: Check if the join side provides the corresponding network interface
  * Dev: bootstrap: Move detect/create mountpoint code to a specific function
  * Dev: unittest: Adjust unit test for previous changes
  * Dev: testcases: Adjust regression.sh to skip new grep version warning
  * Dev: workflows: Disable unit test on python 3.6 and 3.8
  * Dev: run-functional-tests: Enable corosync3 and knet
  * Dev: Dockerfile: Install corosync3 and knet
  * Dev: bootstrap: A scaffold for crmsh to configure cluster with corosync3
  * Dev: profiles: Add new 'knet-default' profile type to keep knet only parameters
  * Dev: bootstrap: Validate network potions
  * Dev: ui_cluster: Add -t/--transport option and change -i/--interface option
  * Dev: Add new parser to parse corosync.conf
  * Dev: bootstrap: Remove bootstrap.update_expected_votes
  * Dev: behave: Adjust functional test for previous changes
  * Dev: ui_cluster: Drop deprecated options
* Mon Aug 21 2023 XLiang@suse.com
- Update to version 4.5.0+20230821.44144a88:
  * Dev: codecov: allow minor drop (< 0.1%%) in coverage checks
  * Fix: github-actions: add condition to prevent crm-cd.yml running in a forked repo
  * add vim modeline to shell script run-functional-tests
* Wed Aug 16 2023 XLiang@suse.com
- Update to version 4.5.0+20230816.1205b7c0:
  * Dev: utils: strip new line when get_stdout_or_raise_error returns
* Thu Aug 10 2023 nicholas.yang@suse.com
- Update to version 4.5.0+20230810.4e4e0452:
  * Dev: behave: Adjust functional test based on previous change
  * Dev: corosync: Enable logging.to_logfile
* Wed Aug  9 2023 XLiang@suse.com
- Update to version 4.5.0+20230809.9714e8ea:
  * Fix: codecov: delay notifications until all reports are uploaded
* Tue Aug  8 2023 XLiang@suse.com
- Update to version 4.5.0+20230809.91c2de47:
  * Dev: github-workflows: do not build when push to a forked repo
  * Fix: codecov: add token in plaintext
  * Revert "Fix: codecov: specify token explicitly"
* Wed Aug  2 2023 XLiang@suse.com
- Update to version 4.5.0+20230802.a753fadc:
  * Dev: behave: adjust functional tests for previous changes
  * Dev: unittest: adjust unittest for previous changes
  * Fix: prun: setsid to prevent ssh from asking a password from terminal
  * Fix: upgradeutil: reduce the timeout for getting sequence from remote node (bsc#1213797)
  * Fix: unittest: fix unit tests for crmsh.bootstrap.Context.set_context
* Tue Aug  1 2023 XLiang@suse.com
- Update to version 4.5.0+20230802.4a06200b:
  * Fix: userdir: Get the effictive user name instead of using getpass.getuser (bsc#1213821)
  * Dev: requirements: remove parallax
* Tue Jul 25 2023 nicholas.yang@suse.com
- Update to version 4.5.0+20230725.cf4a40a4:
  * Dev: spec: Adjust spec file for Fedora
  * Dev: spec: Rewrite SPEC file to use modern pip+wheel and don't use deprecated setup.py
* Mon Jul 24 2023 XLiang@suse.com
- Update to version 4.5.0+20230724.3b4b1f6d:
  * Dev: behave: add a function test for the previous change
  * Fix: upgradeutil: support the change of path of upgrade_seq in crmsh-4.5 (bsc#1213050)
* Fri Jul 14 2023 XinLiang <XLiang@suse.com>
- Dev: spec: Define python3_sitelib if it is not defined
- Dev: spec: Update package dependency
* Wed Jul  5 2023 XLiang@suse.com
- Update to version 4.5.0+20230705.be003475:
  * Fix: codecov: specify token explicitly
  * Fix: ui_context: wait4dc should assume a subcommand completes successfully if no exceptions are raised (bsc#1212992)
* Sat Jul  1 2023 XLiang@suse.com
- Update to version 4.5.0+20230701.3fb634fe:
  * Dev: codecov: do not post comment in pull requests until all behave tests are finished
  * Dev: testcases: update the cases to adapt to updated version of pacemaker
  * Dev: behave: install coverage.py in docker image
  * Dev: test_container: refactor Dockerfile for better performance
  * Dev: github-actions: add codecov
  * Dev: behave: add coverage to functional test
  * Fix: upgradeutil: do not tried to upgrade when the cluster is partially set up
  * Dev: behave: adjust functional tests for previous changes
  * Dev: unittest: add unit tests for bootstrap.Context.initialize_user
  * Dev: unittest: adjust unit tests for previous changes
  * Fix: bootstrap: fix the validation of option -N and -c (bsc#1212436)
* Mon Jun 19 2023 XLiang@suse.com
- Update to version 4.5.0+20230619.c62e66bb:
  * medium: ui_node: fix cib rollback race on node standby
* Fri Jun 16 2023 XLiang@suse.com
- Update to version 4.5.0+20230616.6eb1cea0:
  * Dev: tox: Remove py3.6 and py3.8 for current master branch
  * Dev: unittest: Adjust unit test for previous changes
  * Dev: behave: Add functional test for previous change
  * Dev: remove unused codes
  * Dev: ui_cluster: Use 'CustomAppendAction' instead of 'append' argparse action
* Tue Jun  6 2023 XLiang@suse.com
- Update to version 4.5.0+20230606.b511e42b:
  * switch to the new container image
  * Dev: behave: adjust functional test for previous changes
  * Fix: geo_cluster: the behavior of choosing a default user in geo_join/geo_init_arbitrator is different with `cluster join` (bsc#1211817)
  * Fix: utils: do not use sudoer user to create ssh session unless it is specified explicitly (bsc#1211817)
  * Dev: behave: add a function `assert_in` to print the difference when the assertion fails
  * Fix: behave: specify username explicitly in non-root cases for option --qnetd-hostname/--cluster-node
  * Dev: behave: rewrite check_service_state with the new agent
  * Dev: behave: use a standalone agent instead of crmsh.parallax to run commands
* Tue Jun  6 2023 XLiang@suse.com
- Update to version 4.5.0+20230606.9a8fab45:
  * Dev: remove unused codes
  * Dev: ui_corosync: Remove add-node and del-node subcommands
* Thu Jun  1 2023 Matej Cepl <mcepl@suse.com>
- Rewrite SPEC file to use modern pip+wheel and don't use
  deprecated setup.py.
* Wed May 31 2023 XLiang@suse.com
- Update to version 4.5.0+20230531.9de3e687:
  * Dev: bootstrap: Configure ssh key when fetch geo config
* Thu May 18 2023 XLiang@suse.com
- Update to version 4.5.0+20230518.37907c1f:
  * Dev: workflows: Temporarily remove unit_test from needs list for delivery job
  * Dev: cmd_status: Use --output-as option instead of deprecated --as-html and --as-xml options
  * Dev: cmd_status: Append 'with quorum' and 'WITHOUT quorum' to display keyword list
  * Dev: workflows: Temporarily disabled unit_test and submit job
* Mon May 15 2023 XLiang@suse.com
- Update to version 4.5.0+20230515.64893bc7:
  * Dev: behave: Add '<user>@' for -N/--node option for non-root case
  * Dev: behave: Add -q option for run-functional-tests to create qnetd-node
  * Dev: behave: Adjust functional test cases based on previous changes
  * Dev: behave: Create normal user that does not belong to the haclient group
  * Dev: behave: Use 'su - <user>' instead of 'su <user>'
  * Dev: behave: Simulate Azure instance ssh environment
  * Dev: Dockerfile: Remove python3-parallax from dockerfile
  * Dev: spec: Remove python3-parallax from spec file
  * Dev: behave: Add more functional test cases
  * Dev: rsctest: Replace sys.stderr.write with logging
* Mon May 15 2023 XLiang@suse.com
- Update to version 4.5.0+20230515.d279a671:
  * Dev: parallax: unused code removal, and refine docstrings
  * Fix: utils: fix `cluster diff --checksum`
  * Dev: ui_cluster: refine messages for `cluster run` and `cluster coy`
  * Dev: geo: implement non-root support for geo_fetch_config()
  * Fix: bootstrap: failed to join when the cluster is initialized with skip_csync2
  * Dev: prun: minor refactor and add comments
  * Dev: unittest: adjust unit tests for previous changes
  * Dev: prun: implement timeout
  * Dev: prun: add an concurrency limiter
  * Dev: remove python dependency parallax
  * Dev: scripts: implement non-root support with crmsh.prun
  * Dev: unused code removal
  * Dev: implement non-root support for crm_pssh with crmsh.prun
  * Dev: remove some direct calls to parallax module
  * Dev: prun: add special handling for localhost
  * Dev: refine non-root sudoer support for crmsh.parallax.parallax_slurp
  * Dev: refine non-root sudoer support for crmsh.parallax.parallax_copy
  * Dev: upgradeutil: adapt to new parallax interface
  * Dev: refine non-root sudoer support for crmsh.parallax.parallax_call (bsc#1210709)
* Mon May 15 2023 XLiang@suse.com
- Update to version 4.5.0+20230515.db0cbb05:
  * Dev: unittest: adjust unit tests for previous changes
  * Fix: bootstrap: failed to save username for localhost when initializing a cluster with a qnet server
* Wed May 10 2023 XLiang@suse.com
- Update to version 4.5.0+20230510.847a251b:
  * Fix: bootstrap: `init --qnetd-hostname` fails when username is not specified (bsc#1211200)
* Wed May 10 2023 nicholas.yang@suse.com
- Update to version 4.5.0+20230510.3343cc42:
  * Dev: behave: Use 'su - <user>' instead of 'su <user>'
  * Dev: Dockerfile: use opensuse/leap:15.5 for current CI
* Thu Apr 27 2023 XLiang@suse.com
- Update to version 4.5.0+20230427.11d11104:
  * Dev: behave: Add <user>@ when joining for non-root case
  * Dev: behave: Add functional test for bsc#1210693
* Wed Apr 26 2023 XLiang@suse.com
- Update to version 4.5.0+20230426.b7c4b1aa:
  * Dev: behave: Adjust functional test for previous change
  * Dev: unittest: adjust unit tests for previous changes
  * Fix: bootstrap: crm cluster join default behavior change in ssh key handling (bsc#1210693)
* Mon Apr 24 2023 XLiang@suse.com
- Update to version 4.5.0+20230424.75600b3f:
  * Fix: help: Long time to load and parse crm.8.adoc (bsc#1210198)
  * Dev: behave: Adjust functional test for previous change
  * Dev: unittest: Adjust unit test for previous change
  * Fix: lock: Join node failed to wait init node finished (bsc#1210332)
* Fri Apr 21 2023 XLiang@suse.com
- Update to version 4.5.0+20230421.a509b8ce:
  * Dev: bootstrap: Call 'crm configure load' inside crm_configure_load
  * Fix: cibconfig: use any existing rsc_defaults set rather than create another one (bsc#1210614)
  * Revert "Dev: bootstrap: Avoid duplicated setting for rsc_defaults"
  * Dev: bootstrap: Print output for other nodes when using -N option
* Fri Mar 31 2023 XLiang@suse.com
- Update to version 4.5.0+20230331.10398d83:
  * Dev: testcase: update history testcase
  * Dev: log_patterns: update patterns for pacemaker version 2.0+
* Thu Mar 30 2023 XLiang@suse.com
- Update to version 4.5.0+20230330.fd21b87d:
  * Dev: behave: Add functional test for previous changes
  * Dev: unittest: Add unit test for previous changes
  * Dev: bootstrap: Support replacing sbd device via sbd stage
* Thu Mar 30 2023 XLiang@suse.com
- Update to version 4.5.0+20230330.c59dceee:
  * Dev: utils: add auto_convert_role flag for handle_role_for_ocf_1_1 function
* Thu Mar 30 2023 XLiang@suse.com
- Update to version 4.5.0+20230330.60bfb162:
  * Dev: ChangeLog: update ChangeLog for release 4.5.0
* Wed Mar 29 2023 XLiang@suse.com
- Update to version 4.5.0+20230329.6d95249b:
  * Dev: behave: save stderr when running command on remote
* Wed Mar 29 2023 XLiang@suse.com
- Update to version 4.5.0+20230329.0b20d25b:
  * Dev: unittest: Adjust unit test for previous change
  * Dev: bootstrap: Generate the public key on the remote if it does not exist
  * Dev: behave: Add functional test for missing public key case
* Wed Mar 29 2023 XLiang@suse.com
- Update to version 4.5.0+20230329.34448a8c:
  * Dev: unittest: Adjust unit test for previous change
  * Dev: bootstrap: Remove /var/lib/crm and ~/.config/crm/crm.conf when removing node
* Mon Mar 27 2023 XLiang@suse.com
- Update to version 4.5.0+20230327.9a683c11:
  * Dev: behave: Add more test cases for bug 1209193
* Mon Mar 27 2023 XLiang@suse.com
- Update to version 4.5.0+20230327.c76ad5d5:
  * Fix: unittest: Adjust unit tests for previous changes
  * Fix: utils: qdevice initialization should user_pair_for_ssh() to get appreciated users (crmsh#1157)
* Mon Mar 27 2023 XLiang@suse.com
- Update to version 4.5.0+20230327.3cbdd737:
  * Dev: behave: Change docker image as liangxin1300/haleap:15.5
  * Fix: crm report: sustain if there are offline nodes (bsc#1209480)
* Mon Mar 27 2023 XLiang@suse.com
- Update to version 4.5.0+20230327.1d3873bd:
  * Dev: behave: Add Scenario: Do upgrade job without root passwordless
  * Dev: unittest: Add unit test case for previous changes
  * Dev: upgradeutil: Change 'upgrade' terminology to 'configuration fix'
  * Dev: behave: Reuse crmsh.utils.check_passwordless_between_nodes function
  * Dev: utils: Check passwordless between cluster nodes
* Thu Mar 23 2023 XLiang@suse.com
- Update to version 4.5.0+20230323.9f3f56c1:
  * Dev: behave: Adjust sbd functional test based on previous changes
  * Dev: testcases: Adjust testcases after pacemaker upgrade
  * Dev: workflows: split functional_test_resource_subcommand as two jobs
  * Revert "Dev: workflows: Disable resource_failcount.feature temporarily"
  * Dev: Dockerfile: Update pacemaker and libqb version
* Tue Mar 21 2023 XLiang@suse.com
- Update to version 4.5.0+20230321.97bd51bb:
  * Dev: behave: Split the time cost case into two cases
  * Dev: unittest: Adjust unit test for previous changes
  * Dev: remove 'sudo' prefix internally
* Tue Mar 21 2023 XLiang@suse.com
- Update to version 4.5.0+20230321.eda6d2d9:
  * Dev: workflows: Disable resource_failcount.feature temporarily
  * Dev: behave: Add test case for 'Passwordless for root, not for sudoer(bsc#1209193)'
  * Dev: behave: check user shell after init and join, without upgrading
  * Dev: bootstrap: Change user shell for hacluster on remote node, in init_ssh_impl function
  * Dev: behave: Add functional test to check user shell for hacluster
* Mon Mar 20 2023 XLiang@suse.com
- Update to version 4.5.0+20230320.5e777809:
  * Dev: unittest: Adjust unit test for previous changes
  * Fix: validate ssh session when the users is determined by guessing (bsc#1209193)
* Tue Mar 14 2023 XLiang@suse.com
- Update to version 4.5.0+20230314.c7422396:
  * Dev: unittest: Adjust unit test for previous changes
  * Fix: parallax: Use 'sudo bash -c' when executing commands via sudoer (bsc#1209192)
  * Dev: qdevice: Add more debug messages for running commands
  * Dev: log: For the log_only_to_file method, show debug log in debug mode
* Thu Mar  9 2023 XLiang@suse.com
- Update to version 4.5.0+20230309.a4c4192d:
  * Dev: ChangeLog: update ChangeLog for release 4.5.0-rc2
  * Dev: version: Bump crmsh version to 4.5.0
* Thu Mar  9 2023 XLiang@suse.com
- Update to version 4.4.1+20230309.e15745c6:
  * Dev: bootstrap: remove unused codes
  * Dev: unittest: Adjust unit test for previous change
  * Dev: bootstrap: Swap hacluster ssh key with other nodes
  * Dev: behave: Check passwordless for hacluster between cluster nodes
* Tue Mar  7 2023 XLiang@suse.com
- Update to version 4.4.1+20230307.daea9d13:
  * Fix: report: Fix crm report issue under non-root user
* Mon Mar  6 2023 XLiang@suse.com
- Update to version 4.4.1+20230306.0f04eb29:
  * Dev: bootstrap: Don't save core.debug when saving core.hosts
  * Dev: behave: Adjust functional test for previous changes
  * Dev: log: Redirect debug messages into stderr
* Fri Mar  3 2023 XLiang@suse.com
- Update to version 4.4.1+20230303.0df99d8c:
  * Dev: ChangeLog: update ChangeLog for release 4.5.0-rc1
  * replace 2&>1 by 2>&1 and swap with >/dev/null
* Thu Mar  2 2023 XLiang@suse.com
- Update to version 4.4.1+20230302.2b5310b9:
  * Dev: unittest: Adjust unit test for previous change
  * Dev: bootstrap: Add sudo before crm_node under non-root user on remote node
* Thu Mar  2 2023 XLiang@suse.com
- Update to version 4.4.1+20230302.fc282490:
  * Dev: behave: Create user alice on qnetd node
  * Dev: behave: don't build crmsh code on qnetd node
* Thu Mar  2 2023 XLiang@suse.com
- Update to version 4.4.1+20230302.2ed0ab14:
  * Dev: unittest: Adjust unit test for previous changes
  * Fix: qdevice: Unable to setup qdevice under non-root user (bsc#1208770)
* Tue Feb 28 2023 XLiang@suse.com
- Update to version 4.4.1+20230228.2f852310:
  * Dev: utils: Suppress the output of ssh-copy-id for non-root user case
* Mon Feb 27 2023 XLiang@suse.com
- Update to version 4.4.1+20230227.b420cbf5:
  * Dev: unittest: Adjust unit test for previous change
  * Dev: utils: Avoid using magic number
* Fri Feb 24 2023 XLiang@suse.com
- Update to version 4.4.1+20230224.498677ab:
  * Dev: utils: Suppress the output of ssh-copy-id
* Fri Feb 24 2023 XLiang@suse.com
- Update to version 4.4.1+20230224.83dcde63:
  * Dev: unittest: remove test_healthcheck.py since the new implementation is trivial
  * Fix: bootstrap: fail to join a cluster initialized by previous version
  * Dev: healthcheck: refine the implementation to fix ssh key problems by calling function init_ssh instead of calling command `cluster init ssh`
  * Dev: upgradeutil: do upgrade silently (bsc#1208327)
  * Fix: bootstrap: `crm cluster join ssh` raises TypeError (bsc#1208327)
* Tue Feb 21 2023 XLiang@suse.com
- Update to version 4.4.1+20230221.eb38cb6e:
  * Dev: utils: Change the way to get pacemaker's version (bsc#1208216)
* Fri Feb 17 2023 XLiang@suse.com
- Update to version 4.4.1+20230217.7fe11a5c:
  * Dev: report: Enable crm report for sudoer user
* Fri Feb 17 2023 XLiang@suse.com
- Update to version 4.4.1+20230217.0dc54cef:
  * Fix: utils: use parallax_run instead of parallax_call in ServiceManager
  * Dev: uinttest: adjust unit test for previous change
  * Fix: behave: fix a regression for bsc#1183654
  * fix qdevice
  * fix: utils: check hostname alias in user_of
  * fix: utils: make ServiceManager to work with new remote calling utils
  * Dev: bootstrap: guess and ask whether to operate in non-root mode (jsc#PED-290)
  * Dev: bootstrap: allow the cluster to operate with ssh session under non-root sudoer (jsc#PED-290)
* Fri Feb 10 2023 XLiang@suse.com
- Update to version 4.4.1+20230210.df3b7a92:
  * Dev: unittest: Adjust unit test for previous change
  * Dev: behave: Adjust functional test for previous change
  * Dev: utils: Add sudo for the commands in user hints
* Wed Feb  8 2023 XLiang@suse.com
- Update to version 4.4.1+20230208.b437e499:
  * Dev: spec: Requires parallax version 1.0.8
* Tue Feb  7 2023 XLiang@suse.com
- Update to version 4.4.1+20230207.3485cdd1:
  * Fix: hawk fails to parse the slash (bsc#1206217)
* Sat Jan 28 2023 XLiang@suse.com
- Update to version 4.4.1+20230128.8541d6a8:
  * Fix: extra logs while configuring passwordless (bsc#1207720)
* Tue Jan 17 2023 nicholas.yang@suse.com
- Update to version 4.4.1+20230117.fb8b3c2b:
  * Dev: unittest: adjust unit tests for previous change
  * Dev: healthcheck: allow using non-root sudoer for remote access
  * Fix: bootstrap: corosync-cfgtool -R requires privilege
  * Dev: bootstrap: implement swapping hacluster's ssh key using non-root sudoer remote access
  * Dev: unittest: Add unit test for previous change
  * Dev: behave: Add user_access.feature to do functional test for previous change
  * Dev: utils: Check current user's privilege and give hints to user
* Sun Jan 15 2023 XLiang@suse.com
- Update to version 4.4.1+20230115.e69ffac7:
  * Fix spelling errors.
  * Don't use inspect.getargspec, removed in Python 3.11.
* Wed Jan 11 2023 XLiang@suse.com
- Update to version 4.4.1+20230111.89dfe511:
  * Dev: behave: Add 'sudo' before most of commands
  * Dev: behave: Run all cases twice under normal user
* Fri Jan  6 2023 XLiang@suse.com
- Update to version 4.4.1+20230106.b020209b:
  * Dev: unittest: Adjust unit test based on previous change
  * Dev: utils: use --preserve-env option, not -E for sudo
* Thu Jan  5 2023 XLiang@suse.com
- Update to version 4.4.1+20230105.6c47d1cc:
  * Dev: behave: add basic alice-bob init-join test
  * Dev: unittest: replace root by alice and bob
  * Feature: replace root by a custom user with root privileges
* Wed Dec 28 2022 XLiang@suse.com
- Update to version 4.4.1+20221228.326c28fd:
  * Dev: report: 'crm report' to collect journal.log in microseconds
  * Dev: doc: Add deprecated note for 'crm configure erase'
  * Dev: ui_configure: Deprecate configure erase sub-command
* Wed Dec 28 2022 XLiang@suse.com
- Update to version 4.4.1+20221228.7c16362c:
  * Dev: unittest: Adjust unit test for previous changes
  * Dev: ui_cluster: Improve cluster start/stop INFO
* Tue Dec 27 2022 XLiang@suse.com
- Update to version 4.4.1+20221227.bd7d326e:
  * Dev: upgradeutil: do not ask when running in a background process group
* Tue Dec 27 2022 XLiang@suse.com
- Update to version 4.4.1+20221227.d0ae243b:
  * Dev: unittest: Adjust unit test for previous changes
  * Fix: bootstrap: Unset SBD_DELAY_START when running 'crm cluster start' (bsc#1202177)
* Mon Dec 26 2022 XLiang@suse.com
- Update to version 4.4.1+20221226.d38855cb:
  * Dev: unittest: Adjust unit test for previous changes
  * Dev: qdevice: Adjust qdevice reload policy
* Mon Dec 26 2022 XLiang@suse.com
- Update to version 4.4.1+20221226.371d6f7a:
  * Fix: report: Catch read exception (bsc#1206606)
* Thu Dec 15 2022 XLiang@suse.com
- Update to version 4.4.1+20221215.752a541a:
  * Fix: behave: cleanup is not applied to nodes that have been removed from cluster
  * Dev: behave: add behave test for `crm -F node delete`
  * Dev: ui_cluster: unused code removal
  * Dev: unittest: adjust unit test based on previous changes
  * Dev: ui_node: redirect `node delete` to `cluster remove`
* Thu Dec 15 2022 XLiang@suse.com
- Update to version 4.4.1+20221215.9fa76957:
  * Dev: behave: Add functional test for cluster API
* Tue Dec 13 2022 XLiang@suse.com
- Update to version 4.4.1+20221213.6e4f7dfd:
  * Dev: unittest: Adjust unit test based on previous changes
  * Dev: behave: Add functional test for -x option to skip csync2
  * Dev: bootstrap: Add option -x to skip csync2 initialization stage during the whole cluster bootstrap
* Wed Dec  7 2022 XLiang@suse.com
- Update to version 4.4.1+20221207.84e6ea16:
  * Dev: parse: Don't set timeout value when is not set by user meanwhile no value is advised in the metadata
  * Dev: parse: complete advised operation values for other actions beside monitor
  * Dev: unittest: Add unit test for utils.compatible_role
  * Dev: parse: Consider compatibility for role when complete operation actions with advised values
* Tue Dec  6 2022 XLiang@suse.com
- Update to version 4.4.1+20221206.b25bc04c:
  * Dev: unittest: Adjust unit test based on previous changes
  * Dev: qdevice: Refactor qdevice validation code
* Sat Dec  3 2022 XLiang@suse.com
- Update to version 4.4.1+20221203.9bb5442e:
  * Dev: doc: ui_cluster: adapt usage text to asciidoc format
  * Dev: behave: add assert_eq to print expected and actual values when assertions fail
  * Fix: behave: specified destination dir explicitly when source code is copied into a container
  * Dev: ui_context: redirect `foo -h`/`foo --help` to `help foo` (bsc#1205735)
* Fri Dec  2 2022 XLiang@suse.com
- Update to version 4.4.1+20221202.ec9fec0e:
  * Dev: unittest: Adjust unit test based on previous changes
  * Dev: behave: Add functional test based on previous changes
  * Dev: bootstrap: remove more configuration files while removing node from cluster
* Thu Dec  1 2022 XLiang@suse.com
- Update to version 4.4.1+20221201.bdfb0f2c:
  * Change: store the upgrade_seq in /etc/crm/
* Thu Dec  1 2022 XLiang@suse.com
- Update to version 4.4.1+20221201.280e5afb:
  * Fix: qdevice: Adjust SBD_WATCHDOG_TIMEOUT when configuring qdevice not using stage (bsc#1205727)
* Wed Nov 30 2022 XLiang@suse.com
- Update to version 4.4.1+20221130.c3547a20:
  * Dev: testcases: Adjust original regression test based on previous changes
  * Dev: behave: Add functional test for previous changes
  * Fix: cibconfig: Complete promotable=true and interlave=true for Promoted/Unpromoted resource (bsc#1205522)
* Mon Nov 28 2022 XLiang@suse.com
- Update to version 4.4.1+20221128.75c824f5:
  * Dev: bootstrap: return when -N option not specified
  * Dev: unittest: Add unit test for previous commit
  * Dev: bootstrap: join process return immediately when joining itself
* Mon Nov 28 2022 XLiang@suse.com
- Update to version 4.4.1+20221128.1b8068a8:
  * Dev: log: Use original way for the prompt input
* Fri Nov 25 2022 XLiang@suse.com
- Update to version 4.4.1+20221125.ef74cf11:
  * Dev: bootstrap: add timeout to wait_for_cluster and wait_for_resource
* Thu Nov 24 2022 XLiang@suse.com
- Update to version 4.4.1+20221124.37ac467f:
  * Fix: corosync: show corosync ring status if has fault (bsc#1205615)
* Tue Nov 22 2022 XLiang@suse.com
- Update to version 4.4.1+20221122.102a8e11:
  * Dev: workflows: add behave test `healthcheck`
  * Dev: behave: add functional test for previous changes
  * Dev: upgradeutil: change the format of seq from int to major.minor
  * Dev: unittest: move tests to test_healthcheck
  * Dev: bootstrap: fix passwordless ssh authentication for hacluster automatically when a new node is joining the cluster (bsc#1201785)
  * Dev: refactor: extract healthcheck module from upgradeutil
  * Fix: testcases: fix shadow cib tests for previous changes.
  * Fix: testcases: add no_reg option for utils.list_cluster_nodes
  * Dev: unittest: add new tests for upgradeutil
  * Dev: upgradeutil: automated init ssh passwordless auth for hacluster after upgrading (bsc#1201785)
* Tue Nov 22 2022 nicholas.yang@suse.com
- Update to version 4.4.1+20221122.20aa6e8e:
  * Dev: workflows: update actions version
* Wed Nov 16 2022 XLiang@suse.com
- Update to version 4.4.1+20221116.4faefec3:
  * Dev: run-functional-tests: get index of test case in github action
  * Dev: run-functional-tests: Set stonith-enabled=false after setup cluster
  * Dev: run-functional-tests: Deploy and remove containers in parallel
* Tue Nov 15 2022 XLiang@suse.com
- Update to version 4.4.1+20221115.10733d98:
  * Dev: behave: stop sshd.service in test case
* Tue Nov 15 2022 XLiang@suse.com
- Update to version 4.4.1+20221115.a52067ac:
  * Dev: crm: Improve error hints when starting crmsh
* Sat Nov 12 2022 XLiang@suse.com
- Update to version 4.4.1+20221112.1eecda84:
  * Dev: behave: Add functional test to verify report collect trace ra logs
  * Dev: report: collect ra trace files from specified directories
* Fri Nov 11 2022 XLiang@suse.com
- Update to version 4.4.1+20221111.e52b7fa2:
  * Dev: behave: Add functional test for tracing ra with specific directory
  * Dev: Dockerfile: update resource-agents with latest version
* Wed Nov  9 2022 XLiang@suse.com
- Update to version 4.4.1+20221109.3640f356:
  * Dev: ui_resource: trace directory in log info should be changed dynamically
* Tue Nov  8 2022 XLiang@suse.com
- Update to version 4.4.1+20221108.c4182bc4:
  * Dev: testcases: Adjust origin regression test based on previous changes
  * Dev: unittest: Adjust unit test based on previous changes
  * Dev: parse: cli_to_xml: populate advised monitor/start/stop operations values
* Mon Nov  7 2022 XLiang@suse.com
- Update to version 4.4.1+20221107.0c91f0d3:
  * code
  * Dev: behave: Add functional test for parallax OSError: [Errno 24] Too many open files
* Thu Oct 27 2022 XLiang@suse.com
- Update to version 4.4.1+20221027.e42809ff:
  * Packaging: create /var/log/crmsh with tmpfiles.d
  * fix: behave: mkdir /var/log/crmsh in docker image
  * Fix: log: ownership and mode of log files should be set in RotatingFileHandler
  * Fix: #977 crmsh not working when using ACL
  * fix: log: fail to open log file even if user is in haclient group (bsc#1204670)
* Wed Oct 26 2022 XLiang@suse.com
- Update to version 4.4.1+20221026.a0f9a70f:
  * fix: userdir: race condition during directory creation
* Tue Oct 25 2022 Nicholas Yang <nicholas.yang@suse.com>
- Packaging: create /var/log/crmsh with tmpfiles.d (bsc#1204670)
* Fri Oct 14 2022 XLiang@suse.com
- Update to version 4.4.1+20221014.0b04f693:
  * crm.8.adoc: spelling (recipients, embellishments)
* Fri Oct 14 2022 XLiang@suse.com
- Update to version 4.4.1+20221013.11edd97f:
  * Dev: Dockerfile: update the Dockerfile for updating parallax
* Wed Sep 28 2022 XLiang@suse.com
- Update to version 4.4.1+20220928.3480aa0d:
  * Dev: behave: append more functional test for sbd and watchdog
* Wed Sep 28 2022 XLiang@suse.com
- Update to version 4.4.1+20220928.ef80f673:
  * Dev: unittest: Adjust unit test based on previous changes
  * Fix: sbd: Ask if overwrite when given sbd device on interactive mode(bsc#1201428)
* Wed Sep 28 2022 XLiang@suse.com
- Update to version 4.4.1+20220928.ea5c5190:
  * Dev: history: print necessary log messages when collecting report
  * Dev: report: make sure 'crm -d report' could increase the verbosity
* Wed Sep 28 2022 XLiang@suse.com
- Update to version 4.4.1+20220928.ded85d0a:
  * Dev: behave: Add functional test based on previous changes
  * Dev: unittest: Adjust unit test based on previous changes
  * Dev: bootstrap: Adjust cluster properties including priority-fencing-delay
* Fri Sep 23 2022 XLiang@suse.com
- Update to version 4.4.1+20220923.9651e0fa:
  * Dev: unittest: Adjust unit test based on prevous changes
  * Dev: behave: Add functional test based on previous commit
  * Fix: ui_cluster: 'crm cluster stop' failed to stop services (bsc#1203601)
* Wed Sep 21 2022 XLiang@suse.com
- Update to version 4.4.1+20220921.dbe833c5:
  * Dev: unittest: Adjust unit test based on previous changes
  * Dev: bootstrap: Adjust pcmk_delay_max and stonith-timeout for all configured fence agents
* Mon Sep 19 2022 XLiang@suse.com
- Update to version 4.4.1+20220919.2ab5b976:
  * Dev: doc: add help info for related:class for 'configure show' command
  * Dev: cibconfig: "crm config show related:xxx" provides partial search among class, provider, type fields
* Thu Sep 15 2022 XLiang@suse.com
- Update to version 4.4.1+20220915.afcd88e6:
  * Dev: behave: Add functional test case based on previous changes
  * Dev: bootstrap: Adjust sbd related timeout when add/remove qdevice
* Wed Sep 14 2022 XLiang@suse.com
- Update to version 4.4.1+20220914.fa29aa2c:
  * Fix: crash_test: do not use firewalld to isolate a cluster node (bsc#1192467)
* Tue Sep 13 2022 zzhou@suse.com
- Update to version 4.4.1+20220913.57fa9d96:
  * Dev: unittest: Adjust unit test based on previous changes
  * Dev: utils: Refactor class ServiceManager, to show all nodes' status when running in parallel
  * Dev: bootstrap: Add delay to start corosync when node list larger than 5
* Thu Sep  8 2022 XLiang@suse.com
- Update to version 4.4.1+20220908.d668787c:
  * Dev: add remote_auth to known stages of cluster init
  * Dev: add unit tests for SBDTimeout.initialize_timeout
  * Dev: refactor timeout caculation for sbd
* Thu Sep  8 2022 XLiang@suse.com
- Update to version 4.4.1+20220908.88a9f0c9:
  * Dev: GH-workflows: Add a general check to check if data-manifest changed
* Mon Sep  5 2022 XLiang@suse.com
- Update to version 4.4.1+20220905.311a0a0d:
  * Dev: testcases: adjust origin testcases based on previous changes
  * Dev: data-manifest: Update content of data-manifest since #1022 added new files
* Fri Sep  2 2022 XLiang@suse.com
- Update to version 4.4.1+20220902.dceb5b92:
  * Add SAN
  * Apply proposed changes.
  * Do not provide senceless default values for IPAddr2. Fix command line to verify and setup cluster group.
  * Fix typos
  * Add documetation to the script
  * move missplaced directory
  * Initial version of cryptctl setup script.
* Tue Aug 30 2022 XLiang@suse.com
- Update to version 4.4.1+20220830.5a63c85f:
  * Dev: unittest: Adjust unit test based on previous changes
  * Dev: bootstrap: Show remote node name when stopping service remotely
* Mon Aug 29 2022 XLiang@suse.com
- Update to version 4.4.1+20220829.08a730cb:
  * Dev: log: print a full-width progress bar in status_progress to prevent interleaving with log messages
  * Dev: log: print begin and end marker in different lines in status_long
* Wed Aug 24 2022 XLiang@suse.com
- Update to version 4.4.1+20220824.c59544bf:
  * Dev: ui_context: remove duplicated codes
  * Dev: parallax: Add LogLevel=error ssh option to filter out warnings (bsc#1196726)
  * Revert "Fix: utils: Only raise exception when return code of systemctl command over ssh larger than 4 (bsc#1196726)" (bsc#1202655)
* Tue Aug 23 2022 XLiang@suse.com
- Update to version 4.4.1+20220822.c2f5d204:
  * fix: configure: refresh cib before showing or modifying if no pending changes has been made (bsc#1202465)
* Mon Aug 22 2022 XLiang@suse.com
- Update to version 4.4.1+20220822.10c65b3b:
  * Revert "Dev: testcases: Update expected testcase with pacemaker update"
  * Dev: CI: master branch change to use opensuse/leap:15.4 as docker image
* Fri Aug 12 2022 XLiang@suse.com
- Update to version 4.4.1+20220812.5acffe48:
  * Dev: behave: Increase wait time for resource started
* Thu Aug 11 2022 XLiang@suse.com
- Update to version 4.4.1+20220811.e3a59fc7:
  * Fix: bootstrap: Use crmsh.parallax instead of parallax module directly (bsc#1202006)
* Wed Aug 10 2022 XLiang@suse.com
- Update to version 4.4.0+20220810.387d071f:
  * Dev: unittest: Adjust unit test based on previous changes
  * Dev: bootstrap: Generate public key from private key
* Tue Aug  9 2022 XLiang@suse.com
- Update to version 4.4.0+20220809.4f90c4ef:
  * Dev: bootstrap: Don't sync csync2 when peer node's csync2 service not ready
* Mon Aug  8 2022 XLiang@suse.com
- Update to version 4.4.0+20220808.89fa84a6:
  * Dev: bootstrap: Don't open mgmt port since it's deprecated
* Thu Jul 28 2022 XLiang@suse.com
- Update to version 4.4.0+20220728.3f249756:
  * Dev: ui_cluster: Change the dest of -N option as node_list
  * Update crmsh/ui_cluster.py
  * Dev: unittest: Adjust unit test for previous changes
  * Dev: behave: adjust functional test based on previous changes
  * Dev: doc: remove cluster add in doc
  * Dev: bootstrap: remove cluster add sub-command
  * Fix: bootstrap: -N option setup the current node and peers all together (bsc#1175863)
* Mon Jul 11 2022 XLiang@suse.com
- Update to version 4.4.0+20220711.573ebb98:
  * Dev: parallax: Add strict option to avoid raise exception when set to False
* Fri Jul  8 2022 XLiang@suse.com
- Update to version 4.4.0+20220708.6ed6b56f:
  * Fix: utils: use -o and -n to compare files instead of strings for crm_diff (bsc#1201312)
* Tue Jul  5 2022 XLiang@suse.com
- Update to version 4.4.0+20220705.bb8708eb:
  * Dev: CI: trigger CI on push and pull request for all branches
* Fri Jun 24 2022 XLiang@suse.com
- Update to version 4.4.0+20220624.7b89db34:
  * Dev: log: Add replacement fields in str format
* Thu Jun 23 2022 XLiang@suse.com
- Update to version 4.4.0+20220623.6b256b4b:
  * Dev: behave: adjust functional test based on previous changes
  * Dev: ui_cluster: Add examples for 'cluster init' and 'cluster join'
* Sun Jun 19 2022 XLiang@suse.com
- Update to version 4.4.0+20220619.cc0a81a5:
  * Dev: CI: Run delivery and submit stage only at ClusterLabs/crmsh repo
* Tue Jun 14 2022 XLiang@suse.com
- Update to version 4.4.0+20220614.f76fee26:
  * Dev: doc: add help info for related: prefix for 'configure show' command
  * Dev: cinconfig: enable "related:" prefix to show the objects by given ra type
* Fri Jun 10 2022 XLiang@suse.com
- Update to version 4.4.0+20220610.16cc8d68:
  * Fix: crm report: use sudo when under non root and hacluster user (bsc#1199634)
* Wed Jun  1 2022 XLiang@suse.com
- Update to version 4.4.0+20220601.b8c2952f:
  * Dev: ui_cluster: Update help for deprecated --no-overwrite-sshkey option
* Wed Jun  1 2022 XLiang@suse.com
- Update to version 4.4.0+20220601.da41ffc3:
  * Fix: utils: wait4dc: Make change since output of 'crmadmin -S' changed(bsc#1199412)
  * Dev: unittest: Adjust unit test for previous changes
  * Fix: bootstrap: stop and disable csync2.socket on removed node (bsc#1199325)
* Thu May  5 2022 XLiang@suse.com
- Update to version 4.4.0+20220505.a3a00365:
  * Dev: unittest: Adjust unit test for previous changes
  * Fix: crm report: Read data in a save way, to avoid UnicodeDecodeError(bsc#1198180)
* Mon Apr 18 2022 XLiang@suse.com
- Update to version 4.4.0+20220418.cbf7a09e:
  * Dev: README: update README
  * Dev: remove unused files
  * Dev: behave: Change behave test files based on new added "run-functional-tests"
  * Dev: run-functional-tests: Add file run-functional-tests
  * Dev: Dockerfile: Update Dockerfile used by crmsh CI for master branch
* Mon Mar 21 2022 XLiang@suse.com
- Update to version 4.4.0+20220321.8cf6a9d1:
  * Dev: Parametrize the log dir
* Mon Mar 21 2022 XLiang@suse.com
- Update to version 4.4.0+20220321.aa92b3f0:
  * Dev: unittest: Add unit test for previous changes
  * Dev: behave: Add functional test for the scenario one qnetd for multi cluster
  * Dev: ui_cluster: Check if qdevice can contribute vote
  * Dev: qdevice: Improve remove qdevice process
  * Dev: qdevice: Add lock to protect for the same cluster name
  * Fix: qdevice: Add lock to protect init_db_on_qnetd function (bsc#1197323)
  * Dev: qdevice: Consolidate qdevice related separate functions into qdevice.QDevice class
  * Dev: lock: Make lock.py more generic
  * Dev: qdevice: Add cluster name suffix to qdevice-net-node.crq on qnet
  * Dev: qdevice: remove askpass since it's unnecessary after passwordless configured on qnetd
* Mon Mar 21 2022 XLiang@suse.com
- Update to version 4.4.0+20220321.fceabc07:
  * Dev: utils: Remove duplicated debug message
* Fri Mar 18 2022 XLiang@suse.com
- Update to version 4.4.0+20220318.7f434a3b:
  * medium: utils: update detect_cloud pattern for aws
* Mon Mar  7 2022 XLiang@suse.com
- Update to version 4.4.0+20220307.347f815c:
  * Dev: testcases: Update expected testcase with pacemaker update
  * Fix: utils: Only raise exception when return code of systemctl command over ssh larger than 4 (bsc#1196726)
* Thu Feb 17 2022 XLiang@suse.com
- Update to version 4.4.0+20220217.b8f67f4e:
  * Dev: configure.ac: update version as 4.4.0
  * Update ChangeLog for release 4.4.0
* Wed Feb  9 2022 XLiang@suse.com
- Update to version 4.4.0+20220209.0eb4fa28:
  * Dev: remove unused files for origin unit tests way
  * Dev: setup.py: update install requires
  * Dev: README: update with unit tests steps
  * Dev: crmsh-ci.yml: Add python3.6 and 3.10 into unit test list
  * Dev: tox: Adjust tox.ini, add py36 and py310 in envlist
* Tue Feb  8 2022 XLiang@suse.com
- Update to version 4.4.0+20220208.5e6dca1d:
  * Dev: unittest: Adjust unit test for previous changes
  * Fix: sbd: not overwrite SYSCONFIG_SBD and sbd-disk-metadata if input 'n'(bsc#1194870)
* Tue Feb  8 2022 XLiang@suse.com
- Update to version 4.4.0+20220208.84dd4fdd:
  * Dev: bootstrap: the joining node retries an active cluster
  * Dev: behave: Change docker cgroup driver as systemd
  * doc: Website: Add 4.3.1 release note
  * doc: Website: Upload crmsh 4.3.x doc
* Tue Jan 25 2022 XLiang@suse.com
- Update to version 4.4.0+20220125.d0150a88:
  * Dev: ui_node: Use diff and patch instead of replace cib
* Tue Jan 18 2022 XLiang@suse.com
- Update to version 4.4.0+20220118.5d56321b:
  * Dev: crm report: Add dpkg support
* Mon Jan 17 2022 XLiang@suse.com
- Update to version 4.4.0+20220117.3debc274 (tag:4.4.0-rc1):
  * Fix: adapt report to pacemaker daemon name change
* Fri Jan 14 2022 XLiang@suse.com
- Update to version 4.3.1+20220114.29185644:
  * Dev: ChangeLog: update for the recent releases
  * Dev: update version setup.py
* Fri Jan 14 2022 XLiang@suse.com
- Update to version 4.3.1+20220114.07d84c75:
  * Dev: unittest: Adjust unit test for previous change
  * Fix: bootstrap: Don't change pacemaker.service bootup preference (bsc#1194616)
* Fri Jan 14 2022 XLiang@suse.com
- Update to version 4.3.1+20220114.2726e007:
  * Fix: log: Change the log file owner as hacluster:haclient (bsc#1194619)
  * Fix: crash_test: Adjust help output of 'crm cluster crash_test -h'(bsc#1194615)
* Fri Jan 14 2022 XLiang@suse.com
- Update to version 4.3.1+20220114.2003afd7:
  * Dev: crm.conf: Add OCF_1_1_SUPPORT flag to control ocf 1.1 feature
  * Dev: doc: Introduce promotable clone and role Promoted/Unpromoted
  * Dev: behave: Adjust functional test for previous changes
  * Dev: unittest: Add unit test for previous changes
  * Dev: utils: Convert Master/Slave to Promoted/Unpromoted if schema support OCF 1.1
  * Dev: xmlutil: Replace Promoted/Unpromoted as Master/Slave when OCF 1.0 schema detected
  * Dev: doc: Replace pingd as ocf:pacemaker:ping
  * Dev: ui_resource: set target-role as Promoted/Unpromoted when doing promote or demote
  * Dev: ra: Support Promoted/Unpromoted
* Wed Jan 12 2022 XLiang@suse.com
- Update to version 4.3.1+20220112.a945df76:
  * Dev: unittest: Adjust unit test for previous changes
  * Dev: ocfs2: Fix running ocfs2 stage on cluster with diskless-sbd
* Wed Jan 12 2022 XLiang@suse.com
- Update to version 4.3.1+20220112.6245c22e:
  * Dev: behave: Add functional test for the new added -U option
  * Fix: bootstrap: Change default transport type as udpu(unicast) (bsc#1132375)
* Tue Jan  4 2022 XLiang@suse.com
- Update to version 4.3.1+20220104.b683bf0d:
  * Dev: bootstrap: Avoid duplicated setting for rsc_defaults
* Wed Dec 29 2021 XLiang@suse.com
- Update to version 4.3.1+20211229.ace94b1f:
  * Dev: testcase: Adjust original testcase based on previous changes
  * Fix: ui_configure: Give a deprecated warning when using "ms" subcommand (bsc#1194125)
  * Fix: xmlutil: Parse promotable clone correctly and also consider compatibility (bsc#1194125)
* Fri Dec 24 2021 XLiang@suse.com
- Update to version 4.3.1+20211224.922207f9:
  * Dev: doc: Rename hb_report as crm report
  * Dev: crm report: Get distribution info correctly and reuse it
  * Dev: behave: Change in functional test for previous crm report changes
  * Dev: crm_report: Integrate report log into crmsh logging
  * Dev: crm_report: Move hb_report directory to crmsh/report
* Fri Dec 24 2021 XLiang@suse.com
- Update to version 4.3.1+20211224.05c264ee:
  * Dev: log: Print new line when input using default value in interactive mode
* Fri Dec 24 2021 XLiang@suse.com
- Update to version 4.3.1+20211224.bfa7e2d9:
  * Fix: bootstrap: Change log info when need to change user login shell (bsc#1194026)
* Wed Dec 22 2021 XLiang@suse.com
- Update to version 4.3.1+20211222.9360f963:
  * Dev: doc: Mention /etc/crm/profiles.yml in man crm
* Fri Dec 17 2021 XLiang@suse.com
- Update to version 4.3.1+20211217.5d8f3f90:
  * Dev: ui_node: Delete node directly using cibadmin if crm_node -R failed
  * Dev: testcases: adjust origin testcases for OCF 1.1 update
  * Dev: behave: Change CI image as Tumbleweed
* Wed Dec 15 2021 XLiang@suse.com
- Update to version 4.3.1+20211215.85834218:
  * Dev: unittest: Adjust unit test based on previous changes
  * Dev: xmlutil: Add class CrmMonXmlParser to parse xml output of crm_mon
* Fri Dec 10 2021 XLiang@suse.com
- Update to version 4.3.1+20211210.a149de51:
  * Dev: unittest: adjust unit test based on previous changes
  * Dev: behave: adjust functional test based on previous changes
  * Dev: ui_cluster: Exit stop process when there is no DC
  * Dev: ui_cluster: check dlm controld ra is running when stop cluster
  * Dev: log: In status_long function, add a blank line when exception
  * Revert "Dev: ui_cluster: Make sure node is online when stop service"
* Mon Dec  6 2021 XLiang@suse.com
- Update to version 4.3.1+20211206.e34e2fff:
  * Dev: unittest: Add unit test for previous changes
  * Dev: behave: Add functional test for previous changes and cases
  * Dev: sbd: Adjust timeout related values
* Mon Dec  6 2021 XLiang@suse.com
- Update to version 4.3.1+20211206.894f84bb:
  * Dev: unittest: Adjust unit test based on previous changes
  * Dev: ui_cluster: check if qdevice service started when starting cluster if qdevice configured
  * Dev: ui_cluster: Remove node from node list if node is unreachable
* Fri Dec  3 2021 XLiang@suse.com
- Update to version 4.3.1+20211203.5b4e12b3:
  * Dev: idmgmt: Avoid leading with number for ID
  * Dev: ui_node: Improve node standby/online methods
* Fri Dec  3 2021 XLiang@suse.com
- Update to version 4.3.1+20211203.9b8a9910:
  * Dev: ui_cluster: Check service is available before enable/disable qdevice
* Fri Dec  3 2021 XLiang@suse.com
- Update to version 4.3.1+20211203.9786bf28:
  * Dev: unittest: Adjust unit test based on previous changes
  * Dev: Give warning when no-quorum-policy not set as freeze while using DLM
* Mon Nov 29 2021 XLiang@suse.com
- Update to version 4.3.1+20211129.a8e22584:
  * Fix: crm: To avoid the potential "permission denied" error under other users (boo#1192754)
* Fri Nov 19 2021 XLiang@suse.com
- Update to version 4.3.1+20211119.caa0b2aa:
  * Dev: behave: Add functional test for previous changes
  * Fix: ui_resource: Parse node and lifetime correctly (bsc#1192618)
* Tue Nov 16 2021 XLiang@suse.com
- Update to version 4.3.1+20211116.ef2bce26:
  * Dev: unittest: Add unit test for previous changes
  * Dev: testcase: Remove node standby/online test case
  * Dev: behave: Rename features/steps/step_implenment.py as features/steps/step_implementation.py
  * Dev: behave: Add functional test for previous changes
  * Dev: doc: Consolidate help info for those using argparse
  * Dev: ui_cluster: Make sure node is online when stop service
  * Dev: ui_cluster: Graceful shutdown dlm
  * Dev: ui_cluster: Support multi sub-commands with --all option or specific node
* Mon Nov  1 2021 XLiang@suse.com
- Update to version 4.3.1+20211101.7cafcfec:
  * Dev: log: Rotate crmsh.log as 1M and backup count as 10
* Sun Oct 31 2021 XLiang@suse.com
- Update to version 4.3.1+20211027.23b53526:
  * orderedset.py: fix deprecation on collections.MutableSet
* Mon Oct 25 2021 XLiang@suse.com
- Update to version 4.3.1+20211025.56a913a8:
  * Dev: behave: small improve for previous case
  * Dev: crm report: Consolidate collect functions in collect.py and running them in parallel
  * Dev: crm report: Collect report using multiprocessing correctly
* Tue Oct 12 2021 XLiang@suse.com
- Update to version 4.3.1+20211012.4e74e9d1:
  * Dev: testcases: Change origin testcases for previous change
  * Dev: CI: change docker image as leap 15.2, and enlarge the timeout value for each CI case
  * Fix: ui_resource: Parse lifetime option correctly (bsc#1191508)
* Thu Sep 16 2021 XLiang@suse.com
- Update to version 4.3.1+20210916.1b3e21cc:
  * Dev: unittest: Change unit test for previous changes
  * Fix: bootstrap: Add /etc/crm/crm.conf and /etc/crm/profiles.yml into /etc/csync2/csync2.cfg (bsc#1190466)
* Mon Sep 13 2021 XLiang@suse.com
- Update to version 4.3.1+20210913.d7356663:
  * Dev: testcases: origin testcases change for using logging in crmsh
  * Dev: behave: functional test change for using logging in crmsh
  * Dev: unittest: Change unit test since changed as logging
  * Dev: Using python logging in all crmsh modules
  * Dev: hb_report: Integrate hb_report logging
  * Dev: crash_test: Integrate crash test logging
  * Dev: crm: Load python logging config in /usr/sbin/crm
  * Dev: log: Using logging as log system in crmsh
  * Dev: msg: Remove msy.py
  * Dev: constants: Add color const for logging
* Tue Sep  7 2021 XLiang@suse.com
- Update to version 4.3.1+20210907.58e47776:
  * Dev: unittest: Adjust unit test for previous changes
  * Fix: utils: Improve detect_cloud function and support non-Hyper-V in Azure
* Fri Aug 27 2021 XLiang@suse.com
- Update to version 4.3.1+20210827.1ae49236:
  * Fix: hb_report: Using python way to collect ra trace files (bsc#1189641)
* Fri Aug 27 2021 XLiang@suse.com
- Update to version 4.3.1+20210827.4e4e83b3:
  * Fix: bootstrap: adjust host list for parallax to get and copy known_hosts file(bsc#1188971)
* Wed Aug 11 2021 XLiang@suse.com
- Update to version 4.3.1+20210811.4045e09d:
  * Dev: unittest: Add unit test for previous changes
  * Fix: bootstrap: Adjust corosync and sbd parameters according to the profile environment detected (bsc#1175896)
  * Fix: sbd: adjust sbd systemd TimeoutStartSec together with SBD_DELAY_START
  * Dev: Makefile: add etc/profiles.yml and move crm.conf.in into etc
* Thu Aug  5 2021 XLiang@suse.com
- Update to version 4.3.1+20210805.18f9a8c1:
  * Fix: doc: Note that resource tracing is only supported by OCF RAs(bsc#1188966)
  * Dev: testcases: adjust expected output for previous changes
  * Dev: ui_resource: Enhancement trace output
* Wed Jul 28 2021 XLiang@suse.com
- Update to version 4.3.1+20210728.8029db25:
  * Medium: ra: performance/usability improvement (avoid systemd)
* Mon Jul 26 2021 XLiang@suse.com
- Update to version 4.3.1+20210726.3de6f304:
  * Dev: testcases: adjust some testcases expected output due to previous change
  * Dev: ui_context: Add info when spell-corrections happen
* Mon Jul 19 2021 XLiang@suse.com
- Update to version 4.3.1+20210719.c45a9f5d:
  * Dev: unittest: adjust unit test for previous changes
  * Dev: ocfs2: set no-quorum-policy as freeze when configuring OCFS2
* Wed Jul 14 2021 XLiang@suse.com
- Update to version 4.3.1+20210714.57de51d5:
  * Fix: parse: Should still be able to show the empty property if it already exists(bsc#1188290)
* Mon Jul  5 2021 XLiang@suse.com
- Update to version 4.3.1+20210705.b2ba54f9:
  * Dev: unittest: Adjust unit test code for qdevice.py
  * Dev: qdevice: Split class QDevice into qdevice.py from corosync.py
* Fri Jul  2 2021 XLiang@suse.com
- Update to version 4.3.1+20210702.314a7eb4:
  * Fix: resource: make untrace consistent with trace (bsc#1187396)
* Wed Jun 30 2021 XLiang@suse.com
- Update to version 4.3.1+20210630.bff856e3:
  * Fix: bootstrap: check for missing fields in 'crm_node -l' output (bsc#1182131)
* Mon Jun 28 2021 XLiang@suse.com
- Update to version 4.3.1+20210628.3128d590:
  * Dev: unittest: add unit test for previous changes
  * Dev: sbd: enable SBD_DELAY_START in virtualization environment
* Thu Jun 24 2021 XLiang@suse.com
- Update to version 4.3.1+20210624.c64d3a07:
  * Dev: unittest: adjust unit test for ocfs2.py
  * Fix: ocfs2: Skip verifying UUID for ocfs2 device on top of raid or lvm on the join node (bsc#1187553)
* Tue Jun 22 2021 XLiang@suse.com
- Update to version 4.3.1+20210622.f66c274b:
  * Dev: unittest: Adjust unit test code for previous changes
  * Dev: sbd: Split class SBDManager into sbd.py from bootstrap.py
* Thu Jun 17 2021 XinLiang <XLiang@suse.com>
- Update to version 4.3.1+20210617.00ec6905:
  * Bump package version as 4.3.1
  * Dev: ChangeLog: update for the recent releases
* Wed Jun 16 2021 XLiang@suse.com
- Update to version 4.3.0+20210616.cdcfe52e:
  * Dev: testcases: adjust origin testcases for previous change
  * Fix: history: use Path.mkdir instead of mkdir command(bsc#1179999, CVE-2020-35459)
  * Dev: unittest: adjust unit test for preflight check change to crash test
  * Dev: doc: replace preflight check doc as crash test doc
  * Dev: crash_test: Add big warnings to have users' attention to potential failover
  * Dev: crash_test: rename preflight_check as crash_test
* Thu Jun 10 2021 XLiang@suse.com
- Update to version 4.3.0+20210610.0e0d05fc:
  * Dev: unittest: adjust unit test for previous changes
  * Fix: bootstrap: update sbd watchdog timeout when using diskless SBD with qdevice(bsc#1184465)
* Thu Jun 10 2021 XLiang@suse.com
- Update to version 4.3.0+20210610.c7eb914f:
  * Dev: utils: allow configure link-local ipv6 address
  * Dev: bootstrap: return when not specify ocfs2 device on interactive mode
* Mon Jun  7 2021 XLiang@suse.com
- Update to version 4.3.0+20210607.41a0731e:
  * Fix: parse: shouldn't allow property setting with an empty value(bsc#1185423)
* Mon May 31 2021 XLiang@suse.com
- Update to version 4.3.0+20210526.aa5f3385:
  * Dev: behave: add more descriptions for subcommands to pass the test
  * Dev: crm.8.adoc: remove redundant help message
  * Fix: help: show help message from argparse(bsc#1175982)
* Tue May 25 2021 XLiang@suse.com
- Update to version 4.3.0+20210525.8fd84a2e:
  * Dev: behave: add functional test for ocfs2 configure process
  * Dev: unittest: add unit test for ocfs2 related codes
  * Dev: ocfs2: add ocfs2.OCFS2Manager to manage ocfs2 configure process
* Tue May 18 2021 XLiang@suse.com
- Update to version 4.3.0+20210518.46a0704a:
  * Dev: cibconfig: resolve TypeError for fencing-topology tag
* Mon May 10 2021 XLiang@suse.com
- Update to version 4.3.0+20210510.2775a5e2:
  * Dev: unittest: move watchdog unit test code into test_watchdog.py
  * Dev: watchdog: split class Watchdog into watchdog.py from bootstrap.py
* Fri May  7 2021 XLiang@suse.com
- Update to version 4.3.0+20210507.bf02d791:
  * Dev: bootstrap: raise exception and execute status_done on success
* Fri May  7 2021 XLiang@suse.com
- Update to version 4.3.0+20210507.2bbd169d:
  * Dev: unittest: adjust unittest for previous changes
  * Dev: behave: add functional test for adding sbd on running cluster
  * Dev: unittest: adjust unit test for adding sbd on existing cluster
  * Fix: bootstrap: add sbd via bootstrap stage on an existing cluster (bsc#1181906)
  * Fix: bootstrap: change StrictHostKeyChecking=no as a constants(bsc#1185437)
* Thu May  6 2021 XLiang@suse.com
- Update to version 4.3.0+20210506.8cee9321:
  * Dev: unittest: adjust unit test for the change of status_long
  * Dev: bootstrap: change status_long with contextmanager
* Fri Apr 16 2021 XLiang@suse.com
- Update to version 4.3.0+20210416.49f489c2:
  * Dev: unittest: add unit test code for query_qdevice_status functiona
  * Dev: add "crm corosync status qdevice" sub-command
* Wed Apr 14 2021 XLiang@suse.com
- Update to version 4.3.0+20210414.d22dd892:
  * Dev: unittest: adjust unit test for disable sbd warning
  * Dev: bootstrap: disable unnecessary warnings (bsc#1178118)
* Mon Apr 12 2021 XLiang@suse.com
- Update to version 4.3.0+20210412.7d40b39d:
  * Dev: unittest: adjust unit test code according to previous commit
  * Fix: bootstrap: sync corosync.conf before finished joining(bsc#1183359)
* Thu Apr  8 2021 XLiang@suse.com
- Update to version 4.3.0+20210408.270d14c2:
  * Dev: behave: adjust functional test for qdevice help change
  * Dev: ui_cluster: add qdevice help info
* Tue Mar 30 2021 XLiang@suse.com
- Update to version 4.3.0+20210330.06bf9cad:
  * Dev: ui_cluster: enable/disable corosync-qdevice.service
* Mon Mar 29 2021 XLiang@suse.com
- Update to version 4.3.0+20210329.61da557d:
  * Dev: unittest: adjust unit test for parsing space in sbd devices
  * Fix: bootstrap: parse space in sbd device correctly(bsc#1183883)
* Mon Mar 29 2021 XLiang@suse.com
- Update to version 4.3.0+20210329.675e8981:
  * Dev: unittest: adjust unit test for preflight_check since its path changed
  * Dev: preflight_check: move preflight_check directory into crmsh
* Mon Mar 29 2021 XinLiang <XLiang@suse.com>
- Update to version crmsh-4.3.0+20210323.086cc4a3
  * Change the package format
* Tue Mar 23 2021 XLiang@suse.com
- Update to version 4.3.0+git.20210323.086cc4a3:
  * Dev: behave: add functional test for changing /etc/hosts
  * Dev: unittest: adjust unit test for get_cluster_node_hostname change
  * Fix: bootstrap: get the peer node name correctly (bsc#1183654)
* Fri Mar 19 2021 XLiang@suse.com
- Update to version 4.3.0+git.20210319.b0adc897:
  * Fix: update verion and author (bsc#1183689)
* Wed Mar 17 2021 XLiang@suse.com
- Update to version 4.3.0+git.20210317.5ee12f25:
  * Dev: behave: adjust functional test for configuring qdevice on interactive mode
  * Dev: unittest: unit test codes for configuring qdevice on interactive mode
  * Dev: bootstrap: enable configuring qdevice on interactive mode
* Mon Mar 15 2021 XLiang@suse.com
- Update to version 4.3.0+git.20210315.5d07d43e:
  * Dev: behave: change the test case for failcount behavior change
  * Fix: ui_resource: change return code and error to warning for some unharmful actions(bsc#1180332)
* Mon Mar 15 2021 XLiang@suse.com
- Update to version 4.3.0+git.20210315.fae29920:
  * Dev: README: change the build status link in README
* Mon Mar 15 2021 XLiang@suse.com
- Update to version 4.3.0+git.20210311.c2e8856c:
  * Dev: behave: change functional test about lock directory
  * Dev: unittest: change lock directory as constant in ut code
  * Dev: lock: change lock directory under /run
  * Dev: unittest: adjust unittest for diskless SBD warning codes
  * Fix: bootstrap: raise warning when configuring diskless SBD with node's count less than 3(bsc#1181907)
  * Dev: unittest: Adjust unit test since qdevice code changed
  * Dev: behave: Add functional test for qdevice add/remove on a single node cluster
  * Fix: bootstrap: Adjust qdevice configure/remove process to avoid race condition due to quorum lost(bsc#1181415)
  * Dev: utils: remove unused utils.cluster_stack and its related codes
  * Dev: cibconfig: remove related code about detecting crm_diff support --no-verion
  * Fix: ui_configure: raise error when params not exist(bsc#1180126)
  * Dev: doc: remove doc for crm node status
  * Dev: ui_node: remove status subcommand
  * Fix: hb_report: walk through hb_report process under hacluster(CVE-2020-35459, bsc#1179999; CVE-2021-3020, bsc#1180571)
  * Dev: unittest: add unit test for authorized ssh access for hacluster
  * Fix: bootstrap: setup authorized ssh access for hacluster(CVE-2020-35459, bsc#1179999; CVE-2021-3020, bsc#1180571)
* Fri Feb 19 2021 XLiang@suse.com
- Update to version 4.3.0+git.20210219.811c32f0:
  * Dev: unittest: adjust unit test for analyze sublevel
  * Dev: doc: add analyze and preflight_check help messages in doc
  * Dev: analyze: Add analyze sublevel and put preflight_check in it
* Tue Feb  9 2021 XLiang@suse.com
- Update to version 4.2.0+git.1612860179.982502ba:
  * Dev: utils: change default file mod as 644 for str2file function
* Fri Jan 29 2021 XLiang@suse.com
- Update to version 4.2.0+git.1611885080.8dea33ff:
  * Dev: unittest: adjust unittest for error message when raise ClaimLockError
  * Dev: hb_report: Detect if any ocfs2 partitions exist
  * Dev: lock: give more specific error message when raise ClaimLockError
* Tue Jan 26 2021 XLiang@suse.com
- Update to version 4.2.0+git.1611641933.1ccbf10a:
  * Dev: unittest: unit test for lsof_ocfs2_device function
  * Fix: hb_report: run lsof with specific ocfs2 device(bsc#1180688)
* Mon Jan 25 2021 XLiang@suse.com
- Update to version 4.2.0+git.1611543254.8c7eb168:
  * Fix: Replace mktemp() to mkstemp() for security
  * Dev: unit test cases for preflight check ASR SBD feature utils.py
  * Fix: Remove the duplicate --cov-report html in tox.
  * Dev: unit test cases for preflight check ASR SBD feature check.py and task.py
  * Fix: fix some lint issues.
  * Fix: Replace utils.msg_info to task.info
  * Fix: Solve a circular import error of utils.py
* Thu Jan 21 2021 XLiang@suse.com
- Update to version 4.2.0+git.1611201540.a1006e39:
  * Dev: corosync: change the permission of corosync.conf to 644
* Wed Jan 20 2021 XLiang@suse.com
- Update to version 4.2.0+git.1611106206.1586ae99:
  * Dev: unittest: add unit test codes for preflight_check
  * Fix: preflight_check: task: raise error when report_path isn't a directory
* Mon Jan 18 2021 XLiang@suse.com
- Update to version 4.2.0+git.1610961380.fc379403:
  * Dev: unittest: unit test for bootstrap.Watchdog class
  * Dev: behave: functional test for bootstrap.Watchdog class
  * Fix: bootstrap: Use class Watchdog to simplify watchdog config(bsc#1154927, bsc#1178869)
  * Dev: Polish the sbd feature.
  * Dev: Replace -f with -c and run check when no parameter provide.
  * Fix: Fix the yes option not working
  * Fix: Remove useless import and show help when no input.
  * Dev: Correct SBD device id inconsistenc during ASR
* Tue Jan 12 2021 XLiang@suse.com
- Update to version 4.2.0+git.1610410636.fef21a41:
  * Dev: unittest: add unit test for sbd uuid related codes
  * Fix: bootstrap: make sure sbd device UUID was the same between nodes(bsc#1178454)
* Fri Jan  8 2021 XLiang@suse.com
- Update to version 4.2.0+git.1610068052.ef5f2e6c:
  * Fix: completers: return complete start/stop resource id list correctly(bsc#1180137)
  * Dev: Makefile.am: change makefile to integrate preflight_check
  * Medium: integrate preflight_check into crmsh
* Thu Jan  7 2021 XLiang@suse.com
- Update to version 4.2.0+git.1609987436.0d3a9bf5:
  * Dev: unittest: add test data for possible tun0 interface
  * Fix: utils: skip if no netmask in the result of ip -o addr show(bsc#1180421)
* Tue Dec 29 2020 XLiang@suse.com
- Update to version 4.2.0+git.1609212218.f5948b3b:
  * Fix: bootstrap: add /etc/modules-load.d/watchdog.conf into csync.cfg(bsc#1180424)
* Mon Dec 28 2020 XLiang@suse.com
- Update to version 4.2.0+git.1609145188.39d42c2e:
  * Dev: unittest: adjust unit test for bootstrap.invoke change
  * Low: bootstrap: make invoke return specific error(bsc#1177023)
* Thu Dec 24 2020 XLiang@suse.com
- Update to version 4.2.0+git.1608798184.58fd399e:
  * Dev: test: add timeout-minutes to each test job
* Wed Dec 23 2020 XLiang@suse.com
- Update to version 4.2.0+git.1608715188.e14964a8:
  * Dev: behave: adjust functional test for scenarios in lock.py
  * Dev: unittest: add unit test for lock.py
  * Fix: bootstrap: Refactor join_lock.py for more generic using purpose
* Wed Dec 16 2020 XLiang@suse.com
- Update to version 4.2.0+git.1608108646.71447e68:
  * Dev: unittest: adjust unit test for utils.ping_node
  * Dev: bootstrap: use ping to test host is reachable before joining
* Tue Dec 15 2020 XLiang@suse.com
- Update to version 4.2.0+git.1608018611.d57681b8:
  * Dev: unittset: adjust unit test code for setup_passwordless_with_other_nodes function
  * Low: bootstrap: check cluster was running on init node
* Fri Dec  4 2020 XLiang@suse.com
- Update to version 4.2.0+git.1607075079.a25648d8:
  * Dev: unittest: unit test code for class bootstrap.JoinLock
  * Fix: bootstrap: use class JoinLock to manage lock in parallel join(bsc#1175976)
* Tue Dec  1 2020 XLiang@suse.com
- Update to version 4.2.0+git.1606837217.bf7af3a6:
  * Dev: unittest: adjust ut for disable_service and enable_service changes
  * Fix: utils: improve disable_service and enable_service function(bsc#1178701)
* Mon Nov 16 2020 XLiang@suse.com
- Update to version 4.2.0+git.1605511823.7cff5ff0:
  * Dev: unittest: adjust unit test for disable corosync-qdevice
  * Fix: bootstrap: disable corosync-qdevice if not configured(bsc#1178701)
* Thu Nov 12 2020 XLiang@suse.com
- Update to version 4.2.0+git.1605167067.631c7f2c:
  * Dev: hb_report: change the default dest data format, more readable
* Tue Nov 10 2020 XLiang@suse.com
- Update to version 4.2.0+git.1604973283.791bdb4c:
  * Dev: unittest: add unit test for _get_sbd_device_interactive function
  * Low: bootstrap: minor change for _get_sbd_device_interactive function(bsc#1178333)
* Mon Nov  9 2020 XLiang@suse.com
- Update to version 4.2.0+git.1604900699.29415625:
  * Low: bootstrap: should include /etc/sysconfig/nfs into csync2.cfg(bsc#1178373)
* Fri Oct 30 2020 XLiang@suse.com
- Update to version 4.2.0+git.1604052559.2a348644:
  * Dev: behave: collect corosync.log if it defined in config file
  * Fix: hb_report: collect corosync.log if it defined in config file(bsc#1148874)
  * Dev: unittest: remove .travis.yml
  * Dev: unittest: remove test case which might rely on runtime environment
  * Dev: unittest: Create .github/workflows/crmsh-ci.yml, to use github action
  * Dev: unittest: adjust duplicated test function name
* Tue Oct 27 2020 XLiang@suse.com
- Update to version 4.2.0+git.1603805337.0e19de06:
  * Dev: unittest: unit test for function do_start/do_stop
  * Fix: ui_cluster: check service status while start/stop(bsc#1177980)
* Tue Oct 27 2020 XLiang@suse.com
- Update to version 4.2.0+git.1603785356.e1de2810:
  * Dev: unittest: adjust unit test for stop_services change
  * Dev: bootstrap: stop service which is active, not which is available
* Wed Oct 21 2020 XLiang@suse.com
- Update to version 4.2.0+git.1603292079.8fae778b:
  * Dev: behave: verify hawk was stopped when removing node
  * Dev: unittest: adjust unit test for this PR#648
  * Fix: bootstrap: Stop hawk service when removing node(bsc#1175708)
* Tue Oct 20 2020 XLiang@suse.com
- Update to version 4.2.0+git.1603162937.49ce94a5:
  * Dev: unittest: adjust unit test for service management codes refactor
  * Dev: utils: Refactor service management code
* Tue Oct 20 2020 XLiang@suse.com
- Update to version 4.2.0+git.1603156877.5b81da60:
  * Fix: cibverify: give warning if crm_verify return warning(bsc#1122391)
  * Dev: behave: verify convert score to kind
  * Dev: unittest: unit test for score_to_kind function
  * Dev: doc: remove score related in doc for rsc_order configure
  * Fix: parse: convert score to kind for rsc_order configure(bsc#1122391)
* Wed Oct 14 2020 XLiang@suse.com
- Update to version 4.2.0+git.1602654994.34e0eeb6:
  * Dev: unittest: Unit test for related changes based on remove node bug
  * Dev: behave: functional test for bug of removing node(bsc#1165644)
  * Fix: bootstrap: remove specific configured address while removing node(bsc#1165644)
* Fri Oct  9 2020 XLiang@suse.com
- Update to version 4.2.0+git.1602225426.5f84efb5:
  * Dev: unittest: unit test for hb_report sanitize
  * Dev: behave: functional test for hb_report sanitize
  * Fix: hb_report: fix sanitize functionality(bsc#1163581)
* Thu Sep 24 2020 XLiang@suse.com
- Update to version 4.2.0+git.1600915005.e8089225:
  * FIx start_delay with start-delay
  * fix on_fail should be on-fail
* Tue Sep 22 2020 XLiang@suse.com
- Update to version 4.2.0+git.1600742357.6be225e5:
  * Low: config: Try to handle configparser.MissingSectionHeaderError while reading config file
  * Dev: behave: functional test for obscure sensitive data by default
  * Medium: ui_configure: Obscure sensitive data by default(bsc#1163581)
* Fri Sep 11 2020 XLiang@suse.com
- Update to version 4.2.0+git.1599810948.3db12a7a:
  * Dev: unittest: unit test for collect archived logs
  * Dev: behave: functional test for collect archived logs
  * Fix: hb_report: collect archived logs(bsc#1148873)
* Thu Sep 10 2020 XLiang@suse.com
- Update to version 4.2.0+git.1599702667.157fc6b5:
  * Dev: unittest: adjust unit test for checking sbd package installed
  * Low: bootstrap: check whether sbd package installed
  * Dev: unittest: Improve unit test for qdevice configuration
  * Dev: behave: Improve qdevice functional test
  * Low: bootstrap: Improve qdevice configure process * More reasonable naming for variables * More function docstrings * Move function to more reasonable location * Create functions to integrate similar functions inside one * Change big function to small one, more easier for unit test, like: * Refactor functions * Create utils.cluster_run_cmd function to avoid using crm cluster run directly in code
* Wed Sep  9 2020 XLiang@suse.com
- Update to version 4.2.0+git.1599639093.ba35c7d1:
  * Dev: unittest: adjust unittest for swap keys with other nodes when join_ssh
  * Low: bootstrap: swap keys with other nodes when join_ssh(bsc#1176178)
* Mon Aug 24 2020 XLiang@suse.com
- Update to version 4.2.0+git.1598257562.570eb99d:
  * Fix: bootstrap: revert ssh_merge function for compatibility(bsc#1175057)
  * Dev: behave: adjust functional test for sbd config process changes
  * Dev: unittest: adjust unit test cases for sbd config process changes
  * Fix: bootstrap: adjust sbd config process to fix bug on sbd stage(bsc#1175057)
* Tue Jul 28 2020 XLiang@suse.com
- Update to version 4.2.0+git.1595940615.c452cc00:
  * Dev: unittest: test the case which command "crm corosync status quorum" return code is 2
  * Dev: behave: use "crm corosync status quorum" to check the quorum status
  * Low: corosync: handle the return code of corosync-quorumtool correctly(bsc#1174588)
* Thu Jul 23 2020 XLiang@suse.com
- Update to version 4.2.0+git.1595517298.a06e892f:
  * Dev: unittest: append unit test for corosync status related codes
  * Low: ui_corosync: copy ssh key to qnetd while detect need password(bsc#1174385)
* Thu Jul  9 2020 XLiang@suse.com
- Update to version 4.2.0+git.1594286044.7a596d12:
  * Low: hb_report: Fix collecting of binary data (bsc#1166962)
* Wed Jul  8 2020 XLiang@suse.com
- Update to version 4.2.0+git.1594199184.309141ea:
  * Dev: unittest: unit test for ssh key configuration improvement
  * Dev: bahave: adjust based on ssh key configuration improvement
  * High: bootstrap: ssh key configuration improvement(bsc#1169581)
* Mon Jun 22 2020 XLiang@suse.com
- Update to version 4.2.0+git.1592790745.eaa14889:
  * Dev: behave: functional test for bootstrap network improvement
  * Dev: unittest: unit test for bootstrap network improvement
  * High: bootstrap: bootstrap network improvement
* Tue Jun  9 2020 XLiang@suse.com
- Update to version 4.2.0+git.1591686704.0b90c7c2:
  * Revert "Fix: bootstrap: crmsh use its own specific ssh key(bsc#1169581)"
  * Revert "Dev: hb_report: hb_report use crmsh key to ssh peer node"
  * Revert "Dev: behave: related changes for functional test for using crmsh ssh key"
  * Revert "Dev: unittest: related changes for unittest for using crmsh ssh key"
* Wed Jun  3 2020 XLiang@suse.com
- Update to version 4.2.0+git.1591141885.522c462b:
  * Low: cibconfig: Avoid adding the ID attribute to select_* nodes
* Tue May 19 2020 XLiang@suse.com
- Update to version 4.2.0+git.1589895691.2fba0323:
  * Dev: unittest: unit test for class SBDManager
  * Dev: behave: functional test for sbd functionalities
  * High: bootstrap: using class SBDManager for sbd configuration and management(bsc#1170037, bsc#1170999)
  * Dev: unittest: related changes for unittest for using crmsh ssh key
  * Dev: behave: related changes for functional test for using crmsh ssh key
  * Dev: hb_report: hb_report use crmsh key to ssh peer node
  * Fix: bootstrap: crmsh use its own specific ssh key(bsc#1169581)
* Wed May  6 2020 XLiang@suse.com
- Update to version 4.2.0+git.1588754732.bbb45e68:
  * Low: bootstrap: change ha-cluster-bootstrap log path
* Mon Apr 13 2020 XLiang@suse.com
- Update to version 4.2.0+git.1586769845.5cf0290e:
  * Low: ui_corosync: print cluster nodes while getting quorum and qnetd status
* Thu Apr  9 2020 XLiang@suse.com
- Update to version 4.2.0+git.1586427566.1acaafaf:
  * Low: bootstrap: exit with proper error messages when ssh return failed
* Tue Apr  7 2020 XLiang@suse.com
- Update to version 4.2.0+git.1586271789.976af135:
  * Dev: unittest: test interface_choice function
  * Low: ui_cluster: use argparse choices to validate -i and -t option
* Thu Apr  2 2020 XLiang@suse.com
- Update to version 4.2.0+git.1585823626.1dd5ce1f:
  * Low: corosync: Use with statement  to open file
  * Dev: unittest: change test_add_node_ucast to make whole test reentrant
* Tue Mar 31 2020 XLiang@suse.com
- Update to version 4.2.0+git.1585643641.b911e2f1:
  * Fix: ui_resource: refresh <Tab> should complete resource first(bsc#1167220)
* Mon Mar 30 2020 XLiang@suse.com
- Update to version 4.2.0+git.1585556306.3424694f:
  * Dev: behave: change for deprecated alias
  * Dev: testcases: change for deprecated alias
  * Low: ui_context: give warning if using alias command
  * Fix: doc: Update man page about completion example of crm resource(bsc#1166644)
* Fri Mar 27 2020 XLiang@suse.com
- Update to version 4.2.0+git.1585276059.882beb65:
  * Dev: behave: add functional test for geo cluster setup
  * Low: bootstrap: Simplify bootstrap context
* Wed Mar 25 2020 XLiang@suse.com
- Update to version 4.2.0+git.1585096577.f3257c89:
  * Dev: behave: Functional test for user case master survive
  * Dev: unittest: unittest for qdevice improvement
  * Dev: behave: functional test for qdevice imporvement
  * Low: corosync: Improve qdevice configure process
* Thu Mar 19 2020 XLiang@suse.com
- Update to version 4.2.0+git.1584623405.d39158a2:
  * Fix: bootstrap: Change condition to add stonith-sbd resource(bsc#1166967)
* Wed Mar 18 2020 XLiang@suse.com
- Update to version 4.2.0+git.1584528254.371d05b1:
  * Dev: bootstrap: binding interface when calling "crm cluster init"
* Mon Mar 16 2020 XLiang@suse.com
- Update to version 4.2.0+git.1584360067.097e3790:
  * Dev: unittest: unit test for changed function csync2_update
  * Dev: behave: functional test for scenarios of bsc#1166684
  * Fix: bootstrap: use csync2 '-f' option correctly(bsc#1166684)
* Thu Mar 12 2020 XLiang@suse.com
- Update to version 4.2.0+git.1584013187.b45cfcb6:
  * Low: setup.py: update crmsh's version
  * Fix: crmsh.spec.in: enable completion of crm command(bsc#1166329)
  * Low: crmsh.spec.in: sync contents from NHF's crmsh.spec file
* Tue Mar  3 2020 XLiang@suse.com
- Update to version 4.2.0+git.1583246906.f09ab45e:
  * Dev: testcases: update test output due to pacemaker update
* Tue Feb 18 2020 XLiang@suse.com
- Update to version 4.2.0+git.1581993539.5a1deb03:
  * Dev: behave: functional test for setup cluster with crossed network
  * Dev: unittest: test for get_peer_hostname/is_online/find_configured_ip functions
  * Dev: corosync: check whether local ip has already configured
  * Dev: bootstrap: check whether init node is online while joining
  * Dev: bootstrap: for udpu, don't check join node's ip was in the same network
* Sat Feb  1 2020 XLiang@suse.com
- Update to version 4.2.0+git.1580544897.c42c9530:
  * Low: unittest: add unit test to detect_cloud
* Fri Jan 31 2020 XLiang@suse.com
- Update to version 4.2.0+git.1580467952.1931808d:
  * Low: utils: update detect_cloud pattern for aws
* Wed Jan 29 2020 XLiang@suse.com
- Update to version 4.2.0+git.1580263559.a2b0f500:
  * scripts: python3.8 unittest compatibility
* Wed Jan 22 2020 XLiang@suse.com
- Update to version 4.2.0+git.1579603179.bf924b8b:
  * Low: testcases: adjust testcases based on related upstream version
  * Low: unittest: replace nose with pytest
  * Low: replace configparser.SafeConfigParser as configparser.ConfigParser
* Mon Jan 20 2020 XLiang@suse.com
- Update to version 4.2.0+git.1579517638.06d53d8a:
  * Low: doc: update configure.set documentation
  * Low: behave: functional test for configure.set subcommand
  * Feature: configure: make configure.set to update operation
* Mon Jan 13 2020 XLiang@suse.com
- Update to version 4.2.0+git.1578911004.c1a33535:
  * Dev: behave: Not allowed space value for option
  * Fix: ui_cluster: Not allowed space value for option (bsc#1141976)
* Fri Jan 10 2020 XLiang@suse.com
- Update to version 4.2.0+git.1578645670.4df2f015:
  * Dev: unittest: add unit test for dump_D_process function
  * Fix: hb_report: disable dump all tasks stack into dmesg(bsc#1158060)
* Fri Jan 10 2020 XLiang@suse.com
- Update to version 4.2.0+git.1578641542.ddda681c:
  * Dev: behave: varify help output for commands which replace as argparse
  * Dev: replace optparse with argparse
* Tue Jan  7 2020 XLiang@suse.com
- Update to version 4.2.0+git.1578400179.830baba1:
  * Dev: unittest: remove "placement-strategy=balanced" in ut codes
  * Dev: behave: test placement-strategy value is "default"
  * Fix: bootstrap: set placement-strategy value as "default"(bsc#1129462)
* Tue Jan  7 2020 XLiang@suse.com
- Update to version 4.2.0+git.1578389070.fb171448:
  * Fix: crmsh.spec: using mktemp to create tmp file(bsc#1154163)
* Tue Jan  7 2020 XLiang@suse.com
- Update to version 4.2.0+git.1578387778.867a085b:
  * Dev: bootstrap: Maximum number of SBD device is 3
  * Dev: bootstrap: improve multi disk sbd usability support both '-s device1 -s device2' and '-s "device1;device2"' improve the logic of code
* Fri Jan  3 2020 XLiang@suse.com
- Update to version 4.2.0+git.1578030883.465b4212:
  * dev: unittest: fix test_report.py failing in 2020
* Mon Dec 23 2019 XLiang@suse.com
- Update to version 4.2.0+git.1577086871.f544180c:
  * Update ChangeLog for 4.2.0
* Fri Dec 13 2019 XLiang@suse.com
- Update to version 4.1.0+git.1576228931.ae559358:
  * Dev: bootstrap: support multi disk sbd configure
* Wed Dec 11 2019 XLiang@suse.com
- Update to version 4.1.0+git.1576047267.d87652bb:
  * Dev: behave: functional test for resource failcount set subcommand
  * Low: unittest: add ut for utils.get_nodeid_from_name
  * Fix: ui_resource: set resource failcount correctly(bsc#1144241)
* Mon Dec  9 2019 XLiang@suse.com
- Update to version 4.1.0+git.1575875711.41d65be4:
  * Dev: ui_cluster: replace --qdevice as --qnetd-hostname
  * Dev: corosync: add log and debug messages on each certificate steps
  * Dev: Improvements on naming and class constants
  * Dev: behave: functional test for qdevice setup and options
  * Dev: behave: improve functional test for bootstrap process
  * Dev: ui_cluster: change qdevice related option's help message
  * Dev: utils: add is_unicast function to check transport type
  * Dev: corosync: use custom exception IPAlreadyConfiguredError for add_node_ucast
  * Dev: unittests: test corosync.Qdevice class
  * Dev: bootstrap: support qdevice heuristics
  * Dev: bootstrap: start qdevice/qnetd service when not overwrite configuration
  * Dev: ui_corosync: improve corosync status sub-command
  * Low: utils: refactor parallax_copy, parallax_call and parallax_slurp
  * Dev: bootstrap: remove qnetd
  * Dev: bootstrap: when removing qdevice, remove qdevice database
  * Dev: bootstrap: qdevice certification process when cluster join
  * Dev: ui_cluster: change option info for qdevice/qnetd
  * Dev: bootstrap: qdevice certification process when cluster init
  * Dev: bootstrap: interface for removing qdevice
  * Dev: corosync: check tie-breaker is a valid nodeid
  * Dev: bootstrap: combine Qdevice.valid2 into Qdevice.valid_attr
  * Dev: bootstrap: improve init_qdevice function
  * Dev: bootstrap: make update_expected_votes as outer function for reuse
  * Dev: bootstrap: write qdevice config section when configuring qdevice in stage
  * Dev: bootstrap: adjust corosync configuration for qdevice
  * Dev: bootstrap: make qdevice process as a bootstrap stage
  * Dev: bootstrap: manage qnetd node
  * Dev: bootstrap: valid qdevice parameters
* Wed Nov  6 2019 XLiang@suse.com
- Update to version 4.1.0+git.1573020742.a0b88227:
  * Test: unittest: test Parallax class
  * Dev: parallax: create class Parallax to simplify using parallax
* Thu Oct 31 2019 XLiang@suse.com
- Update to version 4.1.0+git.1572504697.472361c5:
  * Doc: ui_configure: do_property: ask to remove maintenance from resources and nodes
  * Test: ui_configure: do_property: ask to remove maintenance from resources and nodes
  * Dev: ui_configure: do_property: ask to remove maintenance from resources and nodes
* Tue Oct 29 2019 XLiang@suse.com
- Update to version 4.1.0+git.1572385946.69f4f51b:
  * Low: unittest: test init_ssh and init_ssh_remote in bootstrap.py
  * Low: bootstrap: create authorized_keys file if not exists
  * Low: bootstrap: add "--no-overwrite-sshkey" option to avoid SSH key be overwritten
  * Low: bootstrap: don't overwrite ssh key if already exists
* Tue Oct 29 2019 XLiang@suse.com
- Update to version 4.1.0+git.1572337494.6f2c8ea9:
  * Doc: ui_node: do_maintenance: ask to remove maintenance attr from primitives
  * Test: ui_node: do_maintenance: ask to remove maintenance attr from primitives
  * Dev: ui_node: do_maintenance: ask to remove maintenance attr from primitives
* Mon Oct 28 2019 XLiang@suse.com
- Update to version 4.1.0+git.1572251962.bc706121:
  * unittest: add unittest for corosync.add_node_ucast
  * Fix: corosync: reject append ipaddress to config file if already have(bsc#1127095, 1127096)
* Mon Oct 21 2019 dakechi@suse.com
- Update to version 4.1.0+git.1571645029.57177c5d:
  * Test: ui_resource: ask about ALL primitives when overriding attributes
  * Dev: ui_resource: ask about ALL primitives when overriding attributes
* Fri Sep 27 2019 dakechi@suse.com
- Update to version 4.1.0+git.1569593219.e357a9b9:
  * Fix: ui_cluster: refactor function list_cluster_nodes and handle the None situation(bsc#1145520)
* Fri Sep 27 2019 dakechi@suse.com
- Update to version 4.1.0+git.1569593061.35f57072:
  * High: cibconfig: Correctly sanitize the original CIB as patch base (bsc#1127716, bsc#1138405)
  * Revert "high: cibconfig: Use correct CIB as patch base (bsc#1127716)"
  * Partially revert "medium: cibconfig: Sanitize CIB for patching (bsc#1127716)"
* Tue Sep  3 2019 kgronlund@suse.com
- Update to version 4.1.0+git.1567524903.fff07b88:
  * Doc: ui_resource: resolve maintenance vs is-managed conflict
  * Test: ui_resource: resolve maintenance vs is-managed conflict
  * Dev: ui_resource: resolve maintenance vs is-managed conflict
* Tue Aug 27 2019 kgronlund@suse.com
- Update to version 4.1.0+git.1566912937.ad2608af:
  * Test: ui_resource: maintenance: stop using crm_resource
  * Dev: ui_resource: maintenance: stop using crm_resource
* Thu Aug 22 2019 dakechi@suse.com
- Update to version 4.1.0+git.1566462738.45748f84:
  * Revert "dev: Suggestion: Try to centralized command options in one file"
* Mon Aug 19 2019 dakechi@suse.com
- Update to version 4.1.0+git.1566218232.dbdf060c:
  * Fix: utils: fix logic for process non comments line(bsc#1145823)
  * Low: unittest: add unittest for bsc#1145823
* Tue Jul 16 2019 kgronlund@suse.com
- Update to version 4.1.0+git.1563261260.3b251242:
  * doc: manpages: Fix spelling
* Fri Jun 21 2019 dakechi@suse.com
- Update to version 4.1.0+git.1561107542.79593cb0:
  * Fix: utils: issue in to_ascii (bsc#1138115)
* Tue May 21 2019 kgronlund@suse.com
- Update to version 4.0.0+git.1558430233.89bb6eec:
  * Fix: bootstrap: bindnetaddr should accept both network and specific IP(bsc#1135585, bsc#1135586)
  * Fix: hb_report: analysis.txt should includes warning, error, critical messages(bsc#1135696)
  * medium: ui_node: Check corosync state before clearstate (bsc#1129702)
* Mon May 20 2019 kgronlund@suse.com
- Update to version 4.0.0+git.1558344349.9cd3669a:
  * fix: hb_report: handle UnicodeDecodeError(bsc#1130715)
  * setting error='replace' to replace invalid utf-8 characters
  * try to catch UnicodeDecodeError and print traceback
* Wed May  8 2019 kgronlund@suse.com
- Update to version 4.0.0+git.1557307618.dc73b57b:
  * medium: cibconfig: Sanitize CIB for patching (bsc#1127716)
  * high: cibconfig: Use correct CIB as patch base (bsc#1127716)
  * medium: parse: Detect and error on illegal ordering of op attributes (bsc#1129210)
  * medium: utils: Handle sysconfig values containing = (bsc#1129317)
  * low: hb_report: collect output of "sbd dump" and "sbd list"(bsc#1129383)
  * low: msg: add timestamp for DEBUG messages(bsc#1129380)
* Thu Mar 21 2019 XLiang@suse.com
- Update to version 4.0.0+git.1552985860.56f2db3a:
  * Fix: bsc#1129719: check command and related files exist
  * High: constants: add "promotable", "promoted-max" and "promoted-node-max" in clone meta attributes
  * Fix: cibconfig: #425 The ID attribute is not required for select and select_attributes
  * medium: scripts: Set kind for order constraints, not score (bsc#1123187)
  * low: utils: add support for dpkg
  * low: utils: add support for apt-get
  * low: utils: convert string contstants to bytes
  * Fix: bsc#1120857,1120856 bootstrap warning messages should better start with like "WARNING:" instead of "!"
  * Fix: bsc#1120554, bsc#1120555 crmsh crashed when using configure>template>apply
  * High: hbreport: fix UnicodeEncodeError while print(bsc#1093564)
* Wed Feb  6 2019 kgronlund@suse.com
- Avoid touching files to make build more reproducible
- Install bash completion to correct location
* Thu Dec  6 2018 kgronlund@suse.com
- Update to version 4.0.0+git.1543873923.0f9166fd:
  * medium: cibverify: Increase log level for verification (bsc#1116559)
* Wed Nov 14 2018 kgronlund@suse.com
- Update to version 4.0.0+git.1542103310.dd114188:
  * high: cibconfig: Normalize - to _ in param names (bsc#1111579)
  * medium: ra: Handle obsoletes attribute (bsc#1111579)
* Thu Nov  1 2018 kgronlund@suse.com
- Update to version 4.0.0+git.1540390310.315a48ed:
  * ui_cluster: restart cluster is added (bsc#1052088)
  * auto-commit enabling/disabling maintenance mode for a whole cluster (bsc#1112593)
* Mon Oct  8 2018 kgronlund@suse.com
- Update to version 4.0.0+git.1539006450.f80a6308:
  * medium: bootstrap: Skip netmask check on GCP (bsc#1106946)
  * medium: utils: Detect local IP on GCP (bsc#1106946)
* Tue Oct  2 2018 kgronlund@suse.com
- Update to version 4.0.0+git.1538492109.4b1170b0:
  * medium: bootstrap: Correctly check rrp_mode flag (bsc#1110463)
  * medium: bootstrap: Pick first match for multiple routes (bsc#1106946)
  * medium: utils: Use cloud metadata service to discover IP (bsc#1106946)
  * Fix: bootstrap: change default ip address way for both mcast and unicat(bsc#1109975,bsc#1109974)
* Wed Sep 26 2018 kgronlund@suse.com
- Update to version 4.0.0+git.1537967262.68a0bd1e:
  * Fix incorrect bindnetaddr in corosync.conf (bsc#1103833) (bsc#1103834)
* Tue Sep 25 2018 kgronlund@suse.com
- Update to version 4.0.0+git.1537860833.be41d63c:
  * fix: bootstrap: non interactive unicast cluster init and join(bsc#1109172)
  * medium: bootstrap: Disable strict host key checking on all ssh invocations
  * medium: support ocfs2 log collecting
  * hbreport: process name change for pacemaker 2.0(bsc#1106052)
  * Fix: bootstrap: "-i" option doesn't work(bsc#1103833, bsc#1103834)
  * Low: bootstrap: No warning message when using '-q'
  * high: ra: Support Pacemaker 2.0 daemon names
  * high: config: Locate pacemaker daemons more intelligently (#67) (bsc#1096783)
  * Fix: TypeError in logparser.py(bsc#1093433)
* Tue Aug 14 2018 kgronlund@suse.com
- Always require python3-parallax (bsc#1103832)
* Fri May 18 2018 kgronlund@suse.com
- Update to version 4.0.0+git.1526547258.54aafa1d:
  * high: bash_completion: Adjust for non-interactive mode(bsc#1090304)
  * high: utils: Parse /32 route entries
  * low: terminal will lose cursor after type ctrl+c(bsc#1090626)
  * low: ui_configure: Adjust prompt string after help messages(bsc#1090140)
  * low: bootstrap: Strip spaces before some status descriptions
* Mon Apr 16 2018 kgronlund@suse.com
- Update to version 4.0.0+git.1523871649.78999e05:
  * doc: Fix unbalanced example marker (bsc#1075764)
* Wed Apr 11 2018 kgronlund@suse.com
- Update to version 4.0.0+git.1523435067.43bb4847:
  * high: hbreport: adjustment for hbreport (bsc#1088784)
* Wed Mar 28 2018 kgronlund@suse.com
- Update to version 4.0.0+git.1522278003.cd7ae188:
  * high: ui_resource: Undeprecate refresh and remove reprobe (bsc#1084736)
* Tue Feb 27 2018 kgronlund@suse.com
- Update to version 4.0.0+git.1519721966.9abd841c:
  * low: bootstrap: Updated authkey generation (bsc#1077389)
* Tue Feb 13 2018 kgronlund@suse.com
- Update to version 4.0.0+git.1518510059.7a6f94e6:
  * fix: bootstrap: Create pacemaker_remote authkey (bsc#1077389)
  * low: bootstrap: Always ask whether to use sbd
  * fix: hb_report: got the right file decompressor(bsc#1077553)
  * medium: hb_report: Avoid calling deprecated network utilities (bsc#1073638)
* Thu Feb  8 2018 kgronlund@suse.com
- Update to version 4.0.0+git.1518073467.76fb6a0b:
  * high: crm_script: Python2->3 string conversion crash in wizards (bsc#1074835)
* Wed Feb  7 2018 kgronlund@suse.com
- Update to version 4.0.0+git.1518010150.a58fa637:
  * high: bootstrap: Add QDevice/QNetd support (bsc#1070961)
  * medium: hb_report: implement dlm_dump info (bsc#1078710)
  * fix: hb_report: collect sbd info (bsc#1076389)
  * fix: hb_report: Collect irregular log file (bsc#1067438)
* Tue Jan 16 2018 kgronlund@suse.com
- Update to version 4.0.0+git.1516124911.d66d9d1f:
  * medium: constants: Add bundle to constants (bsc#1076239)
  * low: xmlutil: Add bundle to sort (bsc#1076239)
* Fri Jan 12 2018 kgronlund@suse.com
- Update to version 4.0.0+git.1515767348.9561209c:
  * medium: ui_cluster: Stop corosync when stopping pacemaker (bsc#1066156)
  * medium: bootstrap: Don't try to remove full nodes from remote nodes
  * medium: clvm-vg: update to use LVM-activate RA (bsc#1074835)
  * medium: clvm: update to use lvmlockd instead of clvmd (bsc#1074835)
  * low: ui_node: normal is deprecated in favor of member (fate#324508)
  * low: ui_configure: no complete for rename new_id
  * low: bootstrap: Don't ssh to localhost in remove
  * low: ui_configure: improve do_group completer
* Tue Jan  9 2018 kgronlund@suse.com
- Update to version 4.0.0+git.1515511613.5ee0eb23:
  * high: scripts: Enable complex expressions in when: (bsc#1074835)
  * medium: hb_report: Support new pacemaker.log location (fate#324508)
  * low: ui_configure: Complete rsc template correctly
  * fix: ra: Convert bytes to str
  * fix: ui_resource: Using crm_failcount instead of crm_attribute(bsc#1074127)
* Wed Dec 13 2017 kgronlund@suse.com
- Update to version 4.0.0+git.1513179435.e1d17d7b:
  * high: scripts: Fix Python 3 migration issues in health, check-uptime (bsc#1071519)
* Tue Dec 12 2017 kgronlund@suse.com
- Update to version 4.0.0+git.1513011384.5aebf8a4:
  * high: parse: Support new alert syntax (#280) (bsc#1069129)
  * high: parse: Support new container bundles (fate#323415)
  * low: hb_report: return "" to avoid TypeError
  * low: ui_configure: use filter_keys replace any_startswith
* Mon Dec  4 2017 kgronlund@suse.com
- Update to version 4.0.0+git.1512406036.adc26906:
  * high: bootstrap: Fix firewall reload command invocation (bsc#1071108)
* Mon Dec  4 2017 kgronlund@suse.com
- Update to version 4.0.0+git.1512395407.e65870b4:
  * high: bootstrap: Encode, not decode (bsc#1070344)
* Mon Dec  4 2017 kgronlund@suse.com
- Update to version 4.0.0+git.1512385350.d06aa847:
  * Fix writing non-ascii chars to log (bsc#1070344)
  * Fix is_program(dmidecode) error (bsc#1070344)
  * low: ui_configure: fix for 309d2e, remove "id=" in a save way
  * low: ra: Don't require deprecated parameters (#321)
  * low: cibconfig: use refresh instead of reset after commit
* Mon Nov 27 2017 kgronlund@suse.com
- Update to version 4.0.0+git.1511604050.816cb0f5:
  * high: crm_rpmcheck: Fix bytes to str encoding error (bsc#1069294)
  * medium: bootstrap: Missing dmidecode on ppc64le (bsc#1069802)
* Tue Nov 21 2017 kgronlund@suse.com
- Update to version 4.0.0+git.1511256861.18b44cfa:
  * high: bootstrap: Use default IP address for ring0 (bsc#1069142)
  * medium: scripts: make sure gfs2 can be configured using hawk (bsc#1067123)
  * medium: bootstrap: fix init vgfs crash if no "-o device" option
  * medium: bootstrap: fix init storage crash if no value input
  * medium: ui_configure: fix crash when no args given
  * medium: filter exist args
  * low: utils: convert bytes to str (bsc#1067823)
  * low: ui_context: Continue completing when input is an alias
  * low: bootstrap: Change error/confirm message with specific device name
* Mon Nov 13 2017 kgronlund@suse.com
- Update to version 4.0.0+git.1510563824.1aecfa01:
  * high: utils: Use python3 in util scripts (bsc#1067823)
  * high: bootstrap: Use firewall-offline-cmd for firewalld (bsc#1067498)
  * medium: hb_report: Verify corosync.conf exists before opening it (bsc#1067456)
  * low: config: Collect /var/log/ha-cluster-bootstrap.log (bsc#1067438)
  * medium: bootstrap: Avoid SSH to localhost (bsc#1067324)
* Thu Nov  9 2017 kgronlund@suse.com
- Update to version 4.0.0+git.1510233955.43c72bf7:
  * high: bootstrap: Fix readline error in cluster remove (bsc#1067424)
  * low: bootstrap: Clarify removal warning
  * low: bootstrap: Avoid printing None instead of NTP service name (bsc#1060602)
* Thu Nov  2 2017 kgronlund@suse.com
- Update to version 4.0.0+git.1509626995.fa880522:
  * high: bootstrap: revert corosync ports for mcast configuration as well (bsc#1066196)
  * high: bootstrap: Revert default corosync port to 5405/5404 (bsc#1066196)
  * medium: NewCommit: ui_configure: complete for ra actions
  * medium: ui_configure: Replace compl.null to compl.attr_id where an id is required
  * medium: ui_context: Stop completing when an id is required
  * low: ui_context: reset term when using help command+ctrlC
  * low: utils: Stop using deprecated functionality
* Tue Oct 31 2017 kgronlund@suse.com
- Update to version 4.0.0+git.1509449399.1e22e954:
  * Make sure scripts use python3 (fate#323526)
  * medium: enable add the second heartbeat line for unicast
  * medium: bootstrap: check init options before running
  * low: ui_script: Sort keys when printing JSON
* Mon Oct 30 2017 kgronlund@suse.com
- Update to version 4.0.0+git.1509349758.2bd8a099:
  * Port to Python 3 (fate#323526)
  * hb_report: config file for hb_report (fate#321640)
* Fri Sep 15 2017 kgronlund@suse.com
- Correct name of python-dateutil package
* Sat Sep  9 2017 kgronlund@suse.com
- Update to version 3.0.1+git.1504985015.b695b452:
  * medium: ui_node: node attribute/status-attr is about node attr, not for resources
  * medium: bootstrap: Only call firewall-cmd if firewalld is active
* Wed Aug 30 2017 kgronlund@suse.com
- Update to version 3.0.1+git.1504075678.b5dce7ab:
  * low: utils: is_process did not work
  * low: utils: Use /proc for process discovery
  * low: bootstrap: Fix formatting of confirmation prompt (bsc#1028704)
  * medium: bootstrap: Set expected_votes based on actual node count (bsc#1033288)
  * remove bindnetaddr for unicast(bsc#1030437)
  * lsb, service, stonith and systemd don't have any providers; so, it shouldn't be completed when type 'tab' after these ra classes.
  * doc: Document lifetime parameter format
  * medium: Add support for pacemaker PR#1208
  * Feature: add rules support to operations
  * low: bootstrap: Fall back to logging into $TMPDIR/ha-cluster-bootstrap.log
  * Improved cd completion
  * Improve ls command outputs
  * Remove "up/back/end" option at root level
  * medium: ui_context: Make all the options can be completed
  * medium: ui_ra: Improve resource agents completion
  * medium: ui_cluster: Add enable/disable option to enable/disable pacemaker service
  * medium:command:adjust the 'ls' print width for long options
  * low:scripts:health: save health-report when run "crm cluster health"
  * low: ui_cluster: add "delete" alias for "remove" option
  * low: bootstrap: give a confirm message when remove node
  * medium: bootstrap: add callback function to check valid port range
  * medium: ui_cluster: Add cluster rename command
  * low: ui_cluster: when use help option, do not exit, just print help messages and return
  * low: ui_cluster: when have an error for optparse, just return and stay at shell
  * low: ui_cluster: complete node name once
  * low: help: adjust the help print width
  * low: ui_cluster: show cluster name in cluster status command
  * Add missing ')'
  * low: completers: filter out ms resource when doing promote/demote
  * low: bootstrap: Don't rely on ha-cluster-* shortcuts
  * low: bootstrap: Improve message when sbd is not installed (bsc#1050427)
  * low: ui_cluster: run command on a specific node
  * medium: bootstrap: run "csync2_update" for all files after new joining node call csync2_remote
  * low: ui_cluster: change cluster name need restart cluster service
  * medium: bootstrap: disable completion and history when running bootstrap
  * high: bootstrap: expected votes wouldn't update in unicast mode
  * medium: bootstrap: configure with IPv6(mcast)
  * medium: bootstrap: configure with IPv6(unicast)
  * medium: bootstrap: validation for bindnetaddr/mcastaddr
  * medium: bootstrap: validation for admin IP
  * medium: utils: list_cluster_nodes: read nodes list from cib.xml
  * low: main: add hostname in promptstr
  * medium: enable adding a second heartbeat ring for mcast
  * low: bootstrap: give error hints when use sbd without watchdog
  * medium: ui_resource: start stopped resources and stop started resources
  * Detect firewall by checking installed packages
  * Fix SBD configuration when using SBD device (Fixes #235)
  * medium: bootstrap: Add support for chrony
  * low: bootstrap: Check for firewalld before SuSEfirewall2
  * medium: ui_configure: in modgroup, add free id and remove id in group
  * medium: ui_node: node utilization is about node attr, not for resources
- Drop merged patches:
  * Remove 0001-Allow-empty-fencing_topology-bsc-1025393.patch
  * Remove 0002-low-bootstrap-Fix-warning-for-formatting-SBD-device-.patch
  * Remove 0003-medium-ui_cluster-Fix-init-with-no-arguments-bsc-102.patch
  * Remove 0004-low-utils-Use-proc-for-process-discovery.patch
  * Remove 0005-medium-scripts-health-Make-health-script-available-a.patch
  * Remove 0006-remove-bindnetaddr-for-unicast-bsc-1030437.patch
  * Remove 0007-medium-bootstrap-Set-expected_votes-based-on-actual-.patch
  * Remove 0008-high-cibconfig-Graph-file-output-option-was-reversed.patch
  * Remove 0009-medium-bootstrap-Enable-help-geo-init-etc.-bsc-10374.patch
  * Remove 0010-medium-bootstrap-Handle-failure-to-fetch-config-grac.patch
  * Remove 0011-medium-bootstrap-Check-required-arguments-to-geo-joi.patch
  * Remove 0012-doc-geo-join-requires-clusters-argument-bsc-1037442.patch
  * Remove 0013-medium-bootstrap-Make-arbitrator-argument-optional-b.patch
  * Remove 0014-medium-history-Revert-preference-of-messages-over-ha.patch
  * Remove 0015-medium-ui_cluster-Add-force-to-ha-cluster-remove-bsc.patch
  * Remove 0016-high-bootstrap-Add-option-to-enable-diskless-SBD-mod.patch
  * Remove 0017-medium-scripts-Clarify-help-text-for-NFS-wizard-bsc-.patch
  * Remove 0018-medium-scripts-Relax-broadcast-IP-validation-bsc-104.patch
  * Remove 0019-medium-bootstrap-Fix-watchdog-SBD-envvars-bsc-104511.patch
* Mon Aug 14 2017 kgronlund@suse.com
- Rewrite python shebang of scripts to help other distributions
* Fri Aug  4 2017 bwiedemann@suse.com
- keep .adoc timestamp to not embed build date in crm.8.html (boo#1047218)
* Fri Jun 23 2017 kgronlund@suse.com
- medium: bootstrap: Fix watchdog SBD envvars (bsc#1045118)
  * Add 0019-medium-bootstrap-Fix-watchdog-SBD-envvars-bsc-104511.patch
- medium: scripts: Relax broadcast IP validation (bsc#1044233)
  * Add 0018-medium-scripts-Relax-broadcast-IP-validation-bsc-104.patch
- medium: scripts: Clarify help text for NFS wizard (bsc#1044244)
  * Add 0017-medium-scripts-Clarify-help-text-for-NFS-wizard-bsc-.patch
* Thu Jun 22 2017 kgronlund@suse.com
- high: bootstrap: Add option to enable diskless SBD mode to cluster init (bsc#1045118)
  * Add 0016-high-bootstrap-Add-option-to-enable-diskless-SBD-mod.patch
- medium: ui_cluster: Add --force to ha-cluster-remove (bsc#1044071)
  * Add 0015-medium-ui_cluster-Add-force-to-ha-cluster-remove-bsc.patch
* Fri Jun  2 2017 kgronlund@suse.com
- medium: history: Revert preference of messages over ha-log.txt (bsc#1031138)
  * Add 0014-medium-history-Revert-preference-of-messages-over-ha.patch
* Wed May 10 2017 kgronlund@suse.com
- medium: bootstrap: Make arbitrator argument optional (bsc#1038386)
  * Add 0013-medium-bootstrap-Make-arbitrator-argument-optional-b.patch
* Wed May  3 2017 kgronlund@suse.com
- doc: geo-join requires --clusters argument (bsc#1037442)
  * Add 0012-doc-geo-join-requires-clusters-argument-bsc-1037442.patch
- medium: bootstrap: Check required arguments to geo-join (bsc#1037421)
  * Add 0011-medium-bootstrap-Check-required-arguments-to-geo-joi.patch
- medium: bootstrap: Handle failure to fetch config gracefully (bsc#1037423)
  * Add 0010-medium-bootstrap-Handle-failure-to-fetch-config-grac.patch
- medium: bootstrap: Enable "help geo-init" etc. (bsc#1037417)
  * Add 0009-medium-bootstrap-Enable-help-geo-init-etc.-bsc-10374.patch
* Thu Apr 27 2017 kgronlund@suse.com
- high: cibconfig: Graph file output option was reversed (bsc#1036595)
- Add 0008-high-cibconfig-Graph-file-output-option-was-reversed.patch
* Mon Apr 24 2017 kgronlund@suse.com
- low: bootstrap: Update fix for formatting SBD device (bsc#1028704)
- medium: bootstrap: Set expected votes based on actual node count (bsc#1033288)
- Add 0007-medium-bootstrap-Set-expected_votes-based-on-actual-.patch
* Fri Apr 21 2017 bliu@suse.com
- low: remove bindnetaddr for unicast(bsc#1030437)
- Add 0006-remove-bindnetaddr-for-unicast-bsc-1030437.patch
* Thu Apr 20 2017 kgronlund@suse.com
- medium: scripts/health: Make health script available as wizard (fate#320848) (fate#320866)
- Add 0005-medium-scripts-health-Make-health-script-available-a.patch
* Wed Mar 15 2017 kgronlund@suse.com
- low: bootstrap: Fix warning for formatting SBD device (bsc#1028704)
- medium: ui_cluster: Fix init with no arguments (bsc#1028735)
- low: utils: Use /proc for process discovery
- Add 0002-low-bootstrap-Fix-warning-for-formatting-SBD-device-.patch
- Add 0003-medium-ui_cluster-Fix-init-with-no-arguments-bsc-102.patch
- Add 0004-low-utils-Use-proc-for-process-discovery.patch
* Tue Feb 28 2017 kgronlund@suse.com
- Allow empty fencing topology (bsc#1025393)
- Add 0001-Allow-empty-fencing_topology-bsc-1025393.patch
* Tue Jan 31 2017 kgronlund@suse.com
- Update to version 3.0.0:
  * high: bootstrap: Add bootstrap commands (fate#321114)
  * high: logparser: Update transition RE (#168)
  * medium: hb_report: don't use backticks in local
  * medium: hb_report: Make sure this never expands to rm -rf /
  * medium: ui_history: Avoid ugly wrapping of diff output
  * medium: ui_cluster: Fix broken cluster remove command
  * low: cibconfig: Clearer error for duplicate ID (bsc#1009748)
  * low: crm_pssh: Fix nodenum envvar name
  * low: cmd_status: More detail in verify output
  * low: ui_cluster: start/stop don't touch corosync, just pacemaker
  * low: ui_script: Fix script list all/names argument handling
  * low: ui: Fix vim highlightning support.
  * low: ui_cluster: No need to check the cluster stack in requires
  * low: completers: give the op's hint when type tab after 'op'
* Wed Nov  2 2016 kgronlund@suse.com
- Update to version 2.2.0+git.1476084519.a000372:
  * high: cibconfig: Ensure temp CIB is readable by crm_diff (bsc#999683)
  * high: parse: Support target pattern in fencing topology
  * medium: ui_configure: option to obscure passwords
  * medium: cibconfig: Remove from tags when removing object
  * medium: scripts: Better corosync defaults (bsc#1001164)
  * medium: scripts: Drop logrotate check from cluster health
  * medium: corosync: Fix missing variable in del-node
  * low: cmd_status: Highlight plural forms (bsc#996806)
* Thu Sep 15 2016 kgronlund@suse.com
- Update to version 2.2.0+git.1473924149.8abc212:
  * high: history: Quote archive tarball name if it contains spaces (bsc#998959)
  * high: history: Prefer /var/log/messages over ha-log.txt (bsc#998891)
* Fri Sep  2 2016 kgronlund@suse.com
- Update to version 2.3.1+git.1472802925.a4a4041:
  * Require Python 2.6+, not 2.7 (bsc#995611)
* Tue Aug  9 2016 kgronlund@suse.com
- Update to version 2.2.0+git.1470743271.64d1a40:
  * medium: constants: Add missing alerts constants (#150) (bsc#992789)
* Sat Jul 30 2016 kgronlund@suse.com
- Update to version 2.2.0+git.1469918297.1b801f6:
  * high: hb_report: Skip lines without timestamps in log correctly (bsc#989810)
  * high: hb_report: Don't collect logs from journalctl if -M is set (bsc#990025)
  * high: parse: Use original _TARGET_RE
  * low: Fix a setting example of the alert to become the error
  * low: scripts: Fix use of non-relative import for ra
* Wed Jun  1 2016 kgronlund@suse.com
- Update to version 2.2.0+git.1464769043.9e4df55:
  * medium: tmpfiles: Create temporary directory if non-existing (bsc#981583)
* Thu May 26 2016 kgronlund@suse.com
- Update to version 2.2.0+git.1464237560.fd9e583:
  + high: constants: Add maintenance to set of known attributes (bsc#981659)
  + medium: xmlutil: reduce unknown attribute to warning (bsc#981659)
* Wed May 25 2016 kgronlund@suse.com
- Update to version 2.2.0+git.1464167894.621fe00:
  + medium: scripts: no-quorum-policy=ignore is deprecated (bsc#981056)
* Mon May 23 2016 kgronlund@suse.com
- Update to version 2.2.0+git.1463777827.9b402a8:
  + high: history: Store live report in per-user directory (bsc#980924)
  + medium: logparser: Handle read-only access to metadata cache (bsc#980924)
  + medium: logparser: Fix use-before-declaration error in logparser
  + medium: history: Report better error when history user is not sudoer (bsc#980924)
  + low: utils: Clearer error if permission denied when locking (bsc#980924)
  + low: history: fall back to any log file in report root
* Thu May 12 2016 kgronlund@suse.com
- Update to version 2.2.0+git.1462967444.169c554:
  + high: parse: Support for event-driven alerts (fate#320855) (#136)
  + high: utils: Avoid deadlock if DC changes during idle wait (bsc#978480)
  + medium: ui_resource: Add force argument to resource cleanup (bsc#979420)
  + medium: ui_resource: Show utilization in output from crm resource scores
  + high: ui_resource: Improved resource move/clear/locate commands
* Tue May  3 2016 kgronlund@suse.com
- Update to version 2.2.0+git.1462285059.d79cd0d:
  + high: ui_root: Add crm verify command
  + medium: hb_report: Fix broken -S option (#137)
  + low: hb_report: Fix spurious error on missing events.txt
  + low: scripts: Note SBD recommendation in vmware script (fate#318320)
  + low: scripts: Note SBD recommendation in libvirt script (fate#318320)
* Thu Apr 21 2016 kgronlund@suse.com
- Update to version 2.2.0+git.1461246131.bf3c265:
  + medium: scripts: Add vmware to data manifest (fate#318320)
  + medium: ui_node: Fix crash in node fence command (bsc#974902)
  + low: scripts: Preserve formatting in description for vmware wizard
  + low: scripts: Better description for sbd
* Tue Apr 19 2016 kgronlund@suse.com
- Update to version 2.2.0+git.1461083981.dab79a4:
  + high: scripts: VMware fencing using vCenter (fate#318320)
* Tue Apr 19 2016 kgronlund@suse.com
- Update to version 2.2.0+git.1461051741.724349d:
  + low: cibconfig: Don't mix up CLI name with XML tag
  + low: constants: Add missing reload operation to parser
  + low: corosync: Recycle node IDs when possible
  + low: parse: Don't validate operation name in parser (bsc#975357)
  + low: scripts: Only print debug output locally unless there were remote actions
  + low: scripts: Fix watchdog test in sbd-device (fate#318320)
  + low: scripts: Shouldn't set -e here (fate#318320)
- Remove bug-974902_crm-node-fence.patch
* Fri Apr 15 2016 ygao@suse.com
- medium: ui_node: Fix "crm node fence" (bsc#974902)
  - bug-974902_crm-node-fence.patch
* Mon Mar 21 2016 kgronlund@suse.com
- Update to version 2.2.0+git.1458546035.5df0420:
  + medium: scripts: SBD wizard which configures SBD itself (fate#318320)
  + medium: main: Add -o|--opt to pass extra options for crmsh
  + medium: hb_report: Add timeout to SSH connection (bsc#971690)
  + low: command: handle stray regex characters in input
  + low: scripts: Clean up various scripts
* Wed Mar 16 2016 bwiedemann@suse.com
- Fix build-compare by only touching files with timestamps in the future
  and by not including the rebuild counter in hb_report
* Tue Mar 15 2016 kgronlund@suse.com
- Update to version 2.2.0+git.1458042315.389d264:
  + high: history: Faster log parsing (bsc#970278)
  + medium: ui_node: Use stonith_admin -F to fence remote nodes (bsc#967907)
  + medium: crm_pssh: Fix live refresh of journalctl logs (bsc#970931)
  + medium: hb_report: Use server attribute for remote nodes if set (bsc#970819)
  + medium: ui_node: Add crm node server command
  + medium: scripts: Simplify SBD script (bsc#968076) (fate#318320)
  + medium: scripts: inline scripts for call actions
  + medium: scripts: Don't require sudo for root
  + medium: scripts: Set sudo and full path for exportfs -v in nfs scripts
  + medium: scripts: Add nfs-utils to list of packages for nfsserver
  + low: history: use os.listdir to list history sessions
  + low: scripts: Fix error in service action
  + low: logtime: Improve performance of syslog_ts (bsc#970278)
  + low: hb_report: Print covered time span at exit (bsc#970823)
  + low: hb_report: Warn if generated report is empty (bsc#970823)
  + low: log_patterns_118: Add captures to log patterns for tagging (bsc#970278)
  + low: ui_resource: alias show to get
  + low: hb_report: Suggest user checks timeframe on empty logs (bsc#970823)
  + low: logparser: Add cib info to __meta for hawk
* Wed Feb 24 2016 kgronlund@suse.com
- Update to version 2.2.0+git.1456299101.87fe3c9:
  + high: ui_configure: Fix commit force (#120)
  + medium: config: make multiarch dependency a dynamic include (#119)
  + low: ui_node: Less cryptic query when fencing node
* Fri Feb 19 2016 kgronlund@suse.com
- Update to version 2.2.0+git.1455627181.78fd949:
  + high: scripts: Add LVM on DRBD cluster script (bsc#951132)
  + high: scripts: Add NFS on LVM and DRBD cluster script (bsc#951132)
  + high: added the "push" method to the "configure load" command (fate#320389)
  + medium: ui_configure: Only wait for DC if resources were stopped (#117)
  + medium: hb_report: Don't collect logs on non-nodes (bsc#959031)
  + medium: hb_report: Don't collect logs on non-nodes (bsc#959031)
  + medium: ui_configure: Only wait for DC if resources were stopped (#117)
  + medium: command: Disable fuzzy matcher for completion (#116)
  + medium: corosync: added optional parameter [name] to "corosync add-node" function
  + medium: constants: clone-min meta attribute (new in Pacemaker 1.1.14)
  + medium: cibconfig: add and|or filter combinators to influence filtering (fate#320401)
  + Medium: history: update patterns for resource (new lrmd)
  + medium: ui_configure: Rename show-property to get-property
  + medium: scripts: Updated SBD cluster script (fate#318320)
  + low: Fix title style vs. sentence style in cluster scripts (bsc#892108)
  + low: Fix title style vs. sentence style in cluster scripts (bsc#892108)
  + Low: maintenance: allow action to be forced
- Remove merged patches:
  - Remove 0001-high-history-Parse-log-lines-without-timestamp-bsc-9.patch
  - Remove 0002-high-scripts-Improved-OCFS2-cluster-script-bsc-95398.patch
  - Remove 0003-high-scripts-fix-broken-cluster-init-script-bsc-9631.patch
* Fri Jan 22 2016 kgronlund@suse.com
- high: scripts: fix broken cluster init script (bsc#963135)
- high: scripts: Improved OCFS2 cluster script (bsc#953984)
- high: history: Parse log lines without timestamp (bsc#955581)
- Add 0001-high-history-Parse-log-lines-without-timestamp-bsc-9.patch
- Add 0002-high-scripts-Improved-OCFS2-cluster-script-bsc-95398.patch
- Add 0003-high-scripts-fix-broken-cluster-init-script-bsc-9631.patch
* Tue Jan 19 2016 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1452867205.c160c5a:
  + high: cibconfig: Fix XML import bug for cloned groups (bsc#959895)
  + high: cibconfig: fail if new object already exists (bsc#959965)
  + high: cibconfig: Preserve failure through edit (bsc#959965)
  + medium: ui_cib: Call crm_shadow in batch mode to avoid spawning subshell (bsc#961392)
  + medium: ui_history: Add events command (bsc#952449)
  + medium: scripts: Reformat scripts to simplified form
  + medium: scripts: Load single file yml scripts
  + medium: cibconfig: Detect false container children
  + medium: history: Ignore central log
  + medium: history: Fix live report refresh (bsc#950422) (bsc#927414)
  + low: don't use deprecated crm_attribute -U option
  + low: hb_report: Drop function from event patterns
  + low: clidisplay: Avoid crash when colorizing None
  + doc: Documentation for history events command
* Mon Dec  7 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1449475283.649c9d2:
  + high: ui_configure: Move validate-all validation to a separate command (bsc#956442)
  + high: scripts: Don't delete steps from upgraded wizards (bnc#957925)
  + medium: scripts: Enable setting category in legacy wizards (bnc#957926)
  + high: scripts: Don't require scripts to be an array of one element
  + high: scripts: Conservatively verify scripts that modify the CIB (bsc#951954)
  + high: ui_resource: Enable start/stop/status for multiple resources at once (bsc#952775)
  + high: ui_resource: Add constraints and operations commands
  + high: ui_ra: Add ra validate command (bsc#956442)
  + high: script: Fix issues found in cluster scripts
  + low: resource: Fix unban alias for unmigrate
* Thu Nov 19 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1447774225.24dd944:
  + high: xmlutil: Order is significant in resource_set (bsc#955434)
* Mon Nov  9 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1447033314.c640af6:
  + medium: script: (filesystem) create stopped (bsc#952670)
  + doc: configure load can read from stdin
  + medium: scripts: Lower copy target to string
* Thu Oct 29 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1446121677.5f4ab3c:
  + high: scripts: Eval CIB text in correct scope (bsc#952600)
  + medium: scripts: Check required parameters for optional sub-steps
  + medium: utils: Fix python 2.6 compatibility
* Wed Oct 28 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1446022288.cbb7d77:
  + medium: scripts: No optional steps in legacy wizards (bsc#952226)
  + medium: ui_script: Tag legacy wizards as legacy in show (bsc#952226)
* Mon Oct 26 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1445863187.686e3ec:
  + high: utils: Revised time zone handling (bsc#951759)
* Tue Oct 20 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1445338389.7433378:
  + high: scripts: Fix DRBD script resource reference (bsc#951028)
  + low: constants: Tweaked graph colors
* Thu Oct 15 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1444854254.fc37f7f:
  + high: utils: Handle time zones in parse_time (bsc#949511)
  + medium: cibconfig: Fix sanity check for attribute-based fencing topology (#110)
  + medium: ui_script: Optionally print common params
  + medium: hb_report: Remove reference to function name in event patterns (bsc#942906)
  + medium: report: Make transitions without end stretch to 2525
  + doc: add missing <> to fencing_topology syntax
  + doc: add missing backslash in fencing_topology example
  + doc: add explanatory comments to fencing_topology
  + doc: Update the scripts documentation
  + doc: Fix unclosed block in scripts documentation
* Mon Oct 12 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1444661352.14fa72b:
  + high: scripts: Determine output format of script correctly (bsc#949980)
  + high: cibconfig: Fix bug with node/resource collision
* Thu Oct  8 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1444340345.59850ca:
  + high: utils: Fix cluster_copy_file error when nodes provided (bsc#949603)
  + low: xmlutil: More informative message when updating resource references after rename
  + doc: fix some command syntax grammar in the man page
  + doc: resource-discovery for location constraints
* Tue Oct  6 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1444133917.3f7f79f:
  + high: cibconfig: Fix bug in is_edit_valid (bsc#948547)
  + high: cibconfig: Delete constraints before resources
* Tue Oct  6 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1444122392.193bf69:
  + high: cibconfig: Allow nodes and resources with the same ID (bsc#948547)
  + high: cibconfig: Allow node/rsc id collision in _set_update (bsc#948547)
  + medium: hb_report: Don't cat binary logs
  + low: report: Silence tar warning on early stream close
* Wed Sep 30 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1443544100.aa2abda:
  + medium: report: Enable opening .xz-compressed report tarballs
  + medium: config: Always fall back to /usr/bin:/usr/sbin:/bin:/sbin for programs (bsc#947818)
  + low: ui_resource: Silence spurious migration non-warning from pacemaker
  + high: log_patterns_118: Update the correct set of log patterns (bsc#942906)
* Thu Sep 24 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1443105613.80a246f:
  + medium: cibconfig: Only warn for grouped children in colocations (bsc#927423)
* Thu Sep 24 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1443102798.74361f5:
  + high: ui_node: Show remote nodes in crm node list (bsc#877962)
  + medium: cibconfig: Warn if configuring constraint on child resource (bsc#927423) (#101)
  + medium: cibconfig: Allow order constraints on group children (bsc#927423)
* Tue Sep 22 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1442913222.4ba506b:
  + high: config: Remove config.core.supported_schemas (bsc#946893)
* Fri Sep 11 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1441965248.a9a616d:
  + low: scripts: Fix typo in email type verifier
  + low: scripts: [MailTo] install mailx package
  + high: scripts: Add enum type to script values
  + medium: parse: Add support for node attribute as fencing topology target
  + doc: Improve documentation for the history level
  + low: ui_history: Swap from and to times if to < from
  + low: ui_history: Better error handling and documentation for the detail command
  + medium: report: Add transition tags command (bsc#943470)
  + medium: report: Mark transitions with errors with a star in info output (bsc#943470)
* Fri Sep  4 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1441319359.d823416:
  + high: scripts: Generate actions for includes if none are defined
  + high: script: Fix subscript agent reference bug
  + medium: crm_pssh: Timeout is an int (bsc#943820)
  + medium: scripts: Fix typo in lvm script
  + low: scripts: [virtual-ip] make lvs_support an advanced parameter
  + low: constants: Add meta attributes for remote nodes
* Mon Aug 31 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1440887645.cd6ac8a:
  + doc: Clarify documentation for colocations using node-attribute
  + high: parse: Fix crash when referencing score types by name (bsc#940194)
  + low: scripts: Improved script parameter validation
  + medium: scripts: Add MailTo script
* Wed Aug 26 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1440626270.8872dbc:
  + low: hb_report: Increase time to wait for the logmark
  + medium: log_patterns: Remove reference to function name in log patterns (bsc#942906)
  + low: hb_report: Collect libqb version (bsc#943327)
  + medium: report: Reintroduce empty transition pruning (bsc#943291)
  + medium: scripts: Ensure that the Filesystem resource exists [nfsserver] (bsc#898658)
  + low: scripts: Make virtual IP optional [nfsserver]
  + high: scripts: Add force parameter to cib and crm actions, and don't pass --force by default
  + high: scripts: Default to passing --force to crm after all
  + medium: options: Add --no option
  + medium: scripts: Use --no option over --force unless force: true is set in the script
  + high: ui_script: Print cached errors in json run
* Tue Aug 25 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1440506835.395dad0:
  + high: report: Update transition edge regexes (bsc#942906)
  + high: hb_report: Always prefer syslog if available (bsc#942906)
* Tue Aug 25 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1440493477.255685f:
  + low: scripts: Catch attempt to pass dict as parameter value
  + medium: scripts: Switch install default to false (fate#318482)
* Fri Aug 14 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1439547680.0877a90:
  + low: main: Bash completion didn't handle sudo correctly
  + high: hb_report: Correct path to hb_report after move to subdirectory (bsc#936026)
  + medium: report: Add pacemaker.log to find_node_log list (bsc#941734)
  + high: hb_report: Prefer pacemaker.log if it exists (bsc#941681)
  + high: report: Output format from pacemaker has changed (bsc#941681)
* Wed Aug 12 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1439305144.fbe773c:
  + medium: config: Add report_tool_options (bsc#917638)
* Mon Aug 10 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1438934728.5abada2:
  + Medium: cibconfig: skip sanity check for properties other than cib-bootstrap-options
  + high: parse: Add attributes to terminator set (bsc#940920)
* Thu Jul  9 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1436439891.2cc4984 (fate#318281):
  + high: ui_script: drop end sentinel from API output (fate#318211)
  + low: scripts: Title and category for exportfs
  + low: scripts: Strip shortdesc for scripts and params
  + low: scripts: Tweak description for libvirt
  + low: scripts: make overridden parameters non-advanced by default
  + low: scripts: add missing type annotations to libvirt script
  + low: scripts: Fix formatting for SAP scripts
  + low: scripts: Clearer shortdesc for filesystem
  + low: scripts: Preserve formatting of longdescs
  + medium: ui_script: Add name to action output (fate#318211)
  + low: ui_script: Check JSON command syntax
  + medium: ui_script: Fix bug in verify json encoding
* Mon Jul  6 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1436110355.d603e20:
  + low: scripts: Fix possible reference error in agent include
* Fri Jul  3 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1435949142.a824a98:
  + low: Add HAProxy script to data manifest
  + low: Remove build revision from version
  + low: scripts: Clearer error message
* Fri Jul  3 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1435679589.07d4206:
  + medium: scripts: Add HAProxy script
  + medium: constants: Add 'provides' meta attribute (bsc#936587)
* Thu Jun 25 2015 kgronlund@suse.com
- Update to version 2.2.0~rc3+git.1435265407.2865580:
  + high: hb_report: find utility scripts after move (bsc#936026)
  + high: ui_report: Move hb_report to subdirectory (bsc#936026)
  + high: scripts: subscript values not required if subscript has no parameters / all defaults (fate#318211)
  + high: Makefile: Don't unstall hb_report using data-manifest (bsc#936026)
  + medium: scripts: Fix name override for subscripts (fate#318211)
  + medium: scripts: stop inserting comments as values
  + medium: report: Fall back to cluster-glue hb_report if necessary (bsc#936026)
  + low: scripts: Clean up generated CIB (fate#318211)
* Fri Jun 12 2015 kgronlund@suse.com
- Pre-release 2.2.0-rc3
- high: Merge rewizards development branch (fate#318211)
  (fate#318384) (fate#318483) (fate#318482) (fate#318550)
- Summary of some of the changes included in the merge of
  the rewizards branch:
  + Colorized status output
  + New and more capable cluster script implementation
  + Deprecated the crmsh templates (not the CIB templates,
    the configuration templates)
  + Implemented a JSON API interface to the cluster scripts
    for hawk to use instead of having its own wizards
  + Handlebars-like templating language for cluster scripts
    that modify the CIB
  + Collect metadata from resource agents to avoid duplication
    in configuration scripts
  + Extended validation support for parameter values
  + New cluster scripts:
  - Stonith: SBD and libvirt
  - Apache web server
  - NFS server
  - cLVM
  - Databases: MySQL / MariaDB / Oracle / DB2
  - SAP
  - OCFS2
  - etc.
  + Radically simplified automake and autoconf setup
  + Improved completion performance
  + Added pygment lexers used by the history guide as stand-alone
    python module in contrib/
  + Removed dependency on corosync for regression test suite
  + Sort topics and commands in help output
  + Hide internal commands in help and ls
  + Clearer debug output when simulating
  + Cleaned up and fixed documentation bugs
- Update to version 2.2.0~rc3+git.1434151485.7365522:
  + low: crm: Detect and report use of python 3
  + medium: hb_report: Collect logs from pacemaker.log
  + medium: ui_root: Make the cibstatus command available directly from the root
  + medium: resource: Add ban command
  + medium: handles: {{^feature}}invert blocks{{/feature}}
  + medium: handles: Replace magic value with callables
  + low: handles: Also allow # and $ in identifiers
  + doc: Update reference to parallax in scripts documentation
  + WIP: in-progress notes etc.
  + scripts: Add placeholders for some basic scripts
  + medium: handles: Fix error in strict parameter handling
  + medium: config: add config.path.hawk_wizards
  + medium: ui_script: Add JSON API
  + build: Add update-data-manifest.sh to generate datadir file list
  + contrib: Add pygment lexers used by the history guide
  + doc: Describe website compilation process in development.md
  + doc: scripts: Basic documentation for the cluster scripts
  + medium: help: Sort topics and commands in help output
  + low: handles: Clean up special values
  + doc: Document the script JSON API
  + low: script: Rename describe to show
  + low: command: Hide internal commands from ls
  + doc: Fix unterminated block
  + low: scripts: Stricter regexp for identifiers
  + low: scripts: Handle local runs even if nodelist doesn't contain local node
  + low: cmd_status: Add full argument to status
  + high: cmd_status: Colorize status output
  + Pre-release 2.2.0-rc3
* Wed Jun  3 2015 kgronlund@suse.com
- Pre-release 2.2.0-rc2
- medium: crm_pkg: Fix cluster init bug on RH-based systems
- medium: crm_gv: Improved quoting of non-identifier node names (bsc#931837)
- medium: crm_gv: Wrap non-identifier names in quotes (bsc#931837)
- low: Fix references to pssh to refer to parallax
- medium: report: Try to load source as session if possible (bsc#927407)
- low: xmlutil: Update comment to match the code
- high: report: New detection to fix missing transitions (bnc#917131)
- medium: ui_configure: Add resource as an alias for primitive
- medium: parse: Allow implicit initial for groups as well
- medium: parse: More robust implicit initial parser
- Medium: doc: add history guide
- Low: doc: simplify to make it work with python 2.6
- Medium: hb_report: use faster zypper interface if available
- medium: ui_configure: Wait for DC when removing running resource
- low: schema: Don't leak PacemakerError exceptions (#93)
- high: ui_cluster: Add copy command
- doc: Update the documentation for the upgrade command
- parse: Don't require trailing colon in tag definitions
- high: crm_pssh: Explicitly set parallax inline option (krig/parallax#1)
- high: ui_configure: Add show-property command
- medium: utils: Allow 1/0 as boolean values for parameters
- low: hb_report: Use crmsh config to find pengine/cib dirs (bsc#926377)
- low: ui_options: add alias list for show
- medium: cliformat: Escape double-quotes in nvpair values
- high: parse: Don't allow constraints without applicants
- medium: parse: Disallow location rules without resources
- medium: ui_template: Make new command more robust (bnc#924641)
- high: fix typo in previous commit
- high: ui_node: Don't fence node in clearstate (boo#912919)
- low: Replaced README with README.md
- medium: ui_template: Always generate id unless explicitly defined (boo#921028)
- high: cibconfig: Derive id for ops from referenced resource name (boo#921028)
- medium: templates: Clearer descriptions for editing templates (boo#921028)
- high: ui_context: Wait for DC after commit, not before (#85)
- high: cibconfig: Don't delete valid tickets when removing referenced objects (bnc#922039)
- high: ui_configure: Remove acl_group command (bnc#921056)
- doc: Document changes to template list|new
- medium: help: Teach help to fuzzy match topics
- doc: Describe the shorthand syntax for commands
- low: command: Use fuzzy match for sublevel check
- medium: command: Fuzzy match command names
- low: ui_context: Use true command name when reporting errors
- Low: hb_report: add -X option for extra ssh options
- low: allow pacemaker 1.0 version detection
- low: allow (0,1) as option booleans
- medium: cibconfig: Allow removal of non-existing elements if --force is set
- medium: cibconfig: Allow delete of objects that don't exist without returning error code
- medium: cibconfig: If a change results in no diff, exit silently
- low: pacemaker: Remove debug output
- medium: schema: Remove extra debug output
- medium: schema: Test if node type is optional via schema
- medium: parse: Treat pacemaker-next schema as 2.0+
- low: cibconfig: Improved debug output when schema change fails
- medium: cibconfig: Fix inverted logic causing spurious warning
- Medium: cibconf: preserve cib user attributes
- medium: ra: Handle non-OCF agent meta-data better
- medium: config: Fix case-sensitivity for booleans
- medium: report: Include transitions with configuration changes (bnc#917131)
- medium: xmlutil: Improved check for related elements
- doc: Documentation for show related:<obj>
- medium: report: Convert RE exception to simpler UI output
- medium: cibconfig: add show related:<obj>
- medium: parse: Encode unicode using xmlcharrefreplace in parser
- medium: parse: nvpair attributes with no value = <nvpair name=".."/> (#71)
- medium: ui_cluster: Add diff command (bnc#914525)
- medium: report: Fall back to end_ts = start_ts
- medium: util: Don't fall back to current time
- high: xmlutil: Treat node type=member as normal (boo#904698)
- low: xmlutil: logic bug in sanity_check_nvpairs
- medium: xmlutil: Modify sort order of object types
- medium: cibconfig: Use orderedset to avoid reordering bugs (#79)
- medium: orderedset: Add OrderedSet type
- medium: cibconfig: Detect v1 format and don't patch container changes (bnc#914098)
- medium: constants: Update transition regex (#77)
- Revert "high: xmlutil: Reorder elements only if sort_elements is set (#78)"
- low: ui_options: Add underscore aliases for legacy options
- high: xmlutil: Reorder elements only if sort_elements is set (#78)
- medium: cibconfig: Strip digest from v1 diffs (bnc#914098)
- medium: crm_pssh: Make tar follow symlinks
- medium: constants: Fix transition start detection
- medium: crm_pssh: Handle incomplete Option argument
- high: crm_pssh: Use correct Task API in do_pssh (bnc#913261)
- medium: cibconfig: Break infinite edit loop if --force is set
- high: utils: Locate binaries across sudo boundary (bnc#912483)
- low: config: Convert NoOptionError to ValueError
- low: msg: Add note on modifying supported schemas
- medium: config: Add 2.3 to list of supported schemas
- medium: utils: crm_daemon_dir is added to PATH in envsetup (#67)
- Version 2.2.0-rc2, update ChangeLog
- low: cibconfig: Protect against dereferencing None when building graph
- low: crm_gv: Avoid crashing if passed None in my_edge
- low: cibconfig: Use LXML to remove version data more robustly (#75)
- Remove CIB version in case no --no-version.
- medium: ui_options: Accept prefix or suffix of option as argument
- medium: utils: Check if path basename is less (#74)
- low: report: Delay Report creation until use
- Medium: history: match error/crit messages of pcmk 1.1.12
- low: report: Fix references to PSSH
- high: crm_pssh: Switch to python-parallax over pssh (bnc#905116)
- high: parse: Implicit initial parameter list
- Low: term: get rid of annying ^O in piped-to-less-R output
- medium: parse: Enable name[=value] for nvpair (#71)
- medium: parse: Allow nvpair with no value using name= syntax (#71)
- utils: append_file: open destination in append-mode (boo#907528)
- medium: ui_history: Fix crash using empty object set
- doc: Add note about modeline for vim syntax
- doc: Improved documentation for show and save
- medium: cibconfig: Delete containers first in edits (boo#905268)
- medium: Allow removing groups even if is_running (boo#905271)
- doc: Add documentation section describing rule expressions (boo#905637)
- doc: Clarify documentation for property (boo#905637)
- Medium: config: add alwayscolor to display output option
- medium: config: Add core.ignore_missing_metadata (#68) (boo#905910)
- medium: ui_configure: selectors in save command
- medium: ui_context: Lazily import readline
- medium: cibconfig: Don't bump epoch if stripping version
- medium: ui_configure: Add replace option to commit
- medium: cibconfig: Revised CIB schema handling
- low: cliformat: Colorize id: as identifier (boo#905338)
- medium: config: Fall back to /etc/crm/crmsh.conf (#67)
- high: config: Fix path to system-wide crm.conf (#67)
- medium: cmd_status: Show pending if available, enable extra options
- medium: ra: Use correct path for crmd (#67)
- medium: cibconfig: Allow unsupported schemas with warning
- medium: pacemaker: Support pacemaker-next as schema
- medium: parse: Support resource-discovery in location constraints
- doc: Document deprecation of refresh and reprobe (bnc#905092)
- low: ui_resource: --reprobe and --refresh are deprecated (bnc#905092)
- doc: Document probe op in resource trace (bnc#905050)
- medium: ui_resource: Set probe interval 0 if not set (bnc#905050)
- high: ui_resource: resource trace failed if operation existed (bnc#901453)
- high: ui_resource: Use correct name for error function (bnc#901453)
- medium: ui_resource: Flatten, then filter (#64)
- medium: ui_resource: Only act on resources (#64)
- high: xmlutil: Filter list of referenced resources (bnc#901714)
- high: cibconfig: Don't crash if given an invalid pattern (bnc#901714)
- doc: cibconfig: Add note on inner ids after rename
- medium: xmlutil: Use idmgmt when creating new elements (bnc#901543)
- doc: Remove reference to crmsh documentation at clusterlabs.org
- doc: Clarified note for default-timeouts
- high: hb_report: Collect logs from journald (boo#900654)
- high: report: Find nodes for any log type (boo#900654)
- low: cibconfig: Fix vim modeline
- medium: main: Disable interspersed args
- high: cibconfig: Delay reinitialization after commit
- low: cibconfig: Improve wording of commit prompt
- low: rsctest: Better error message for unsupported action
- medium: ui_maintenance: Combine action and actionssh into a single command
- medium: rsctest: Add basic support for systemd services
- high: ui_maintenance: Add maintenance sublevel (bnc#899234)
- high: parse: Allow empty attribute values in nvpairs (bnc#898625)
- low: main: Replace getopt with optparse
- low: ui_cluster: More informative error message
- low: report: Sort list of nodes
- high: cibconfig: Add tag:<tag> to get all resources in tag
- high: cibconfig: Generate valid CLI syntax for attribute lists (bnc#897462)
- doc: Sort command list in documentation alphabetically
- doc: Handle command names with underscore
- low: ra: Add systemd-support to RaOS
- low: ui_ra: Don't crash when no OCF agents installed
- low: corosync: Check tools before use
- low: main: Catch any ValueErrors that may leak through
- medium: config: Assign default path in all cases
- low: ui_template: List both templates and configs by default
- low: ui_configure: add rm as alias for delete
- low: template: Add 'new <template>' shortcut
- high: scripts: Handle corosync.conf without nodelist in add-node (bnc#862577)
- medium: Handle broken CIB in find_objects
- high: parse: split shortcuts into valid rules
- doc: Rename asciidoc files to %%.adoc
- medium: cibconfig: Add set command
- Low: hb_report: add -Q to usage
- upstream cs: 2.2.0-rc2-167-g4e7baf3
* Wed Oct 29 2014 kgronlund@suse.com
- Release 2.1.1 (bnc#902993)
- upstream cs: 2.1.1
* Tue Oct 28 2014 kgronlund@suse.com
- medium: ui_resource: Only act on resources (#64)
- medium: ui_resource: Flatten, then filter (#64)
- high: ui_resource: Use correct name for error function (bnc#901453)
- high: ui_resource: resource trace failed if operation existed (bnc#901453)
- upstream cs: 2.1.0-63-g9b8d798
* Mon Oct 13 2014 kgronlund@suse.com
- high: hb_report: Collect logs from journald (boo#900654)
- high: report: Find nodes for any log type (boo#900654)
- low: cibconfig: Fix vim modeline
- upstream cs: 2.1.0-55-ga69c53c
* Fri Oct 10 2014 kgronlund@suse.com
- high: cibconfig: Delay reinitialization after commit (bnc#900271)
- low: cibconfig: Improve wording of commit prompt
- upstream cs: 2.1.0-52-geb70880
* Fri Sep 26 2014 kgronlund@suse.com
- high: parse: Allow empty attribute values in nvpairs (bnc#898625)
- low: report: sort list of nodes
- upstream cs: 2.1.0-50-g966ce53
* Fri Sep 19 2014 kgronlund@suse.com
- doc: Documentation for show tag:<tag>
- high: cibconfig: Add tag:<tag> to get all resources in tag
- high: cibconfig: Generate valid CLI syntax for attribute lists (bnc#897462)
- upstream cs: 2.1.0-48-g76c93c8
* Wed Sep  3 2014 kgronlund@suse.com
- high: scripts: Handle corosync.conf without nodelist in add-node (bnc#862577)
- high: parse: split shortcuts into valid rules
- upstream cs: 2.1.0-44-g075fc75
* Thu Aug 28 2014 kgronlund@suse.com
- high: constants: Add acl_target and acl_group to cib_cli_map (bnc#894041)
- cibconfig: Clean up output from crm_verify (bnc#893138)
- upstream: 2.1.0-38-g7d05ad6
* Fri Aug 22 2014 kgronlund@suse.com
- medium: term: Handle $ in input when rendering (bnc#893011)
- upstream: 2.1.0-33-g8cb6b59
* Fri Aug 15 2014 kgronlund@suse.com
- medium: cibconfig: Support crm_diff --no-version (bnc#888726)
- low: constants: Add requires to list of meta attributes
- 2.1.0-30-g7a4a34d
* Tue Aug  5 2014 kgronlund@suse.com
- medium: ui_node: Fix handling of default arguments (bnc#889673)
- medium: crm_pssh: Degrade functionality if pssh is unpatched
- upstream: 2.1.0-26-g29f1259
* Tue Jul 29 2014 kgronlund@suse.com
- high: report: Preserve path when checking timestamp of tarball (bnc#889328)
- medium: config: Respect EDITOR and PAGER environment variables
- medium: parse: pacemaker allows order without score or kind
- medium: hb_report: add -Q option for quick runs
- low: history: use -Q with hb_report to reduce waiting time
- low: hb_report: add timestamp when debugging
- Low: hb_report: combine-logs.pl is obsolete
- upstream: 2.1.0-20-g9de903ff5cd8
* Tue Jul  1 2014 kgronlund@suse.com
- Doc: Fix incorrect title for script section
- Doc: Update ChangeLog for release 2.1
- Low: help: Handle topics with subtopics correctly
- upstream: 2.1.0-4-g7993c9d0f0c8
* Wed Jun 25 2014 kgronlund@suse.com
- Medium: hb_report: dot is not illegal in file names (bnc#884079, debian#715391)
- upstream: 2.0.0-151-g74bdd9a1a02a
* Wed Jun 25 2014 kgronlund@suse.com
- low: history: remove existing report directory on refresh
- upstream: 2.0.0-149-gfb2c8c0591cb
* Thu Jun 19 2014 kgronlund@suse.com
- Medium: hb_report: update interface to zypper (bnc#883186)
- Medium: hb_report: support logs with varied timestamps (bnc#883186)
- Low: hb_report: getstampproc is global (bnc#883186)
- Low: hb_report: gdb debug symbols output change (bnc#883186)
- Low: hb_report: don't restrict debuginfo to cluster stack binaries (zypper) (bnc#883186)
- high: ui_history: Lazily fetch report data on command (bnc#882959)
- medium: report: Make setting report period more robust (bnc#882959)
- medium: ui_history: Print source if given no argument (bnc#883437)
- upstream: 2.0.0-147-g9ea5208a0054
* Fri Jun 13 2014 kgronlund@suse.com
- medium: ui_resource: Remove empty attrlists when overriding children (bnc#882655)
- high: cibconfig: Retain empty attribute sets (bnc#882655)
- low: report: unpack tarball if it's newer than the existing directory
- low: report: get node list based on collected logs, not from cib
- low: report: test for ha-log.txt instead of cib.txt when listing nodes
- low: report: don't warn on extra nodes in the report
- upstream: 2.0.0-133-g934052881c13
* Thu Jun 12 2014 kgronlund@suse.com
- configure: Nicer error when pacemaker is not running (bnc#882475)
- medium: scripts: configure SSH in cluster init (bnc#882476)
- medium: ui_assist: add template command (bnc#882477)
- medium: cliformat: Fix CLI formatting for rules and id-refs
- upstream: 2.0.0-125-g758b534296ff
* Wed Jun 11 2014 kgronlund@suse.com
- doc: Improved documentation for constraints (bnc#873781)
- doc: Document interval suffixes (bnc#873677)
- upstream: 2.0.0-119-gb2f081b32b1a
* Tue Jun 10 2014 kgronlund@suse.com
- medium: ui_node: Fix display of node attributes (bnc#881979)
- medium: parse: Allow remote as node type
- low: cliformat: Don't show extraneous id for acl rules
- upstream: 2.0.0-115-gf5dfb15e7f43
* Thu Jun  5 2014 kgronlund@suse.com
- high: cibconfig: Fix bug in copy_nvpairs (bnc#881369)
- upstream: 2.0.0-111-gf36401b
* Tue Jun  3 2014 kgronlund@suse.com
- high: parse: Try to retain ordering if possible (bnc#880371)
- high: cibconfig: Enable use of v2 patches in Pacemaker (bnc#880371)
- high: parse: support for ACL schema 2.0 (bnc#880371)
- medium: resource: modify some command wait options (bnc#880982)
- upstream: 2.0.0-109-g0b2645b
* Tue Jun  3 2014 kgronlund@suse.com
- medium: ui_resource: trace promote/demote for multistate resources
- medium: parse: Allow empty property sets (bnc#880632)
- medium: schema: Fix typo in test_schema()
- upstream: 2.0.0-99-g3c1db7e
* Tue May 27 2014 kgronlund@suse.com
- high: cibconfig: adjust attributes when adding operations (bnc#880052)
- high: parse: Support id-ref in nvpairs (fate#316118)
- low: ui_configure: Add --force flag to configure delete
- low: ui_resource: Allow untrace without explicit interval
- upstream: 2.0.0-93-g29c4073
* Thu May 22 2014 kgronlund@suse.com
- medium: xmlutil: Limit xpath search to children (bnc#879419)
- medium: ui: Fix argument check in resource commands (gh#crmsh/crmsh#29)
- upstream: 2.0.0-88-g598dfd4
* Fri May 16 2014 kgronlund@suse.com
- high: xmlutil: Include remote nodes in nodelist (bnc#877962)
- high: cibconfig: Ban containers stealing children (bnc#878112)
- high: parse: Allow role in rule-based location constraints (bnc#878128)
- low: command: Add -h and --help as aliases to help
- upstream: 2.0.0-85-g5c9da05
* Wed May 14 2014 kgronlund@suse.com
- medium: ui_resource: Fix race in start/stop/manage/unmanage (bnc#877640)
- medium: report: Return to handling timestamps internally (bnc#877495)
- upstream: 2.0.0-73-g5f04128
* Tue May 13 2014 kgronlund@suse.com
- report: Make regexp groups non-capturing to avoid limit (bnc#877484)
- constants: Rename cluster attribute to cluster-name (fate#316118)
- cibconfig: Enable score for instance_attributes (bnc#865292)
- cibconfig: Support rules in attribute lists (bnc#865292)
- scripts: Handle percent characters in script output (bnc#876882)
- parse: Allow 'in' and 'spec' instead of 'in_range' and 'date_spec'
- pacemaker: Support Pacemaker XML schema version 2.0
- hb_report: Fix ssh passwords again (bnc#867365)
- vars: Add cluster to list of extra cluster properties (fate#316118)
- upstream: 2.0.0-63-g65d1ad8
* Wed Apr 30 2014 kgronlund@suse.com
- ui: Fix garbage characters in prompt (bnc#875788)
- report: Resolve datetime/timestamp mixup (bnc#874162)
- parse: Fix check for action/role in resource set parser (bnc#875787)
- site: pass --force flag through to crm_ticket (bnc#873200)
- cibconf: add comments in the right order (bnc#866434)
- parse: Unify API for err() (bnc#875791)
- crm: Check and complain about python version < 2.6
- upstream: 2.0.0-38-gc2e94fe366a3
* Fri Apr 11 2014 kgronlund@suse.com
- hb_report: pcmk lib changed permissions (bnc#872958)
- history: Use subsecond precision if possible (bnc#872932)
- history: set colours for all nodes found (bnc#872936)
- upstream: 2.0.0-18-ga957470950b6
* Wed Apr  9 2014 kgronlund@suse.com
- parse: Support cib object tags (fate#315101)
- cibconfig: Support filename-style globs in show/edit (bnc#864346)
- Support Pacemaker 1.3 schema
- upstream: 2.0.0-12-g60ed9131ec43
* Mon Apr  7 2014 kgronlund@suse.com
- utils: Don't crash on missing reply to y/n question (bnc#872380)
- ui_resource: Don't create extra nvpairs (bnc#865024)
- Allow building without PyYAML on targets that lack it
- upstream: 2.0.0-5-g69af99663efd
* Mon Apr  7 2014 kgronlund@suse.com
- Upstream release 2.0
- Upstream moved to http://crmsh.github.io
- upstream cs: 0baa5a6
* Thu Apr  3 2014 kgronlund@suse.com
- history: Improve output when using crm_report (bnc#870886)
- make sanity check of node name not case sensitive
- hb_report: Don't use deprecated ifconfig (bnc#871089)
- upstream cs: e4d5b0a985fa
* Thu Mar 27 2014 kgronlund@suse.com
- medium: Enhanced configure syntax (bnc#870753)
- medium: Display without class:provider: prefix if possible (bnc#870755)
- low: Better args error handling in configure load/save (bnc#870654)
- upstream cs: f3309a48f199
* Mon Mar 17 2014 kgronlund@suse.com
- medium: command: Propagate error from auto-commit (bnc#868533)
- medium: crm_pkg: Add --no-refresh to zypper commands
- medium: scripts: Improved setup in cluster init/add (bnc#868008)
- upstream cs: 053db64d9cca
* Thu Mar 13 2014 kgronlund@suse.com
- medium: scripts: Improved debug output from cluster scripts (bnc#866636)
- medium: scripts: corosync uses mcastport - 1 (bnc#868008)
- medium: xmlutil: fencing-topology used broken comparison (bnc#866639)
- medium: utils: ask() did not respect force flag in all cases (bnc#868007)
- low: utils: Nicer warning when crm_simulate fails
- low: ui: Don't call nonexistent function on unsupported cluster stack
- low: main: Better descriptions for -d and -R flags.
- low: parse: More liberal parsing of role assignment in constraint rules
- upstream cs: dbf8e3b7538
* Sat Mar  8 2014 kgronlund@suse.com
- high: xmlutil: Improved XML comparison function (bnc#866434)
- upstream cs: 4bb659cf287e
* Thu Mar  6 2014 kgronlund@suse.com
- high: xmlutil: Don't strip comments from CIB (bnc#866434)
- medium: xmlutil: order-independent XML comparison (bnc#866434)
- test: Improved unit tests (bnc#866434) (bnc#865024)
- medium: scripts: fix bugs in init script (bnc#866569)
- medium: scripts: enable trace logging for cluster scripts (bnc#866636)
- low: xmlutil: don't crash on degenerate colocations
- low: ui_cluster: use crm_mon -bD1 in wait_for_cluster (bnc#866635)
- low: utils: Record all calls in regression test output (bnc#862383)
- upstream cs: 3fe4ae374b57
* Tue Feb 25 2014 kgronlund@suse.com
- medium: ui_resource: Add maintenance command (bnc#863071)
- upstream cs: b0b556a3ca77
* Wed Feb 19 2014 kgronlund@suse.com
- high: scripts: Disable strict host key checking (bnc#864268)
- high: parse: Fix resource sets displaying as XML (savannah#41617) (bnc#864563)
- upstream cs: 6daeb2253a4a
* Thu Feb 13 2014 kgronlund@suse.com
- medium: hb_report: Fix incorrect quotes (bnc#863816)
- upstream cs: 364c59ee0612
* Thu Feb 13 2014 kgronlund@suse.com
- spec: Require python >= 2.6
- high: cibconfig: Handle non-string arguments (bnc#863736)
- low: cibconfig: do not format xml tags when requested (bnc#863746)
- medium: ui_root: Rename root level to 'root' (bnc#863583)
- doc: manpages: Section name broke docbook generation (bnc#863055)
- upstream cs: 6545c6fc8bf6
* Mon Feb 10 2014 kgronlund@suse.com
- tests: run CIB tests with regression test suite
- upstream cs: 49572fb0f7bb
* Thu Feb  6 2014 kgronlund@suse.com
- high: parse: Fix sequential=true for resource sets (bnc#862334)
- medium: corosync: Allow tabs in corosync.conf (bnc#862577)
- low: cibconfig: fencing_topology warning with stonith templates (savannah#41414)
- spec: update description of crmsh package
- tests: split regression tests into separate -test package
- tests: use python-nose as unit test runner
- tests: improved unit test coverage
- upstream cs: cc52dc69ceb1
* Mon Feb  3 2014 kgronlund@suse.com
- medium: xmlutil: rsc_template has no provider attribute (savannah#41410)
- doc: ui_configure: Document the type: prefix argument to configure show (bnc#861776)
- medium: ra: Infer provider from RA name (bnc#860754)
- low: ui_options: add missing documentation for options set (bnc#860585)
- medium: ui_cib: correct name of cib import (bnc#860584)
- medium: ui_ra: Fix problems with ra info command (bnc#860583)
- Update .spec file and restore pkg_group macro to match openSUSE package
  Issue in verification script that prevented use of macro should be fixed
- upstream cs: 3bf6bc6b82ad
* Tue Jan 21 2014 kgronlund@suse.com
- medium: scripts: Updated health script (fate#309206)
- medium: ui_corosync: Fix corosync.log
- medium: config: Fix bug preventing load of crm.conf
- low: xmlutil: fix unescaped backslash in listshadows()
- upstream cs: fdf3c08dc5e2
* Tue Jan 21 2014 kgronlund@suse.com
- medium: ui_resource: Fix crash in resource cleanup (bnc#859570)
- upstream cs: 693938052ee8
* Mon Jan 20 2014 kgronlund@suse.com
- medium: ui_assist: Add assist sublevel (fate#314917)
- low: ui: Tab completion for new commands
- upstream cs: efa56d142298
* Mon Jan 20 2014 kgronlund@suse.com
- medium: report: call corosync-blackbox, not corosync-fplay
- medium: report: Move report command to cli root
- medium: report: Open reports output by crm_report (fate#316330)
- medium: parse: Fix bugs in parsing uppercase input
- medium: hb_report: Install manpage for crmsh_hb_report
- medium: scripts: Add --scriptdir command line option
- medium: scripts: Support sudo in scripts
- low: report: Show progress when processing many transitions
- low: doc: add documentation on single-stepping cluster scripts
- upstream cs: f3c81a0ba50b
* Thu Jan 16 2014 kgronlund@suse.com
- medium: help: Bug in delayed loading of help text
- medium: ui_corosync: new commands: add-node, del-node,
  set, get
- Medium: corosync: Better parser
- medium: scripts: implemented cluster add script
- low: scripts: handle removing multiple nodes at once
- Medium: scripts: Improved syntax for cluster scripts
- Doc: Update cluster script example and documentation
- Medium: scripts: New node remove script
- upstream cs: a10e109c4c04
* Tue Jan 14 2014 kgronlund@suse.com
- Medium: ui_resource: Fix bug in resource restart
- Medium: ui_corosync: add log command
- Medium: scripts: Allow more compact syntax for steps
- Medium: scripts: Clean up after remote script execution
- upstream cs: 7cd5688c164d
* Fri Jan 10 2014 kgronlund@suse.com
- High: scripts: Cluster scripts (fate#316464, fate#309206, fate#316332)
- Medium: help: Return error if help topic is not found (bug#40821)
- Medium: crm_gv: Support rsc_template in graphs (bnc#850159)
- Low: config: Validate boolean values correctly
- Low: main: Seed random generator on startup
- Low: main: More informative error on start failure
- Low: cluster: Use crm_node -l for node list
- Low: ui_cib: Fix typo in sublevel name: cib.cibconfig -> cib.cibstatus
- Doc: Updated documentation
- upstream cs: d2314df6e8a2
* Thu Jan  2 2014 kgronlund@suse.com
- Medium: cibconfig: Updated fix for configure load method (bnc#841764)
- Low: parse: Correct recognition of kind in order constraints
- upstream cs: cfd8529e182b
* Fri Dec 20 2013 kgronlund@suse.com
- Medium: ui_report: Fix bug when calling hb_report in report sublevel
- Medium: ui_history: Fix bug when checking current sublevel in
  history commands
- upstream cs: 809d4b774bd4
* Tue Dec 17 2013 kgronlund@suse.com
- Medium: parse: Resource sets in location constraints (fate#315158)
- Medium: parse: Regular expressions in location constraints
- Dev: unittests: Run unit tests with regression builds
- Low: parse: Stricter parsing of resource names
- Low: utils: Look for crmd in config.path.crm_daemon_dir
- upstream cs: 0d3abc34b627
* Mon Dec  9 2013 kgronlund@suse.com
- medium: parse: rsc_template is not recognized by parser (bnc#854562)
- medium: vars: Add support for remote-node (bnc#854552)
- low: cibconfig: add missing config import
- build: Add userprefs.py to Makefile
- build: Add missing dependency for python-PyYAML (bnc#854060)
- hb_report: Add support for xz compression (bnc#854060)
* Thu Dec  5 2013 kgronlund@suse.com
- build: update version number to 2.0
- ui: minor completion bug fixes
- doc: document 'options show all'
- cluster: Added prototypical cluster sublevel
- upstream cs: 258f36978113
* Tue Dec  3 2013 kgronlund@suse.com
- ui: Added bash completion
- ui: Improved interactive completion (bnc#845337)
- ui: Better help output
- ui: Colors for prompt and interactive help
- ui: Tab completion for multi-line statements (bnc#845339)
- config: New configuration file format
- ui: New command: resource scores
- configure: Allow setting role in location constraints
- templates: Updated OCFS2 template
- cluster: WIP cluster configuration sublevel
- upstream cs: b63a22f6252b
* Mon Oct 28 2013 dmuhamedagic@suse.com
- build: add dependency on which
- upstream cs: eff5a29dc60e
* Fri Oct 25 2013 dmuhamedagic@suse.com
- build: add hb_report from cluster-glue
- ui: anonymous temporary shadow CIBs
- ra: improve error reporting if the RA does not exist
- history: add wdiff command
- upstream cs: da117d6c690d
* Wed Oct 16 2013 dmuhamedagic@suse.com
- doc: explain groups in more detail (bnc#845336)
- cibconf: fix two fencing top issues (savannah#40173)
- node: clear state new way since pcmk 1.1.8 (bnc#843699)
- cibconf: improve message when producing a configuration graph
- upstream cs: 6ebf75d0560b (1.2.6)
* Wed Sep 25 2013 dmuhamedagic@suse.com
- cibconf: fix removing cluster properties in edit (bnc#841764)
- history: improve setting history source
- cibconf: fix rsc_template referencing (savannah#40011)
- help: fix help for alias commands
- history: show and allow completion of all primitives and not
  only top level resources such as groups
- site: add missing completions
- site: add missing command aliases
- upstream cs: crmsh-1.2.6
* Mon Sep 23 2013 kgronlund@suse.com
- Use fdupes to make symlinks of duplicate .pyo files.
* Fri Sep 13 2013 dmuhamedagic@suse.com
- Add crmsh-cibadmin_can_patch.patch: Allow atomic CIB updates
  (cibadmin -P support)
* Fri Sep 13 2013 dmuhamedagic@suse.com
- completion: list all resource ids for rsctest
- rsctest: fix multistate resource testing
- rsctest: add support for STONITH resources
- history: use more anonymous groups to prevent out of groups
  assertion
- upstream cs: edde9365afa6
* Wed Aug 28 2013 dmuhamedagic@suse.com
- cibconf: disable atomic updates until cibadmin gets fixed
- cibconf: match special ids on configuration edit (fixes
  disappearing elements on edit)
- doc: website sources
- upstream cs: 5cfd0ebaa7e3 (1.2.6-rc3)
* Thu Aug  8 2013 dmuhamedagic@suse.com
- cibconf: repair configure load update
- upstream cs: 66376eb02944
* Mon Aug  5 2013 dmuhamedagic@suse.com
- release candidate 1.2.6-rc1
- main: allow starting with a specified CIB shadow
- main: make sure that tmp files get removed
- cibconf: replace minidom with lxml
- cibconf: groups can have the container meta attribute
- cibconf: do not load CIB automatically in a non-interactive
  mode (bnc#813045)
- cibconf: allow single level fencing_topology (savannah#38737)
- cibconf: improve exit code if a referenced element does not
  exist (e.g. in the show command)
- cibconf: add simulate alias for the ptest command
- cibconf: add -S when running crm_simulate (formerly ptest)
- cibconf: use cibadmin patch to update live CIB (with pcmk >= 1.1.10)
- cibconf: node ids are not id but text
- cibconf: improve elements edit operation
- resource: trace and untrace (RA) commands
- resource: prevent whitespace in meta_attributes when setting
  attributes in nested elements such as groups (bnc#815447)
- resource: add option for better control of group management
  (bnc#806901)
- node/resource: improve lifetime processing
- node: update interface to crm_node, its usage changed
  (bnc#805278)
- node: maintenance/ready commands
- node: ignore case when looking up nodes
- node: update interface to crm_node (node delete)
- node: allow forced node removal
- shadow: fix regression in cib import (from PE file)
- shadow: set shadow directory according to the user preference
- history: fix search for resource messages (bnc#803790)
- history: refresh live report for commands other than info
  (bnc#807402)
- history: use anonymous re groups to prevent out of groups assertion
- history: fix xpath expression for graphs of resource sets
- history: skip empty lines (!) when searching logs
- history: add support for rfc5242 date format in syslog
- userprefs: add reset command
- ui: fix exit code of crm status if crm_mon fails (savannah#38702)
- ui: fix exit code of the help command
- parse: drop obsolete test for operations
- performance: do not make unnecessary parameter uniqueness test
  (bnc#806372)
- performance: check programs existence with python os module
  (bnc#806372)
- performance: improve tests for running resources
* Tue Feb 12 2013 dmuhamedagic@suse.com
- main: do not fail if the user's homedir is not defined
- cibconfig: directed graph support
- cibconfig: modgroup command
- cibconfig: fix syntax error in ptest
- history: create missing parts of the history cache directory
- history: graph command
- history: show pe commands
- history: diff between PE inputs
- upstream cs: 53d0f83c064e (release v1.2.5)
* Thu Dec 27 2012 dmuhamedagic@suse.com
- history: update completion lists for transition
- history: add one node log pattern
- history: add date to the long peinputs listing
- upstream cs: bf5c9a8b3e87 (v1.2.4 really)
* Wed Dec 19 2012 dmuhamedagic@suse.com
- history: force refresh on session load
- history: detailed transition output
- history: add colours to info
- history: try always to print some real time period
- history: print transitions in info
- history: fix regression when creating log objects
- history: implement transition save (to shadow) subcommand
- upstream cs: 7c09f05419e6 (v1.2.4)
* Tue Dec 11 2012 dmuhamedagic@suse.com
- cibconfig: improve id management on element update
- cibconfig: don't bail out if filter fails
- ui: improve quotes insertion
- history: optimize source refreshing
- history: fix setting up the timeframe alias for limit
- history: fix unpacking reports specified without directory
- history: add log subcommand to transition
- ra: add support for nagios plugins
- ra: don't print duplicate RAs in the list command (bnc#793585)
- utils: make sure that there's at least one column (savannah#37658)
- build: pcmk.pc renamed to pacemaker.pc in pacemaker v1.1.8
- upstream cs: fe29639e39eb (v1.2.3)
* Mon Oct 15 2012 dmuhamedagic@suse.com
- report: adjust patterns for 1.1.8
- ra: manage without glue installed (savannah#37560)
- cibconfig: show error message on id in use
- ui: readd quotes for single-shot commands
- upstream cs: b6bb311c7bd3 (crmsh-1.2.1)
* Thu Oct 11 2012 dmuhamedagic@suse.com
- cibconfig: repair edit for non-vi users
- cibconfig: node type is optional now
- ra: add support for crm_resource
- ra: improve support for RH fencing-agents
- utils: exit code of cibadmin -Q on no section changed in 1.1.8
- history: add the exclude (log messages) command
- report: remove keyword 'as' which is not compatible with python
  2.4 (savannah#37534)
- build: replace StrictVersion with LooseVersion (savannah#37537)
- upstream cs: 1d38a7a06f04
* Thu Sep 27 2012 dmuhamedagic@suse.com
- ra: don't fail on unknown ${} term sequences (fixes oracle
  metadata)
- cibconfig: update schema separately (don't remove the status
  section)
- upstream cs: 0994b099c2dc
* Tue Sep 18 2012 dmuhamedagic@suse.com
- help: add topics to the help system
- help: add '?' as alias for help
- help: append slash to levels in overview help screen
- help: page overview help screens
- ui: add vim syntax highlighting support
- utils: use crm_simulate if ptest is not available
- upstream cs: df0b30262868 (release 1.2.0)
* Wed Aug 29 2012 dmuhamedagic@suse.com
- ui: import readline only when needed (don't print ".[?1034h")
- cibconfig: support kind attribute in orders
- cibconfig: implement node-attribute in collocations
- cibconfig: drop attributes set to default on cib import
- cibconfig: support require-all in resource sets
- cibconfig: support setting attributes resource sets
- cibconfig: support for fencing-topology
- cibconfig: new schema command
- upstream cs: a4f00b8fb5c8
* Fri Jul 20 2012 dmuhamedagic@suse.com
- history: implement session saving
- history: add alias (timeframe) for the limit command
- history: improve limiting the report time period
- xml: retrieve data from schema (lf#2092)
- xml: support for RNG schema
- upstream cs: 2651d52fb3cd
* Mon Jul  9 2012 dmuhamedagic@suse.com
- ui: fix the node status command (lf#2175)
- cibconf: display referenced attr set ids (lf#2304)
- cibconf: don't verify parameters starting with '$'
- cibconf: fix meta attributes verify for container elements (lf#2555)
- cibconf: test for duplicate monitor intervals (lf#2586)
- cibconf: don't skip monitor operations on verify
- ui: don't accept non-ascii input (lf#2597)
- upstream cs: a2b420ccab94
* Mon Jul  2 2012 dmuhamedagic@suse.com
- ra: don't require certain parameters for rhcs stonith resources
- ticket: fix redirecting rsc references in tickets (bnc#763465)
- ui: enable wait (option -w) for single-shot configure commands
- upstream cs: 94167417eb8f
* Fri Jun  8 2012 dmuhamedagic@suse.com
- report: fine tune resource match patterns
- utils: improve terminal output height calculation (pager)
- upstream cs: d1dc149810d7
* Wed Jun  6 2012 dmuhamedagic@suse.com
- rsctest: fixes and support for clones
- upstream cs: fb4d9bbaff30
* Tue Jun  5 2012 dmuhamedagic@suse.com
- rsctest: resource testing
- upstream cs: 28450520a1f1
* Fri May 25 2012 dmuhamedagic@suse.com
- shadow: calculate shadow directory just like crm_shadow (bnc#759056)
- history: update patterns for resources
- upstream cs: 9569a7f283cb afba1bc67e98
* Mon Apr 23 2012 tserong@suse.com
- Add libxslt-tools to BuildRequires
* Thu Mar 29 2012 lmb@novell.com
- Change how appropriate version of pacemaker for ticket support is
  required (bnc#752241)
* Tue Mar 27 2012 dmuhamedagic@suse.com
- drop dependency on python-xdg (lives in SDK repo)
* Tue Mar 27 2012 dmuhamedagic@suse.com
- add Requires pacemaker >= 1.1.6-2 to the spec file
* Mon Mar 26 2012 dmuhamedagic@suse.com
- move user files to standard locations (XDG)
- site: ticket standby and activate commands
- cibstatus: ticket management
- site: update interface to crm_ticket
- cibconf: use uname instead of id when listing nodes (cl#5043)
- ra: use only effective UID when choosing RA interface
- ra: always use lrmadmin with glue 1.0.10 (cl#5036)
- upstream cs: 9569a7f283cb
* Tue Feb 14 2012 tserong@suse.com
- history: reset time period when setting source
- doc: describe deficiency in the configure edit command (bnc#715698)
- cibconf: repair resource parameter uniqueness test
- completion: add command aliases to completion tables (cl#5013)
- cibconf: repair ability to manage multiple rsc/op_defaults (bnc#737812)
- history: add clone/ms resources to events (fixes the transition command)
- utils: repair ptest usage (bnc#736212)
- cibconf: repair xml edit
- history: expand clones and ms in the resource command (bnc#729631)
- build: add optional regression testing on rpm build
- upstream cs: c06b8cf8fcf8
* Wed Jan 11 2012 tserong@suse.com
- Clean up spec file (fix license string, don't rm buildroot, etc.)
* Tue Jan 10 2012 cfarrell@suse.com
- license update: GPL-2.0
  It is sufficient to add the GPL-2.0 in SPDX format
* Fri Dec 16 2011 tserong@suse.com
- Add BuildRequires: libtool
* Thu Nov 24 2011 dmuhamedagic@suse.com
- cibconf: remove also elements which depend on the resource
  template which is to be deleted (bnc#730404)
- cibconf: report error if a referenced template in primitive
  doesn't exist (bnc#730404)
- upstream cs: cb8034d8d3da
* Thu Nov 17 2011 dmuhamedagic@suse.com
- cibconf: exchange rsc and with-rsc after converting collocation
  sets to standard constraints (bnc#729628)
- cibconf: convert resource sets to standard constraints on
  resource removal (bnc#729628)
- ra: fix start/stop interval test
- history: don't assume that a hb_report tarball name matches the
  top directory name
- completion: add templates as possible resource refences in
  constraints
- upstream cs: aa1bda731a28
* Sun Nov  6 2011 dmuhamedagic@suse.com
- history: handle non-existing source better (bnc#728346)
- history: fix regression when fetching new PE inputs (bnc#723417)
- history: use debug severity for repeating messages (bnc#726611)
- upstream cs: 431a83929670
* Wed Oct 26 2011 dmuhamedagic@suse.com
- build: fetch the daemon location from glue-config.h
- upstream cs: 1d7925b6862a
* Mon Oct 24 2011 dmuhamedagic@suse.com
- ui: revert changeset 3802eb56b914 (bnc#717198)
- utils: prevent spurious error messages if an element doesn't
  exist in CIB (bnc#723677)
- report: add pattern to match resource log messages
- upstream cs: 43184b4987f1
* Wed Oct 19 2011 dmuhamedagic@suse.com
- stable release 1.1.0
- history/troubleshooting support
- template support
- geo-cluster support commands
- support for configure rsc_ticket
- support for LRM secrets at the resource level
- enable removal of unmanaged resources (bnc#696506)
- split-off from Pacemaker after release 1.1.6
- upstream cs: d2c001ae6344
